package com.up.zpb.controller.api;

import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Objects;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alipay.api.AlipayApiException;
import com.alipay.api.internal.util.AlipaySignature;
import com.google.common.collect.Maps;
import com.up.zpb.mapper.MemberMapper;
import com.up.zpb.mapper.MemberOrderMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.UserOperRecordsMapper;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.DateUtils;
import com.up.zpb.util.PayUtils;
import com.up.zpb.vo.MemberOrder;


@CrossOrigin
@RestController("appAliPayCallBackApi")
@RequestMapping("aliPayCallBack")
public class AlipayCallBackApi {
	private static final Logger log = LoggerFactory.getLogger(AlipayCallBackApi.class);
	
	public final static String CHARSET = ConfigurationUtils.getStringValue("ALI_CHARSET");
	public final static String publicKey = ConfigurationUtils.getStringValue("ALI_PAY_PUBLIC_KEY");
	
	@Autowired
	private MemberOrderMapper memberOrderMapper;
	
	@Autowired
	private MemberMapper memberMapper;
	
	@Autowired
	private ProjectOrderMapper projectOrderMapper;
	
	@Autowired
	private ShopMapper shopMapper;
	
	@Autowired
	private UserOperRecordsMapper userOperRecordsMapper;
	
	@RequestMapping("callBack")
	public void callback(HttpServletRequest request,HttpServletResponse response) throws IOException {
		log.info("alipay callBack run.....");
		//获取支付宝POST过来反馈信息
		Map<String,String[]> requestParams = request.getParameterMap();
		String orderNo = new String(request.getParameter("out_trade_no").getBytes("ISO-8859-1"),"UTF-8");
		String orderFee = new String(request.getParameter("total_amount").getBytes("ISO-8859-1"),"UTF-8");
		String trade_no = new String(request.getParameter("trade_no").getBytes("ISO-8859-1"),"UTF-8");
		String buyer_logon_id =null;
		if(Objects.isNull(request.getParameter("buyer_logon_id"))) {
			if(Objects.nonNull(request.getParameter("buyer_id"))) {
				buyer_logon_id = new String(request.getParameter("buyer_id").getBytes("ISO-8859-1"),"UTF-8");		
			}
		}else {
			buyer_logon_id = new String(request.getParameter("buyer_logon_id").getBytes("ISO-8859-1"),"UTF-8");	
		}
		
		String gmt_payment = new String(request.getParameter("gmt_payment").getBytes("ISO-8859-1"),"UTF-8");
		log.info("orderNo : "+orderNo+"   "+"orderFee : "+orderFee+"  "+"trade_No : "+trade_no);
		//1、校验签名
		Boolean signVerified = checkSign(requestParams);
		log.info("signVerified");	
		if(!signVerified) {
			response.getWriter().write("failed");
		}else {
			response.getWriter().write("success");
			MemberOrder order = memberOrderMapper.selectByPrimaryKey(orderNo);
			if(1 == order.getStatus()) {
				return;
			}
			//2、支付金额校验
			log.info("orderFee:{}",orderFee);
			log.info("payAmount------>"+ order.getOrderFee().toString());
			double fee = Double.parseDouble(orderFee);
			Double payAmount = Double.valueOf(order.getOrderFee().toString());
			if(fee!=payAmount){
					response.getWriter().write("failed");
			}else {
			log.info("支付成功进入");
				//支付成功 更新对应记录
			    //更新订单表
			    order.setStatus(1);
			    order.setPaymentType(0);// 支付宝
				order.setBuyerEmail(buyer_logon_id);
				order.setPayTime(DateUtils.format(gmt_payment, "yyyy-MM-dd hh:mm:ss"));//支付时间
				order.setTradeNo(trade_no);//支付流水号
				memberOrderMapper.updateByPrimaryKey(order);
				Map<String,Object> parameters = Maps.newHashMap();
				parameters.put("orderNo", order.getOrderNo());
				Map<String, Object> mo = memberOrderMapper.selectByOrderNo(parameters);
				Integer dura =Integer.valueOf(mo.get("duration").toString());
				log.info("dura--->"+ dura);
				//创建会员相关信息
				if((Integer)mo.get("catgory") != 4) {
					PayUtils.createMember(order, memberMapper,shopMapper,dura,userOperRecordsMapper);
				}else {
					PayUtils.updateProjectOrderForSuccess(order.getOrderNo(),projectOrderMapper);
				}
			 log.info("支付成功结束");
			}
		}
	}
	
	public Boolean checkSign(Map<String,String[]> requestParams){
		//获取支付宝POST过来反馈信息
		Map<String,String> params = new HashMap<String,String>();
		for (Iterator<String> iter = requestParams.keySet().iterator(); iter.hasNext();) {
		    String name = (String) iter.next();
		    String[] values = (String[]) requestParams.get(name);
		    String valueStr = "";
		    for (int i = 0; i < values.length; i++) {
		        valueStr = (i == values.length - 1) ? valueStr + values[i]
		                    : valueStr + values[i] + ",";
		  	}
		    //乱码解决，这段代码在出现乱码时使用。
			params.put(name, valueStr);
		}
		//切记alipaypublickey是支付宝的公钥，请去open.alipay.com对应应用下查看。
		boolean flag = false;
		try {
			flag = AlipaySignature.rsaCheckV1(params, publicKey, CHARSET,"RSA2");
		} catch (AlipayApiException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return flag;
	}

}
