package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.AliPayService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;

@RestController
@RequestMapping("/aliPay/auth")
public class AppAliPayController extends AbstractController{

	
	@Autowired
	AliPayService appAliPayService;
	
	private static final Logger logger = LoggerFactory.getLogger(AppAliPayController.class);

	/**
	 * app支付
	 * @param request
	 * @return
	 */
	@PostMapping("appPay")
	public ResultObject appPay(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("orderSource"), "orderSource").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.aliPay(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	/**
	 * H5支付
	 * @param request
	 * @return
	 */
	@PostMapping("h5Pay")
	public ResultObject H5Pay(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("orderSource"), "orderSource").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.h5Pay(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	
	/**
	 * 官网支付宝支付
	 * @param request
	 * @return
	 */
	@PostMapping("aliPayPC")
	public ResultObject aliPayPC(HttpServletRequest request,HttpServletResponse response) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("orderSource"), "orderSource").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.aliPayPC(parameters,response);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	
	/**
	 * 获取金额
	 * @param request
	 * @return
	 */
	@PostMapping("getPayAmount")
	public ResultObject getPayAmount(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.getPayAmount(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	
	/**
	 * 
	 * @param request
	 * @return
	 */
	@PostMapping("createPCOrder")
	public ResultObject createPCOrder(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.createPCOrder(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	
	/**
	 * 检测订单是否支付
	 * @param request
	 * @return
	 */
	@PostMapping("isPay")
	public ResultObject isPay(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("orderNo"), "orderNo").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = appAliPayService.isPay(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	
	

}
