package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AppService;
import com.up.zpb.service.AreasService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.ProjectOrderService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;

@RestController
@RequestMapping("appInfo")
public class AppController  extends AbstractController {


	private static final Logger logger = LoggerFactory.getLogger(AppController.class);
	@Autowired
	AppService appService;
	@Autowired
	AreasService areaService;
	@Autowired
	RedisBaseDao redisBaseDao;
	@Autowired
	private ProjectOrderService projectOrderService;
	@Autowired
	private DictionaryService dictionaryService;



	/**
	 * APP首页接口
	 * @param request
	 * 	cityId：APP所在城市
	 * @return
	 */
	@PostMapping("/showInfoApp")
	public ResultObject showInfoApp(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【showInfoApp()开始=========="+parameters+"】");
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			
			String userType="1";
			UserApp loginUserEn=this.dictionaryService.getLoginUser(request);
			if(loginUserEn!=null && StringUtils.isNotEmpty(loginUserEn.getUserType()) && Integer.valueOf(loginUserEn.getUserType())>1 ){
				userType="2";
			}
			String indexKey=Constant.SHOW_INFO_APP + parameters.get("cityId").toString()+Constant.JOIN+userType;
			
			if(redisBaseDao.exists(indexKey)){
				resultObject.putAll(redisBaseDao.hMGetMap(indexKey));
			}else {
				parameters.put("userType", userType);
				resultObject=appService.showInfoApp(parameters,indexKey);
			}
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【showInfoApp()结束=========="+resultObject+"】");
		return resultObject;
	} 
	
	
	/**
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findProjectOrderPage")
	public ResultObject findProjectOrderPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findProjectOrderPage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.projectOrderService.findProjectOrderPage(parameters);
		logger.info("【showInfoApp()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/*@PostMapping("/findCallInfo")
	public Map<String, Object> findCallInfo(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findCallInfo()=================入参："+parameters+"】");
		try {
			try{
				CheckParametersUtil.getInstance()
				.put(parameters.get("projectId"), "projectId")
				.put(parameters.get("projectType"), "projectType")
				.put(parameters.get("agentId"), "agentId")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=this.appService.findCallInfo(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} 
		logger.info("【findCallInfo()=================出参："+resultObject+"】");
		return resultObject;
	}
	*/
}
