package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AreasService;
import com.up.zpb.service.BrandService;
import com.up.zpb.service.CallCenterService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.JWTUtil;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.Brand;
import com.up.zpb.vo.BrandContactsError;
import com.up.zpb.vo.BrandContactsErrorArea;
import com.up.zpb.vo.BrandLinkman;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;

/**
 * 
 * 
 * 
 * @author PJJ
 * @version 1.0
 * @created 2019年7月30日 下午2:23:36
 */
@RestController
@RequestMapping(value = "/brand")
public class BrandController {

	private static final Logger logger = LoggerFactory.getLogger(BrandController.class);

	@Autowired
	private ShowInfoService showInfoService;
	@Autowired
	private RedisBaseDao redisBaseDao;
	@Autowired
	private CallCenterService callCenterService;
	@Autowired
	private DictionaryService dictionaryService;
	@Autowired
	private AreasService areasService;
	@Autowired
	private BrandService brandService;

	/**
	 * 获取品牌分页列表
	 * 
	 * @return
	 */
	@PostMapping("/getBrandList")
	@Cacheable(key = "#pageNum+'.'+#brandName+'.'+#region+'.'+#brandType+'.'+#titleMianjiId+'.'+#brandNature", value = "brand:list")
	public Map<String, Object> getBrandList(HttpServletRequest request, String pageNum, String brandName, String region,
			String brandType, String titleMianjiId, String brandNature) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【=================入参：" + parameters + "】");
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("pageSize"), "pageSize")
						.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.remove("cityId");// 进来默认展示所有城市的品牌
			resultObject = showInfoService.getBrandList(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		}
		logger.info("【=================出参：" + resultObject + "】");
		return resultObject;
	}

	/**
	 * 品牌搜索条件： 需求面积-拓展区域-品牌业态
	 * 
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findBrandSearch")
	public ResultObject findBrandSearch(HttpServletRequest request) throws Exception {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		parameters.put("belongs", "1");
		if (redisBaseDao.exists(Constant.FIIND_BRAND_SEARCH + parameters.get("cityId").toString())) {
			resultObject
					.putAll(redisBaseDao.hMGetMap(Constant.FIIND_BRAND_SEARCH + parameters.get("cityId").toString()));
		} else {
			resultObject = this.showInfoService.findBrandSearch(parameters);
		}
		return resultObject;
	}

	/**
	 * 热门推荐
	 * 
	 * @return
	 */
	@PostMapping("/getHotBrandList")
	public Map<String, Object> getHotBrandList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【=================入参：" + parameters + "】");
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("pageSize"), "pageSize")
						.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject = showInfoService.getBrandList(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		}
		logger.info("【=================出参：" + resultObject + "】");
		return resultObject;
	}

	/**
	 * 品牌详情
	 * 
	 * @param request
	 * @return
	 */
	@PostMapping("/findBrandDetail")
	public Map<String, Object> findBrandDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【=================入参：" + parameters + "】");
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("brandId"), "brandId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = showInfoService.findBrandDetail(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		}
		logger.info("【=================出参：" + resultObject + "】");
		return resultObject;
	}

	@PostMapping("/savePhoneRecord")
	public Map<String, Object> savePhoneRecord(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【savePhoneRecord()=================入参：" + parameters + "】");
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("brandId"), "brandId")
						.put(parameters.get("userId"), "userId").put(parameters.get("phone"), "phone").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = showInfoService.savePhoneRecord(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		}
		logger.info("【savePhoneRecord()=================出参：" + resultObject + "】");
		return resultObject;
	}

	// ======================app品牌迭代
	/**
	 * 初始化下拉框数据
	 * 
	 * @param request
	 * @return
	 */
	@PostMapping("/brandReleasedPage")
	public ResultObject brandReleasedPage(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			// 拓展区域
			resultObject.put("expandAreaList", this.areasService.selectAreasNoQuanBu("0"));
			// 业态
			resultObject.put("brandBusinessList", brandService.getBrandBusinessList());
			// 品牌定位
			resultObject.put("brandPositioningList", this.dictionaryService.selectMapByParentKey("123"));
			// 岗位
			resultObject.put("brandPostList", this.dictionaryService.selectMapByParentKey("546"));

		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	
	/**
	 * 初始化下拉框数据
	 * 
	 * @param request
	 * @return
	 */
	@PostMapping("/brandReleasedPageAndroid")
	public ResultObject brandReleasedPageAndroid(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			// 拓展区域
			resultObject.put("expandAreaList", this.areasService.selectAreasNoQuanBu("0"));
			// 业态
			resultObject.put("brandBusinessList", brandService.getBrandBusinessList());
			// 品牌定位
			resultObject.put("brandPositioningList", this.dictionaryService.selectMapByParentKeyD("123"));
			// 岗位
			resultObject.put("brandPostList", this.dictionaryService.selectMapByParentKeyD("546"));

		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	

	/**
	 * 发布品牌
	 * 
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/brandReleased")
	public ResultObject brandReleased(HttpServletRequest request, Brand entity) {
		logger.info("【==========发布品牌-请求全路径是："+request.getRequestURL()+"参数："+JSON.toJSONString(entity)+"】");
		ResultObject resultObject = new ResultObject();
		entity.setCreateBy(this.getLoginMember(request).getId()+"");
		resultObject=this.brandService.publishBrand(entity);
		logger.info("【==========发布品牌-返回结果："+resultObject.toString());
		return resultObject;
	}
	
	
	


	/**
	 * 成为品牌联系人
	 * 
	 * @param request
	 * @param brandContacts
	 * @return
	 */
	@PostMapping("/auth/createContact")
	public ResultObject createContact(HttpServletRequest request, BrandLinkman entity) {
		ResultObject resultObject = new ResultObject();
		try {
			logger.info("【==========成为品牌联系人-请求全路径是："+request.getRequestURL()+"参数："+JSON.toJSONString(entity)+"】");
			if(StringUtils.isBlank(entity.getBrandContactsArea())){
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("参数【brandContactsArea】不能为空");
				return resultObject;
			}
			Integer userId=this.getLoginMember(request).getId();
			entity.setCreateBy(userId==null?1:userId);
			this.brandService.createContact(entity);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【==========成为品牌联系人-返回结果："+resultObject.toString());
		return resultObject;
	}

	/**
	 * 品牌纠错
	 * 
	 * @param request
	 * @param brandContactsError
	 * 
	 * @return
	 */
	@PostMapping("/auth/createContactError")
	public ResultObject createContactError(HttpServletRequest request, BrandContactsError brandContactsError) {
		ResultObject resultObject = new ResultObject();
		try {
			logger.info("【==========品牌纠错-请求全路径是："+request.getRequestURL()+"参数："+JSON.toJSONString(brandContactsError)+"】");
			brandContactsError.setMemberId(this.getLoginMember(request).getId());
			String brandContactsArea = brandContactsError.getBrandContactsArea();
			if (StringUtils.isNotBlank(brandContactsArea)) {
				String[] beas = StringUtils.split(brandContactsArea, ";");
				for (String bea : beas) {
					String[] rp = StringUtils.split(bea, "-");
					BrandContactsErrorArea bca1 = new BrandContactsErrorArea();
					bca1.setRegionsId(Integer.valueOf(rp[0]));
					bca1.setProvinceId(rp[1]);
					brandContactsError.getBrandContactsErrorAreaList().add(bca1);
				}
			} else {
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("请传联系人的负责区域");
			}
			this.brandService.createContactError(brandContactsError);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【==========品牌纠错-返回结果："+resultObject.toString());
		return resultObject;
	}

	
	/**
	 * 获取当前登录用户信息
	 * @param request
	 * @return
	 */
	protected UserApp getLoginMember(HttpServletRequest request) {
		logger.info("【========== 获取当前登录用户信息-请求全路径是："+request.getRequestURL()+"?"+request.getQueryString()+"】");
		String token = request.getHeader(Constant.APP_HEADER_ACCESS_TOKEN);
		if (StringUtils.isBlank(token)) {
			token = request.getParameter(Constant.APP_HEADER_ACCESS_TOKEN);
		}
		UserApp userEn=JWTUtil.unsign(token, UserApp.class);
		logger.info("【========== 获取当前登录用户信息-返回结果:"+userEn.getId());
		return userEn;
	}
	/**
	 * 回显联系人信息
	 * @param request
	 * @param brandContactId  对应linkman表主键
	 * @return
	 */
	@PostMapping("/auth/showContactError")
	public ResultObject showContactError(HttpServletRequest request,Integer brandContactId) {
		ResultObject resultObject = new ResultObject();
		try {
			logger.info("【=================入参brandContactId：" + brandContactId + "】");
			resultObject = this.brandService.getContactError(brandContactId,this.getLoginMember(request).getId());
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【=================返回结果：" + resultObject + "】");
		return resultObject;
    }
	
	@PostMapping("/findMyPublishBrand")
	public Map<String, Object> findMyPublishBrand(HttpServletRequest request, String createBy) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		logger.info("【=================入参：" + parameters + "】");
		try {
			try {
				CheckParametersUtil.getInstance()
						.put(parameters.get("createBy"), "createBy")
						.put(parameters.get("brandNature"), "brandNature").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = brandService.findMyPublishBrand(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		}
		logger.info("【=================出参：" + resultObject + "】");
		return resultObject;
	}
	
	

}
