package com.up.zpb.controller.api;


import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.service.CompanyService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 公司列表
 */
@RestController
@RequestMapping(value = "/company/auth")
public class CompanyController {

    private static final Logger logger = LoggerFactory.getLogger(CompanyController.class);

    @Autowired
    private CompanyService companyService;

    /**
     * 公司下成员列表信息
     *
     * @param request
     * @return
     */
    @PostMapping("/myCompanyList")
    public ResultObject myCompanyList(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject.put("data", companyService.selectMyCompanyList(parameters));
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }


    /**
     * 移出成员
     *
     * @param request
     * @return
     */
    @PostMapping("/deleteUser")
    public ResultObject deleteUser(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        companyService.deleteUser(parameters);
        return resultObject;
    }


}
