package com.up.zpb.controller.api;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.service.customer.CustomerService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.Customer;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.enums.CustomerEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

/**
 * 客源控制器
 */
@RestController
@RequestMapping("/customer")
@Controller
public class CustomerController {

    private static final Logger logger = LoggerFactory.getLogger(CustomerController.class);

    @Autowired
    private CustomerService customerService;


    /**
     * 客源列表搜索所需json
     *
     * @param cityId
     * @returns
     */
    @PostMapping("/getSearchCustomerDictionaries")
    public ResultObject getSearchCustomerDictionaries(String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(cityId, "cityId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return customerService.getListEntrust(cityId);
    }

    /**
     * 客源管理列表
     *
     * @param request
     * @return
     */
    @PostMapping("/getSearchCustomer")
    public ResultObject getSearchCustomer(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("cityId"), "cityId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = customerService.getSearchCustomer(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    /**
     * PC发布客源所需要的json
     *
     * @param cityId
     * @return
     */
    @PostMapping("/auth/getEntrust")
    public ResultObject getEntrust(String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(cityId, "cityId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return customerService.getEntrust(cityId);
    }

    /**
     * App发布客源所需要的json
     * type 1写字楼 2 商铺
     *
     * @return
     */
    @PostMapping("/auth/getEntrustApp")
    public ResultObject getEntrustApp(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("cityId"), "cityId")
                    .put(parameters.get("type"), "type")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return customerService.getEntrustApp(parameters);
    }


    /**
     * 客源信息录入提交
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/submit")
    public ResultObject submit(HttpServletRequest request, Customer customer) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(customer.getEntrustOne(), "entrustOne")
                    .put(customer.getEntrustTwo(), "entrustTwo")
                    .put(customer.getWantRegion(), "wantRegion")
                    .put(customer.getWantArea(), "wantArea")
                    .put(customer.getWantAreaMin(), "wantAreaMin")
                    .put(customer.getWantAreaMax(), "wantAreaMax")
                    .put(customer.getRemarks(), "remarks")
                    .put(customer.getCommission(), "commission")
                    .put(customer.getCityId(), "commission")
                    .put(customer.getCommissionDate(), "commissionDate")
                    .put(customer.getCreateUser(), "createUser")
                    .put(customer.getCreateTel(), "createTel")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return customerService.submit(parameters, customer);
    }

    /**
     * 客源详情页
     *
     * @param request
     * @return
     */
    @PostMapping("/detail")
    public ResultObject detail(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            resultObject = customerService.getDetail(parameters);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

    /**
     * 经纪人-我的客源列表
     *
     * @param request
     * @return
     */
    @PostMapping("/getMySourceList")
    public ResultObject getMySourceList(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        logger.info("【CustomerController】【getMySourceList()开始==========】"+parameters+"");
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("userId"), "userId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        logger.info("【CustomerController】【getMySourceList()结束=========="+resultObject+"】");
        return customerService.getMySourceList(parameters);
    }

    /**
     * 获取 我的页面  我的客源列表 客户类型筛选项 与订单状态下拉
     * @param request
     * @return
     * @throws Exception
     */
    @GetMapping("/getSourceType")
    public ResultObject getFollowSearch(HttpServletRequest request)throws Exception{
        ResultObject resultObject=new ResultObject();
        logger.info("【CustomerController】【getSourceType()开始==========】");
        try{
            //客户类型
            ArrayList<Map<String, Object>> customerList = new ArrayList<>();
            HashMap<String, Object> customerMap = new HashMap<>();
            customerMap.put("id",null);
            customerMap.put("typeName","全部类型");
            customerList.add(customerMap);
            CustomerEnum.CustomerType[] values = CustomerEnum.CustomerType.values();
            for (CustomerEnum.CustomerType value : values) {
                HashMap<String, Object> map = new HashMap<>();
                map.put("id",value.getValue());
                map.put("typeName",value.getName());
                customerList.add(map);
            }

            //订单状态
            ProjectEnum.OrderStatus[] orderStatuses = ProjectEnum.OrderStatus.values();
            HashMap<String, Object> statusMap = new HashMap<>();
            statusMap.put("id",null);
            statusMap.put("stautsName","全部状态");
            ArrayList<Object> statusList = new ArrayList<>();
            statusList.add(statusMap);
            for (ProjectEnum.OrderStatus orderStatus : orderStatuses) {
                HashMap<String, Object> map = new HashMap<>();
                map.put("id",orderStatus.getValue());
                map.put("stautsName",orderStatus.getName());
                statusList.add(map);
            }
            
            resultObject.put("customerType",customerList);
            resultObject.put("orderStatusType",statusList);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        logger.info("【CustomerController】【getSourceType()结束=========="+resultObject+"】");
        return resultObject;
    }
    
    
    
    
    @PostMapping("/findMyFollowCustomerPage")
    public ResultObject findMyFollowCustomerPage(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        logger.info("【findMyFollowCustomerPage】开始=========="+parameters+"");
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("agentId"), "agentId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        logger.info("【findMyFollowCustomerPage】结束=========="+resultObject+"】");
        return this.customerService.findMyFollowCustomerPage(parameters);
    }
    
    
    @PostMapping("/findMyPublishCustomerPage")
    public ResultObject findMyPublishCustomerPage(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        logger.info("【findMyPublishCustomerPage】开始=========="+parameters+"");
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("agentId"), "agentId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        logger.info("【findMyPublishCustomerPage】结束=========="+resultObject+"】");
        return this.customerService.findMyPublishCustomerPage(parameters);
    }
    
    
}
