package com.up.zpb.controller.api;

import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.HomeShopService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.UserApp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/**
 * 房源发布控制器
 */
@RestController
@RequestMapping("/homeShop")
public class HomeShopController {

    private static final Logger logger = LoggerFactory.getLogger(HomeShopController.class);

    @Autowired
    private HomeShopService homeShopService;
    @Autowired
    private DictionaryService dictionaryService;

    /**
     * 商铺出售
     *
     * @param request
     * @param shop
     * @return
     */
    @PostMapping("/auth/submitShopSell")
    public ResultObject submitShopSell(HttpServletRequest request, Shop shop) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        shop.setAgentId(String.valueOf(parameters.get("authentication")));
        try {
            CheckParametersUtil.getInstance()
            .put(parameters.get("commission"), "commission")
            //.put(parameters.get("commissionType"), "commissionType") 配合appV2.0上线暂时去掉必填校验
            .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        //渠道 优先从参数里取
		if(ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
			UserApp userApp=this.dictionaryService.getLoginUser(request);
			shop.setChannel(userApp.getChannel()+"");
		}else{
			shop.setChannel(parameters.get("channel")+"");
		}
        try {
            return homeShopService.submitShop(parameters, shop);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    /**
     * 商铺出租
     *
     * @param request
     * @param shop
     * @return
     */
    @PostMapping("/auth/submitShopLease")
    public ResultObject submitShopLease(HttpServletRequest request, Shop shop) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        shop.setAgentId(String.valueOf(parameters.get("authentication")));
        try {
        	try {
                CheckParametersUtil.getInstance()
                .put(parameters.get("commission"), "commission")
                //.put(parameters.get("commissionType"), "commissionType") 配合appV2.0上线暂时去掉必填校验
                .checkParameter();
            } catch (Exception e) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage(e.getMessage());
                logger.error(e.getMessage(), e);
                return resultObject;
            }
        		//渠道 优先从参数里取
			if(ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
				UserApp userApp=this.dictionaryService.getLoginUser(request);
				shop.setChannel(userApp.getChannel()+"");
			}else{
				shop.setChannel(parameters.get("channel")+"");
			}
			System.out.println("===== : "+shop.getChannel());
            return homeShopService.submitShopLease(parameters, shop);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    /**
     * 商业新盘
     *
     * @param request
     * @param shop
     * @return
     */
    @PostMapping("/auth/submitShopNew")
    public ResultObject submitShopNew(HttpServletRequest request, Shop shop) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        shop.setAgentId(String.valueOf(parameters.get("authentication")));
        try {
        	try {
                CheckParametersUtil.getInstance()
                .put(parameters.get("commission"), "commission")
                //.put(parameters.get("commissionType"), "commissionType") 配合appV2.0上线暂时去掉必填校验
                .checkParameter();
            } catch (Exception e) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage(e.getMessage());
                logger.error(e.getMessage(), e);
                return resultObject;
            }
        		//渠道 优先从参数里取
			if(ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
				UserApp userApp=this.dictionaryService.getLoginUser(request);
				shop.setChannel(userApp.getChannel()+"");
			}else{
				shop.setChannel(parameters.get("channel")+"");
			}
            return homeShopService.submitShopNew(parameters, shop);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }


    /**
     * 发布商铺Json
     *
     * @param request
     * @return
     */
    @PostMapping("/getDictionary")
    public ResultObject getShopDictionary(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return homeShopService.getShopDictionary(parameters);
    }

    /**
     * 写字楼房源Json
     *
     * @param request
     * @return
     */
    @PostMapping("/getHomeDictionary")
    public ResultObject getHomeSearch(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return homeShopService.getHomeDictionary(parameters);
    }



}
