/**
 * 
 */
package com.up.zpb.controller.api;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.Office;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import com.up.zpb.vo.enums.OfficeEnum;

/**
 * 
 *      
 * 写字楼    
 * @author PJJ       
 * @version 1.0     
 * @created 2019年7月29日 下午5:19:45
 */
@RestController
@RequestMapping(value = "/office")
public class OfficeController extends AbstractController {
	private static final Logger logger = LoggerFactory.getLogger(OfficeController.class);

	@Autowired
	private OfficeService officeService;
	@Autowired
	RedisBaseDao redisBaseDao;
	@Autowired
	private DictionaryService dictionaryService;
	
	
	@PostMapping("/findList")
	public ResultObject findList(HttpServletRequest request) {
		Map<String,Object> paraMap=new HashMap<String,Object>();
		return this.officeService.findList(paraMap);
    }
	
	/**
	 * 写字楼出售主页-搜索条件
	 * 区域-面积-总价-类型
	 * @param request
	 * @return
	 */
	@PostMapping("/findOfficeSaleSearch")
	public Map<String, Object> findOfficeSaleSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【findOfficeSaleSearch()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "2");
			resultObject=this.officeService.findOfficeSaleSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findOfficeSaleSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	@PostMapping("/selectOfficePage")
	public ResultObject selectOfficePage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【selectOfficePage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		parameters.put("sortColumn", "1");
		resultObject= this.officeService.selectOfficePage(parameters);
		logger.info("【selectOfficePage()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	/**
	 * 推荐写字楼 
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/selectHotOffice")
	public ResultObject selectHotOffice(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【selectHotOffice()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("typeSale"), "typeSale")
		.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		parameters.put("rentType", parameters.get("typeSale"));
		parameters.remove("typeSale");
		resultObject=this.officeService.selectHotOffice(parameters);
		logger.info("【selectHotOffice()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 写字楼出租-搜索条件
	       区域-面积-日租-类型   
	 * @param request
	 * @return
	 */
	@PostMapping("/findOfficeRentSearch")
	public Map<String, Object> findOfficeRentSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findOfficeRentSearch()开始=========="+parameters+"】");
		try {
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "2");
			resultObject=this.officeService.findOfficeRentSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findOfficeRentSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	
	/**
	 * 写字楼新盘-搜索条件
	        区域-均价-类型
	 * @param request
	 * @return
	 */
	@PostMapping("/findOfficeNewSearch")
	public Map<String, Object> findOfficeNewSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【findOfficeNewSearch()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "2");
			resultObject=this.officeService.findOfficeNewSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findOfficeNewSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	@PostMapping("/findProjectDetail")
	public Map<String, Object> pcOfficeDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【findProjectDetail()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("projectId"), "projectId")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=this.officeService.pcOfficeDetail(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findProjectDetail()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	@PostMapping("/appOfficeDetail")
	public Map<String, Object> appOfficeDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【appProjectDetail()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("projectId"), "projectId")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=this.officeService.appOfficeDetail(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【appProjectDetail()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	
	
	/**
	 * 我发布的写字楼 app
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findMyPublishOfficePage")
	public ResultObject findMyPublishOfficePage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findMyPublishOfficePage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.put(parameters.get("agentId"), "agentId")
		/*.put(parameters.get("auditStatus"), "auditStatus")*/
		.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.officeService.findMyPublishOfficePage(parameters);
		logger.info("【findMyPublishOfficePage()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 我跟进的写字楼
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findMyFollowOfficePage")
	public ResultObject findMyFollowOfficePage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findMyPublishOfficePage()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance() 
			.put(parameters.get("pageSize"), "pageSize")
			.put(parameters.get("pageNum"), "pageNum")
			.put(parameters.get("agentId"), "agentId")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.officeService.findMyFollowOfficePage(parameters);
		logger.info("【findMyFollowOfficePage()结束=========="+resultObject+"】");
		return resultObject;
	}	
	
	
	/**
	 * 房源发布-写字楼   
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/auth/publishOffice")
	public ResultObject publishOffice(HttpServletRequest request,Office entity) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【publishOffice()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("agentId"), "agentId")
			.put(parameters.get("type"), "type")
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("businessAreaId"), "businessAreaId")
			.put(parameters.get("realAddress"), "realAddress")
			//.put(parameters.get("name"), "name")
			.put(parameters.get("developer"), "developer")
			.put(parameters.get("singleFamily"), "singleFamily")
			//.put(parameters.get("floorCurrent"), "floorCurrent")
			//.put(parameters.get("floorTotal"), "floorTotal")
			.put(parameters.get("buildArea"), "buildArea")
			//.put(parameters.get("station1"), "station1")
			//.put(parameters.get("station2"), "station2")
			//.put(parameters.get("decorate"), "decorate")
			//.put(parameters.get("register"), "register")
			//.put(parameters.get("separate"), "separate")
			//.put(parameters.get("matchArr"), "matchArr")
			//.put(parameters.get("labelArr"), "labelArr")
			//.put(parameters.get("unitPrice"), "unitPrice")
			//.put(parameters.get("feeProperty"), "feeProperty")
			//.put(parameters.get("imgs"), "imgs")
			//.put(parameters.get("imgPaper"), "imgPaper")
			//.put(parameters.get("introduce"), "introduce")
			.put(parameters.get("supportProfile"), "supportProfile")
			//.put(parameters.get("entrustPaper"), "entrustPaper")
			//.put(parameters.get("commission"), "commission")
			//.put(parameters.get("feeService"), "feeService")
			//.put(parameters.get("expired"), "expired")
			//.put(parameters.get("linkman"), "linkman")
			//.put(parameters.get("phone"), "phone")
			.put(parameters.get("rentType"), "rentType")
			.put(parameters.get("commission"), "commission")
			//.put(parameters.get("commissionType"), "commissionType") 配合appV2.0上线暂时去掉必填校验
			.checkParameter();
			
			if(OfficeEnum.TypeSale.RENT.getValue().equals(parameters.get("rentType")+"") || OfficeEnum.TypeSale.NEWS_RENT.getValue().equals(parameters.get("rentType")+"")){
				//出租必填参数校验
				CheckParametersUtil.getInstance()
				.put(parameters.get("dailyRent"), "dailyRent")
				.checkParameter();
			}
			//渠道 优先从参数里取
			if(ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
				UserApp userApp=this.dictionaryService.getLoginUser(request);
				entity.setChannel(userApp==null?"":userApp.getChannel()+"");
			}else{
				entity.setChannel(parameters.get("channel")+"");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.officeService.publishOffice(parameters,entity);
		logger.info("【publishOffice()结束=========="+resultObject+"】");
		return resultObject;
	}

	/**
	 * 个人管理-跟进的写字楼
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/selectOfficeManager")
	public ResultObject selectOfficeManager(HttpServletRequest request) throws Exception {
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【OfficeController】【selectOfficeManager()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
					.put(parameters.get("projectType"), "projectType")
					.put(parameters.get("type"), "type")
					.put(parameters.get("pageNum"), "pageNum")
					.put(parameters.get("pageSize"), "pageSize")
					.put(parameters.get("agentId"), "agentId")
					.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.officeService.selectOfficeManager(parameters);
		logger.info("【OfficeController】【selectOfficeManager()结束=========="+resultObject+"】");
		return resultObject;
	}


	/**
	 * 下架
	 */
	@PostMapping("/officeOut")
	public  ResultObject officeOut(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("id"), "id")
			.put(parameters.get("onlineStatus"), "onlineStatus")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject= officeService.officeOut(parameters);
		return resultObject;
	}

	
	
	@PostMapping("/updatePublishOffice")
	public ResultObject updatePublishOffice(HttpServletRequest request,Office entity) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【updatePublishOffice()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("agentId"), "agentId")
			.put(parameters.get("type"), "type")
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("businessAreaId"), "businessAreaId")
			.put(parameters.get("realAddress"), "realAddress")
			.put(parameters.get("developer"), "developer")
			.put(parameters.get("singleFamily"), "singleFamily")
			.put(parameters.get("buildArea"), "buildArea")
			.put(parameters.get("supportProfile"), "supportProfile")
			.put(parameters.get("rentType"), "rentType")
			.put(parameters.get("commission"), "commission")
			.checkParameter();
			if(OfficeEnum.TypeSale.RENT.getValue().equals(parameters.get("rentType")+"") || OfficeEnum.TypeSale.NEWS_RENT.getValue().equals(parameters.get("rentType")+"")){
				//出租必填参数校验
				CheckParametersUtil.getInstance()
				.put(parameters.get("dailyRent"), "dailyRent")
				.checkParameter();
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.officeService.updatePublishOffice(parameters,entity);
		logger.info("【updatePublishOffice()结束=========="+resultObject+"】");
		return resultObject;
	}
	

}
