/**
 * 
 */
package com.up.zpb.controller.api;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.OrderService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import com.up.zpb.vo.fourhundred.Answered;

/**
 * 认购订单表  
 * @author PJJ       
 * @version 1.0     
 * @created 2019年8月2日 下午7:39:45
 */
@RestController
@RequestMapping(value = "/order")
public class OrderController extends AbstractController {
	private static final Logger logger = LoggerFactory.getLogger(OrderController.class);

	@Autowired
	private OrderService orderService;
	@Autowired
	private DictionaryService dictionaryService;
	@Autowired
	private FourHundredService fourHundredService;
	
	
	/**
	 * app-到访，走节点
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/submitOrder")
	public ResultObject submitOrder(HttpServletRequest request,ProjectOrder project) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【submitOrder()开始==========入参："+parameters+"】");
		try{
			//首次到访
			CheckParametersUtil.getInstance()
			.put(parameters.get("projectId"), "projectId")
			.put(parameters.get("projectType"), "projectType")
			.put(parameters.get("orderStatus"), "orderStatus")
			.put(parameters.get("agentId"), "agentId")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		
		UserApp  user=this.dictionaryService.getLoginUser(request);
		if(user!=null){
			project.setChannel(user.getChannel()+"");
		}
		
		resultObject=this.orderService.submitOrder(parameters,project);
		logger.info("【submitOrder()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 认购-签约-结佣-完成
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/exchangeOrder")
	public ResultObject exchangeOrder(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【exchangeOrder()开始==========入参："+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("orderNo"), "orderNo")
			.put(parameters.get("orderStatus"), "orderStatus")
			.checkParameter();
			
			UserApp loginUser=this.dictionaryService.getLoginUser(request);
			if(loginUser==null){
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("必须登录！");
				return resultObject; 
			}
			parameters.put("loginUserId", loginUser.getId());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		
		resultObject=this.orderService.exchangeOrder(parameters);
		logger.info("【exchangeOrder()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	/**
	 * 查看项目的联系人电话
	 * @param request
	 * @param project
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/seeProjectPhone")
	public ResultObject seeProjectPhone(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【seeProjectPhone()开始==========入参："+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("projectId"), "projectId")
			.put(parameters.get("projectType"), "projectType")
			.put(parameters.get("agentId"), "agentId")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		UserApp  loginUser=this.dictionaryService.getLoginUser(request);
		if(loginUser!=null && ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
			//如果参数没传，才取token里面的。
			parameters.put("channel", loginUser.getChannel()+"");
		}
		
		resultObject=this.orderService.seeProjectPhone(parameters,loginUser);
		logger.info("【seeProjectPhone()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 单独打电话，不记录联系次数
	 * @param request
	 * @param project
	 * @param customerPhone  --非发布房源的人的手机号
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/processAllCallOnly")
	public ResultObject processAllCallOnly(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【processAllCallOnly()开始==========入参："+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("projectId"), "projectId")
			.put(parameters.get("projectType"), "projectType")
			.put(parameters.get("customerTel"), "customerTel")
			.put(parameters.get("publishTel"), "publishTel")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		UserApp  loginUser=this.dictionaryService.getLoginUser(request);
		if(loginUser!=null && ObjectHelpUtils.isMyNull(parameters.get("channel")+"")){
			//如果参数没传，才取token里面的。
			parameters.put("channel", loginUser.getChannel()+"");
		}
		resultObject=this.orderService.processAllCall(parameters.get("projectId")+"", parameters.get("projectType")+"", 
				parameters.get("customerTel")+"", parameters.get("publishTel")+"",parameters.get("channel")+"",loginUser);
		logger.info("【processAllCallOnly()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	
	@PostMapping("/taskBinding")
	public void taskBinding(HttpServletRequest request) throws Exception{
		this.fourHundredService.taskBinding(); 
	}
	@PostMapping("/taskAnsweredList")
	public void taskAnsweredList(HttpServletRequest request) {
		this.fourHundredService.taskAnsweredList(); 
		this.fourHundredService.taskNoAnsweredList();
	}
	@PostMapping("/batchGuHuaToDept")
	public void batchGuHuaToDept(HttpServletRequest request) throws Exception{
		this.fourHundredService.batchGuHuaToDept(); 
	}
	
	@PostMapping("/bangDingOne")
	public ResultObject taskBindingOne(HttpServletRequest request) {
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("linkPhone"), "linkPhone")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		this.fourHundredService.bangDingOne(parameters.get("linkPhone")+""); 		
		return resultObject;
	}
	
	
}
