package com.up.zpb.controller.api;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.RecommendUserService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/***
 * 推荐朋友控制器
 */
@RestController
@RequestMapping("/recommend")
public class RecommendUserController extends AbstractController {

    private static final Logger logger = LoggerFactory.getLogger(RecommendUserController.class);

    @Autowired
    private RecommendUserService recommendUserService;

    /**
     * 推荐朋友
     * 渠道：platForm 0-PC_WEB;1-IOS;2-Android;3-M_WEB
     *
     * @param request
     * @return
     */
    @PostMapping("/friendRegister")
    public ResultObject friendRegister(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("cityId"), "cityId")
                    .put(parameters.get("userId"), "userId")
                    .put(parameters.get("phone"), "phone")
                    .put(parameters.get("validCode"), "validCode")
                    .put(parameters.get("platForm"), "platForm")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return recommendUserService.friendRegister(parameters);
    }

    /**
     * 已推荐朋友列表
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/friendList")
    public ResultObject friendList(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        try {
            Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
            Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
            Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
            resultObject.put("totalCount", startPage.getTotal());
            resultObject = recommendUserService.friendList(parameters);
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

}
