package com.up.zpb.pay.wx;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.InterruptedIOException;
import java.io.PrintWriter;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLConnection;
import java.net.UnknownHostException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.net.ssl.SSLException;
import javax.net.ssl.SSLHandshakeException;

import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.NoHttpResponseException;
import org.apache.http.client.HttpRequestRetryHandler;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.protocol.HttpClientContext;
import org.apache.http.conn.ConnectTimeoutException;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.impl.conn.PoolingHttpClientConnectionManager;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;

/**
 * HttpClient工具类
 *
 * @author pjj
 * @Description 2019年9月25日
 */
public class ApacheHttpTool {

	private static final Logger logger = LoggerFactory.getLogger(ApacheHttpTool.class);

	// client 对象
	private static CloseableHttpClient httpClient;
	// 连接池
	private static PoolingHttpClientConnectionManager pool;
	// 请求默认配置
	private static RequestConfig requestConfig;

	/** 默认超时参数 */
	// 连接超时时间
	private static final int CONNECTION_TIMEOUT = 1 * 1000;
	// 请求等待返回超时时间
	private static final int SOCKET_TIMEOUT = 2 * 1000;
	// 连接池连接占满时等待超时时间
	private static final int CONN_MANAGER_TIMEOUT = 500;

	/** 调用失败重试次数 */
	private static final int count = 1;

	/** 默认连接池参数 */
	// 连接池最大连接数
	private static final int MAX_TOTAL = 300;
	// 同一主机的最大连接数
	private static final int MAX_PER_ROUTE = 200;

	static {
		pool = new PoolingHttpClientConnectionManager();
		pool.setMaxTotal(MAX_TOTAL);
		pool.setDefaultMaxPerRoute(MAX_PER_ROUTE);

		requestConfig = RequestConfig.custom().setConnectTimeout(CONNECTION_TIMEOUT).setSocketTimeout(SOCKET_TIMEOUT)
				.setConnectionRequestTimeout(CONN_MANAGER_TIMEOUT).build();

		httpClient = HttpClients.custom().setConnectionManager(pool).setDefaultRequestConfig(requestConfig)
				.setRetryHandler(new MyHttpRequestRetryHandler()).build();
	}
	
	
	
    
	/**
	 * 发送post json请求
	 *
	 * @param url
	 * @param headers
	 * @param params
	 * @return
	 */
	public static JSONObject httpPostWithJson(String url, Map<String, String> headers, Object params) {
		System.out.println("【httpPostWithJson====请求地址："+url+"】");
		//System.out.println("【httpPostWithJson====请求头："+JSON.toJSONString(headers)+"】");
		System.out.println("【httpPostWithJson====请求参数："+params+"】");
		JSONObject   resultJson=new JSONObject();
		HttpPost post = new HttpPost(url);
		if (requestConfig != null) {
			post.setConfig(requestConfig);
		}
		// 构造消息头
		//post.setHeader("Content-type", "application/json; charset=utf-8");
		List<String> headerKey = new ArrayList<String>(headers.keySet());
		for (String key : headerKey) {
			post.setHeader(key, headers.get(key));
		}
		// 构建消息实体
		StringEntity entity = new StringEntity(JSON.toJSONString(params), Charset.forName("UTF-8"));
		//entity.setContentEncoding("UTF-8");
		// 发送Json格式的数据请求
		//entity.setContentType("application/json");
		post.setEntity(entity);
		
		try {
			HttpResponse response = httpClient.execute(post);
			String responseBody = EntityUtils.toString(response.getEntity());
			// 检验返回码
			int statusCode = response.getStatusLine().getStatusCode();
			if (statusCode != HttpStatus.SC_OK) {
				resultJson.put("code", "httpFail");
				resultJson.put("msg", "成功码非200，responseBody:"+responseBody);
			}
			return JSONObject.parseObject(responseBody);
		} catch (Exception e) {
			resultJson.put("code", "httpFail");
			resultJson.put("msg", "远程调用失败，请检查http地址【"+url+"】是否正确。>>>"+e.getMessage());
			e.printStackTrace();
		} finally {
			if (post != null) {
				post.releaseConnection();
			}
		}
		System.out.println("【httpPostWithJson====返回报文："+resultJson+"】");
		return resultJson;
	}

	



	/**
	 * 设置重试
	 */
	static class MyHttpRequestRetryHandler implements HttpRequestRetryHandler {

		@Override
		public boolean retryRequest(IOException exception, int executionCount, HttpContext context) {
			if (executionCount > count) { // 超过重试次数，就放弃
				return false;
			}
			if (exception instanceof NoHttpResponseException) {// 没有响应, 重试
				logger.info("没有响应，重试1次");
				return true;
			} else if (exception instanceof ConnectTimeoutException) {// 连接超时,
																		// 重试
				logger.info("连接超时，重试1次");
				return true;
			} else if (exception instanceof SocketTimeoutException) {// 连接或读取超时,
																		// 重试
				logger.info("连接或读取超时，重试1次");
				return true;
			} else if (exception instanceof UnknownHostException) {// 找不到服务器
				logger.info("找不到服务器，重试1次");
				return true;
			} else if (exception instanceof SSLHandshakeException) {// 本地证书异常
				return false;
			} else if (exception instanceof InterruptedIOException) {// 被中断
				return false;
			} else if (exception instanceof SSLException) {// SSL异常
				return false;
			} else {
				logger.error("未记录的请求异常：" + exception.getClass());
			}
			HttpClientContext clientContext = HttpClientContext.adapt(context);
			HttpRequest request = (HttpRequest) clientContext.getRequest();
			// 如果请求是幂等的，则重试
            if (!(request instanceof HttpEntityEnclosingRequest)) return true;
            return false;
		}
	}

	
	
	 /**
     * 向指定 URL 发送POST方法的请求
     * 
     * @param url
     *            发送请求的 URL
     * @param param
     *            请求参数，请求参数应该是 name1=value1&name2=value2 的形式。
     * @return 所代表远程资源的响应结果
     */
    public static JSONObject httpPostWithString(String url, String param) {
    	System.out.println("【请求参数：>>>>>>>>>"+url+"?"+param+"】");
        PrintWriter out = null;
        BufferedReader in = null;
        String result = "";
        try {
            URL realUrl = new URL(url);
            // 打开和URL之间的连接
            URLConnection conn = realUrl.openConnection();
            // 设置通用的请求属性
            conn.setRequestProperty("accept", "*/*");
            conn.setRequestProperty("connection", "Keep-Alive");
            conn.setRequestProperty("user-agent",
                    "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            // 发送POST请求必须设置如下两行
            conn.setDoOutput(true);
            conn.setDoInput(true);
            // 获取URLConnection对象对应的输出流
            out = new PrintWriter(conn.getOutputStream());
            // 发送请求参数
            out.print(param);
            // flush输出流的缓冲
            out.flush();
            // 定义BufferedReader输入流来读取URL的响应
            in = new BufferedReader(
                    new InputStreamReader(conn.getInputStream()));
            String line;
            while ((line = in.readLine()) != null) {
                result += line;
            }
        } catch (Exception e) {
            System.out.println("发送 POST 请求出现异常！"+e);
            e.printStackTrace();
        }
        //使用finally块来关闭输出流、输入流
        finally{
            try{
                if(out!=null){
                    out.close();
                }
                if(in!=null){
                    in.close();
                }
            }
            catch(IOException ex){
                ex.printStackTrace();
            }
        }
        JSONObject   jsonResult = JSONObject.parseObject(result);
        System.out.println("【请求结果：>>>>>>>>>"+jsonResult+"】");
        return jsonResult;
    }
    
    
    
    
    
}
