package com.up.zpb.service.customer;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.customer.CustomerMapper;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ProjectOrderService;
import com.up.zpb.service.impl.OfficeServiceImpl;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.Areas;
import com.up.zpb.vo.Customer;
import com.up.zpb.vo.Dictionary;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.PublishCustomerVo;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.enums.CustomerEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.fourhundred.IvrKeyShow;

@Service
public class CustomerServiceImpl implements CustomerService {

    private static final Logger logger = LoggerFactory.getLogger(CustomerServiceImpl.class);

    @Autowired
    private CustomerMapper customerMapper;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private AreasMapper areasMapper;
    @Autowired
    private BusinessAreaMapper businessAreaMapper;
    @Autowired
    private ProjectOrderService projectOrderService;
    @Autowired
    private ProjectOrderMapper projectMapper;
    @Autowired
    private ProjectOrderMapper projectOrderMapper;
    @Autowired
    private OfficeServiceImpl officeServiceImpl;
    @Autowired
    private OfficeService officeService;
    @Autowired
    private RegionsMapper regionsMapper;
    @Autowired
    private FourHundredService fourHundredService;

    @Override
    public ResultObject submit(Map<String, Object> parameters, Customer customer) {
        ResultObject resultObject = new ResultObject();
        customer.setCreateTime(new Date());
        customer.setStatus("0");
        customer.setType(String.valueOf(parameters.get("entrustOne")));
        if ("1".equals(customer.getType()) || "5".equals(customer.getType())) {
            customer.setRentType("1");//出租
        } else if ("0".equals(customer.getType()) || "4".equals(customer.getType())) {
            customer.setRentType("2");//出售
        } else if ("3".equals(customer.getType()) || "7".equals(customer.getType())) {
            customer.setRentType("3");//新盘出租
        } else if ("2".equals(customer.getType()) || "6".equals(customer.getType())) {
            customer.setRentType("4");//新盘出售
        }
        if ("1".equals(customer.getType()) || "3".equals(customer.getType()) || "5".equals(customer.getType()) || "7".equals(customer.getType())) {
            customer.setRequestType("1");//求租 1,3,5,7
        } else {
            customer.setRequestType("2");//求购
        }
        if ("0".equals(customer.getType()) || "1".equals(customer.getType()) || "2".equals(customer.getType()) || "3".equals(customer.getType())) {
            //写字楼
            customer.setIfShop("2");
        } else {
            customer.setIfShop("1");//商铺
        }
        try {
            customer.setCreateId(String.valueOf(parameters.get("authentication")));
            customer.setStatus("0");
            customer.setType(String.valueOf(parameters.get("entrustOne")));
            //计算预算并存储
            if (Integer.valueOf(customer.getEntrustOne()) % 2 == 0) {
                //求购 单价和意向面积
                customer.setBudgetMin(String.valueOf(customer.getPriceMin() * Double.valueOf(customer.getWantAreaMin())));
                customer.setBudgetMax(String.valueOf(customer.getPriceMax() * Double.valueOf(customer.getWantAreaMax())));
            } else {
                //求租 意向面积和日租金
                customer.setBudgetMin(String.valueOf((customer.getPriceDayMin() * Double.valueOf(customer.getWantAreaMin()) * 365) / 12));
                customer.setBudgetMax(String.valueOf((customer.getPriceDayMax() * Double.valueOf(customer.getWantAreaMax()) * 365) / 12));
            }
            customerMapper.saveAll(customer);
            resultObject.setCode(Constant.CODE_SUCCESS);
            resultObject.setMessage("成功");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject getEntrust(String cityId) {
        ResultObject resultObject = new ResultObject();
        List<Map<String, Object>> parent = dictionaryService.selectMapByParentKey("532");
        List<Map<String, Object>> son1 = dictionaryService.selectMapByParentKey("510");
        List<Map<String, Object>> son2 = dictionaryService.selectMapByParentKey("133");
        for (int i = 0; i < parent.size(); i++) {
            if (i <= 3) {
                parent.get(i).put("childrenList", son1);
            } else {
                parent.get(i).put("childrenList", son2);
            }
        }
        resultObject.put("typeList", parent);
        List<Map<?, ?>> areas = Lists.newArrayList();
        areasMapper.selectByParentId(cityId).forEach(a -> {
            Map<String, Object> c1 = Maps.newHashMap();
            c1.put("id", a.get("id"));
            c1.put("areaName", a.get("area_name"));
            List<Map<?, ?>> childList = Lists.newArrayList();
            businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
                Map<String, Object> c2 = Maps.newHashMap();
                c2.put("childId", ba.get("id"));
                c2.put("childName", ba.get("name"));
                if (!"全部".equals(ba.get("name") + "")) {
                    childList.add(c2);
                }
            });
            c1.put("childList", childList);
            if (!"全部".equals(a.get("area_name") + "")) {
                areas.add(c1);
            }
        });
        resultObject.put("areasList", areas);
        return resultObject;
    }

    @Override
    public ResultObject getListEntrust(String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<?, ?>> areas = Lists.newArrayList();
            Map<String, Object> map = new HashMap<>();
            map.put("id", "");
            map.put("areaName", "全部");
            areas.add(map);
            areasMapper.selectByParentId(cityId).forEach(a -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", a.get("id"));
                c1.put("areaName", a.get("area_name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", ba.get("id"));
                    c2.put("childName", ba.get("name"));
                    if (!"全部".equals(ba.get("name") + "")) {
                        childList.add(c2);
                    }
                });
                c1.put("childList", childList);
                if (!"全部".equals(a.get("area_name") + "")) {
                    areas.add(c1);
                }
            });
            resultObject.put("areasList", areas);
            Map<String, Object> maps = new HashMap<>();
            maps.put("id", "");
            maps.put("name", "全部");
            List<Map<String, Object>> parent = dictionaryService.selectMapByParentKey("532");
            parent.add(0, maps);
            resultObject.put("typeList", parent);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

    @Override
    public ResultObject getSearchCustomer(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        List<Map<String, Object>> resultAll = new ArrayList<>();
        try {
            List<Map<String, Object>> selectCustomer = customerMapper.getSearchCustomer(parameters);
            if (Objects.nonNull(selectCustomer) && selectCustomer.size() != 0) {
                String priceMinStr = StringUtils.EMPTY;
                String priceMaxStr = StringUtils.EMPTY;
                String price = StringUtils.EMPTY;

                for (Map<String, Object> map : selectCustomer) {
                    String want = StringUtils.EMPTY;
                    Map<String, Object> result = new HashMap<>();
                    //面积
                    String wantArea = map.get("want_area_min").toString() + "-" + map.get("want_area_max").toString() + "m²";
                    //委托类型
                    Dictionary search = new Dictionary();
                    search.setdValue(String.valueOf(map.get("entrust_two")));
                    if (map.get("d_name").toString().contains("商铺")) {
                        search.setParentKey(String.valueOf(531));
                        result.put("entrustTwo", dictionaryService.selectParentAndSon(search).getdName());
                    } else {
                        search.setParentKey(String.valueOf(510));
                        result.put("entrustTwo", dictionaryService.selectParentAndSon(search).getdName());
                    }
                    //意向区域
                    String wantRegion[] = String.valueOf(map.get("want_region")).split(",");
                    String wantAreas[] = String.valueOf(map.get("want_area")).split(",");
                    for (int i = 0; i < wantRegion.length; i++) {
                        if (wantRegion.length - i > 1) {
                            want = want + areasMapper.selectById(wantAreas[i]) + "-" + businessAreaMapper.selectByIds(wantRegion[i]) + "、";
                        } else {
                            want = want + areasMapper.selectById(wantAreas[i]) + "-" + businessAreaMapper.selectByIds(wantRegion[i]);
                        }
                    }
                    result.put("id", map.get("id"));
                    result.put("price", getPrice(map));
                    result.put("name", map.get("name"));
                    result.put("commissionDate", "合同签署" + map.get("commission_date") + "天之内");
                    result.put("commission", map.get("commission"));
                    result.put("wantArea", wantArea);
                    result.put("entrustOne", map.get("d_name"));
                    result.put("want", want);
                    resultAll.add(result);
                }
            }
            resultObject.put("data", resultAll);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject getEntrustApp(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();

        try {
            List<Map<?, ?>> areas = Lists.newArrayList();
            areasMapper.selectByParentId(parameters.get("cityId").toString()).forEach(a -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", a.get("id"));
                c1.put("name", a.get("area_name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", ba.get("id"));
                    c2.put("childName", ba.get("name"));
                    childList.add(c2);
                });
                c1.put("childList", childList);
                areas.add(c1);
            });
            resultObject.put("areasList", areas);
            List<Map<String, Object>> parent = new ArrayList<>();
            if (parameters.get("type").toString().equals("2")) {
                parent = dictionaryService.selectMapByParentKey("133");
            } else {
                parent = dictionaryService.selectMapByParentKey("510");
            }
            Map<String, Object> map = new HashMap<>();
            map.put("name", "请选择");
            map.put("id", -1);
            parent.add(0, map);
            resultObject.put("typeList", parent);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

    /**
     * 客源详情
     *
     * @param parameters
     * @return
     */
    @Override
    public ResultObject getDetail(Map<String, Object> parameters) {
        String data = "yyy-MM-dd";
        SimpleDateFormat sdf = new SimpleDateFormat(data);
        ResultObject resultObject = new ResultObject();
        resultObject.put("myRoleType", "2");//发布人为1  其他的经纪人都为2   普通用户为3
        resultObject.put("nodes", "");
        resultObject.put("recordList", "");
        resultObject.put("renGouList", "");
        resultObject.put("signList", "");
        resultObject.put("jieYongList", "");
        resultObject.put("completeList", "");

        Map<String, Object> result = new HashMap<>();
        String want = StringUtils.EMPTY;
        try {
            String projectId = parameters.get("projectId") + "";
            String projectType = parameters.get("projectType") + "";
            Map<String, Object> map = new HashMap<>();
            map = customerMapper.getDetail(parameters);
            //意向区域
            String wantRegion[] = String.valueOf(map.get("want_region")).split(",");
            String wantAreas[] = String.valueOf(map.get("want_area")).split(",");
            for (int i = 0; i < wantRegion.length; i++) {
                if (wantRegion.length - i > 1) {
                    want = want + areasMapper.selectById(wantAreas[i]) + "-" + businessAreaMapper.selectByIds(wantRegion[i]) + "、";
                } else {
                    want = want + areasMapper.selectById(wantAreas[i]) + "-" + businessAreaMapper.selectByIds(wantRegion[i]);
                }
            }

            //基本数据信息
            result.put("price", getPrice(map));
            result.put("want", want);
            result.put("createTime", sdf.format(map.get("create_time")));
            result.put("commission", map.get("commission"));
            result.put("name", map.get("name"));
            result.put("commissionDate", "合同签署" + map.get("commission_date") + "天之内");
            result.put("account", map.get("account"));
            result.put("remarks", map.get("remarks"));
            result.put("wantType", map.get("d_name"));
            result.put("wantArea", map.get("want_area_min").toString() + "-" + map.get("want_area_max").toString() + "m²");
            String sjType=this.dictionaryService.findByKey("549");
			if("2".equals(sjType)){
				//查找外显号
				IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(map.get("linkPhone")+"");
				result.put("linkPhone", ivrEn.getIvrAll());
			}else{
				result.put("linkPhone", map.get("linkPhone"));
			}
			result.put("createPhone", map.get("createPhone"));//经纪人手机号码
            result.put("createName", map.get("createName"));//经纪人姓名
            resultObject.put("data", result);

            //节点：
            ProjectOrder projectEn = this.projectMapper.findProjectEntity(parameters);
            if (projectEn != null) {
                if (Objects.nonNull(projectEn.getOrderStatus())) {
                    resultObject.put("nodes", projectEn.getOrderStatus());//3-到访 4-认购 5-签约 6-结佣 7-终止（完成交易）
                }
            } else {
                resultObject.put("nodes", "2");
            }

            //跟进记录-列表
        	//客源控制按钮
			String ifShow=this.projectOrderService.jsonCustomerOnlyOne(parameters.get("projectId")+"","3");
			resultObject.put("show", ifShow);
			//判断是否为发布人
			this.jsonRoleType(resultObject, projectId, projectType, parameters.get("loginUserId") + "", map.get("create_id") + "");
            officeServiceImpl.followLog(projectId, projectType, parameters.get("loginUserId") + "", resultObject);


        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }


    @Override
    public ResultObject saveAll(Customer customer) {
        ResultObject resultObject = new ResultObject();
        customer.setCreateTime(new Date());
        customer.setEntrustOne(customer.getType());
        customer.setEntrustTwo(customer.getShopType());
        if ("1".equals(customer.getType()) || "5".equals(customer.getType())) {
            customer.setRentType("1");//出租
        } else if ("0".equals(customer.getType()) || "4".equals(customer.getType())) {
            customer.setRentType("2");//出售
        } else if ("3".equals(customer.getType()) || "7".equals(customer.getType())) {
            customer.setRentType("3");//新盘出租
        } else if ("2".equals(customer.getType()) || "6".equals(customer.getType())) {
            customer.setRentType("4");//新盘出售
        }
        if ("1".equals(customer.getType()) || "3".equals(customer.getType()) || "5".equals(customer.getType()) || "7".equals(customer.getType())) {
            customer.setRequestType("1");//求租 1,3,5,7
        } else {
            customer.setRequestType("2");//求购
        }
        if ("0".equals(customer.getType()) || "1".equals(customer.getType()) || "2".equals(customer.getType()) || "3".equals(customer.getType())) {
            //写字楼
            customer.setIfShop("2");
        } else {
            customer.setIfShop("1");//商铺
        }
        try {
            //计算预算并存储
            if (Integer.valueOf(customer.getType()) % 2 == 0) {
                //求购 单价和意向面积
                customer.setBudgetMin(String.valueOf(customer.getPriceMin() * Double.valueOf(customer.getWantAreaMin())));
                customer.setBudgetMax(String.valueOf(customer.getPriceMax() * Double.valueOf(customer.getWantAreaMax())));
            } else {
                //求租 意向面积和日租金
                //TODO 判断priceMin是否有值
                if (Objects.nonNull(customer.getPriceMin())){
                   customer.setPriceDayMin(customer.getPriceMin());
                   customer.setPriceDayMax(customer.getPriceMax());
                }
                customer.setBudgetMin(String.valueOf((customer.getPriceDayMin() * Double.valueOf(customer.getWantAreaMin()) * 365) / 12));
                customer.setBudgetMax(String.valueOf((customer.getPriceDayMax() * Double.valueOf(customer.getWantAreaMax()) * 365) / 12));
            }

            customerMapper.saveAll(customer);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }


    /**
     * 经纪人-我的客源列表
     *
     * @param param
     * @return
     */
    @Override
    public ResultObject getMySourceList(Map<String, Object> param) {
        ResultObject resultObject = new ResultObject();
        try {
            Integer pageNum = Integer.valueOf((String) param.get("pageNum"));
            Integer pageSize = Integer.valueOf((String) param.get("pageSize"));
            PageHelper.startPage(pageNum, pageSize, true);
            PageInfo<Map<String, Object>> mapPageInfo = new PageInfo<>(this.customerMapper.getMySourceList(param));
            List<Map<String, Object>> list = mapPageInfo.getList();
            if (list != null && list.size() > 0) {
                for (Map<String, Object> temp : list) {
                    //获取orderStatus数值对应的name
                    if (null != temp.get("orderStatus")) {
                        ProjectEnum.OrderStatus orderStatus = ProjectEnum.OrderStatus.codeOf(temp.get("orderStatus").toString());
                        temp.put("orderStatusStr", orderStatus.getName());
                    }
                    //获取客户类型type对应name
                    if (null != temp.get("type")) {
                        CustomerEnum.CustomerType type = CustomerEnum.CustomerType.codeOf(temp.get("type").toString());
                        temp.put("typeStr", type.getName());
                    }
                }
            }
            resultObject.put("list", list);
            resultObject.put("totalCount", mapPageInfo.getTotal());
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject selectPage(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String, Object>> selectCustomer = customerMapper.selectPage(parameters);
            resultObject.put("data", selectCustomer);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }


    /**
     * 单价处理
     *
     * @param map
     * @return
     */
    public String getPrice(Map<String, Object> map) {
        if (Objects.nonNull(map.get("price_min"))) {
            String priceMinStr = StringUtils.EMPTY;
            String priceMaxStr = StringUtils.EMPTY;
            BigDecimal priceMin = new BigDecimal(map.get("price_min").toString());
            if (Double.valueOf(String.valueOf(map.get("price_min"))) > 9999) {
                priceMinStr = "万/月";
                priceMin = priceMin.divide(new BigDecimal(10000), 2, BigDecimal.ROUND_HALF_UP);
            } else {
                priceMinStr = "元/月";
            }
            //最大单价
            BigDecimal priceMax = new BigDecimal(map.get("price_max").toString());
            if (Double.valueOf(String.valueOf(map.get("price_max"))) > 9999) {
                priceMaxStr = "万/月";
                priceMax = priceMax.divide(new BigDecimal(10000), 2, BigDecimal.ROUND_HALF_UP);
            } else {
                priceMaxStr = "元/月";
            }
            return priceMin + priceMinStr + "-" + priceMax + priceMaxStr;
        }else{
            return map.get("price_day_min") + "元-" + map.get("price_day_max") + "元";
        }

    }

    /**
     * 无限一二级菜单构造
     *
     * @return
     */
    private static Map<String, Object> getUnlimited() {
        Map<String, Object> topMap = Maps.newHashMap();
        topMap.put("id", -1);
        topMap.put("areaName", "请选择区域");
        List<Map<?, ?>> childList = Lists.newArrayList();
        Map<String, Object> childMap = Maps.newHashMap();
        childMap.put("childId", -1);
        childMap.put("childName", "请选择商圈");
        childList.add(childMap);
        topMap.put("childList", childList);
        return topMap;
    }

    public void jsonRoleType(ResultObject resultObject, String projectId, String projectType, String loginUserId, String agentId) {
        //如果已经生成了订单，则查询订单编号
        ProjectOrder order = this.projectOrderService.ifHaveCustomerProjectOrder(projectId, projectType, loginUserId);
        resultObject.put("orderNo", order == null ? "" : order.getOrderNo());
        //节点：
        resultObject.put("nodes", this.getNodeName(projectId, projectType, loginUserId));
        //myRoleType
        if (loginUserId.equals(agentId)) {
            resultObject.put("myRoleType", "1");//我是房源
        } else {
            resultObject.put("myRoleType", "2");//我是客源
        }
    }

    public String getNodeName(String projectId, String projectType, String agentId) {
        if (Objects.nonNull(agentId)) {
            Map<String, Object> paraMap = new HashMap<String, Object>();
            paraMap.put("projectId", projectId);
            paraMap.put("projectType", projectType);
            paraMap.put("agentId", agentId);
            ProjectOrder projectEn = this.projectOrderMapper.findProjectEntity(paraMap);
            if (Objects.nonNull(projectEn)) {
                return projectEn.getOrderStatus();
            } else {
                return "2";
            }
        } else {
            return "2";//普通用户登录
        }
    }


    @Override
    public ResultObject findMyFollowCustomerPage(Map<String, Object> paraMap) {
        ResultObject resultObject = new ResultObject();
        try {
            //this.analysisLeftRight(paraMap);// 解析搜索条件id为区间
            Integer pageNum = Integer.valueOf((String) paraMap.get("pageNum"));
            Integer pageSize = Integer.valueOf((String) paraMap.get("pageSize"));
            Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
            List<PublishCustomerVo> list = this.customerMapper.findMyFollowCustomerPage(paraMap);
            if (list != null && list.size() > 0) {
                for (PublishCustomerVo temp : list) {
                    this.jsonCustomerMianJi(temp);
                    temp.setSumMyFollowList(this.officeService.getSumFiveStatusList(temp.getId() + "", ProjectEnum.ProjectType.CUSTOMER.getValue(), paraMap.get("agentId") + ""));//联系1人+到访1人+认购1人
                }
            }
            resultObject.put("list", list);
            resultObject.put("totalCount", startPage.getTotal());
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    //格式化面积等字段-客源
    public void jsonCustomerMianJi(PublishCustomerVo temp) {
        if (ProjectEnum.RentType.RENT.getValue().equals(temp.getRentType())
                || ProjectEnum.RentType.NEWS_RENT.getValue().equals(temp.getRentType())) {
            String buildAreaMin = temp.getWantAreaMin();
            String buildAreaMax = temp.getWantAreaMax();
            String dailyMin = temp.getPriceDayMin();
            String dailyMax = temp.getPriceDayMax();
            //月租
            BigDecimal monthRentMin = this.officeService.jsMonthRent(dailyMin, buildAreaMin);
            BigDecimal monthRentMax = this.officeService.jsMonthRent(dailyMax, buildAreaMax);
            temp.setPriceObj(monthRentMin + "-" + monthRentMax + "元/月");
        } else {
            //单价
            temp.setPriceObj(temp.getUnitPriceMin() + "-" + temp.getUnitPriceMax() + "元/㎡");
        }
        Areas areasEn = this.areasMapper.selectProvinceIdByCityId(temp.getAreaId());
        String regionName = this.regionsMapper.findNameById(temp.getRegion());
        if (areasEn != null) {
            temp.setAreaId(areasEn.getAreaname() + "|" + regionName);
        }
        temp.setCommission(temp.getCommission() + "元");
        temp.setMianJi(temp.getWantAreaMin() + "-" + temp.getWantAreaMax() + "㎡");
        temp.setRemarks(temp.getAreaId() + CustomerEnum.RequestType.codeOf(temp.getRequestType()).getName());
    }


    @Override
    public ResultObject findMyPublishCustomerPage(Map<String, Object> paraMap) {
        ResultObject resultObject = new ResultObject();
        try {
            //this.analysisLeftRight(paraMap);//解析搜索条件id为区间
            Integer pageNum = Integer.valueOf((String) paraMap.get("pageNum"));
            Integer pageSize = Integer.valueOf((String) paraMap.get("pageSize"));
            Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
            List<PublishCustomerVo> list = this.customerMapper.findMyPublishCustomerPage(paraMap);
            if (list != null && list.size() > 0) {
                for (PublishCustomerVo temp : list) {
                    this.jsonCustomerMianJi(temp);
                    //我发布的，是统计所有人的联系次数；我跟进的商铺，是统计我自己点击联系的
                    temp.setSumMyFollowList(this.officeService.getSumFiveStatusList(temp.getId() + "", ProjectEnum.ProjectType.CUSTOMER.getValue(), ""));
                }
            }
            resultObject.put("list", list);
            resultObject.put("totalCount", startPage.getTotal());
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    @Override
    public ResultObject selectMyEntrustList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String, Object>> mapList = customerMapper.selectMyEntrustList(parameters);
            for (Map<String, Object> item : mapList) {
                if (String.valueOf(item.get("types")).contains("求租")) {
                    item.put("status", 1);
                } else {
                    item.put("status", 2);
                }
            }
            resultObject.put("data", mapList);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }

    }

}
