package com.up.zpb.service.impl;

import java.text.DecimalFormat;
import java.util.Date;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.google.common.collect.Maps;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.CrmCustomerMapper;
import com.up.zpb.service.AsynSaveCrmService;
import com.up.zpb.vo.CrmCustomer;
import com.up.zpb.vo.ShopRenting;

@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class AsynSaveCrmServiceImpl implements AsynSaveCrmService{
	
	@Autowired
	private CrmCustomerMapper crmCustomerMapper;
	
	@Autowired
	private AreasMapper areasMapper;
	
	@Autowired
	private BusinessAreaMapper businessAreaMapper;

	@Async
	public void saveCrm(ShopRenting sr) {
		CrmCustomer cc = new CrmCustomer();
		cc.setPhone(sr.getPhone());// 手机号码
		cc.setName(sr.getName());// 姓名
		cc.setAreaLower(sr.getAreaLower());// 面积下限
		cc.setAreaUpper(sr.getAreaUpper());// 面积上限
		cc.setMonthlyRentLower(sr.getMonthlyRentLower());// 租金下限
		cc.setMonthlyRentUpper(sr.getMonthlyRentUpper());// 租金上限
		Map<String, Object> parameters= Maps.newHashMap();
		parameters.put("businessCircleId", sr.getBusinessAreaId());
		Map<String, Object> businessArea = businessAreaMapper.selectById(parameters);
		cc.setBusinessArea(areasMapper.selectByCityId(sr.getAreaId().toString()).get(0)
				+ businessArea.get("name").toString());
		String type = sr.getType().toString();
		// 商铺类型
		if (type.equals("0")) { // 商业街商铺
			cc.setBusinessStreet(true);
		} else if (type.equals("1")) {// 社区商业
			cc.setCommunityBusiness(true);
		} else if (type.equals("2")) {// 写字楼配套
			cc.setOfficeBuilding(true);
		} else if (type.equals("3")) {// 市场
			cc.setMarket(true);
		} else if (type.equals("4")) {// 百货购物中心
			cc.setShoppingCenter(true);
		} else if (type.equals("5")) {// 学校
			cc.setSchool(true);
		} else if (type.equals("6")) {// 村镇商铺
			cc.setTown(true);
		} else if (type.equals("7")) {// 档口摊位
			cc.setStall(true);
		} else {// 其他
			cc.setOthers(true);
		}
		cc.setAreaId(sr.getAreaId());
		cc.setBusinessAreaId(sr.getBusinessAreaId());
		cc.setParentManageTypeId(sr.getParentManageTypeId());// 一级业态
		cc.setSonManageTypeId(sr.getSonManageTypeId());// 二级业态
		cc.setCreateTime(new Date());
		cc.setFollowStatus(0);
		cc.setNodeStatus(0);//全部客户
		cc.setCreateType(10);//发布
		cc.setCusId(getNextCustomerID());
		cc.setSolicitingTime(new Date());
		cc.setCityId(sr.getCityId());
		crmCustomerMapper.insert(cc);
	}
	
	public String getNextCustomerID() {
		String cusId = crmCustomerMapper.selectMaxCusId();
		if (StringUtils.isBlank(cusId)) {
			return "110000";
		} else {
			DecimalFormat df = new DecimalFormat("000000");
			String cusID = df.format(Long.valueOf(cusId) + 1);
			return cusID;
		}
	}

	@Override
	public void userSaveToCrm(Map<String, Object> map) {
		int selectByPhone = crmCustomerMapper.selectByPhone(map);
		if(0==selectByPhone) {
			CrmCustomer crm = new CrmCustomer();
			crm.setPhone(map.get("paramPhone").toString());
			crm.setCreateTime(new Date());
			crm.setUpdateTime(new Date());
			crm.setCreateType(6);
			crm.setFollowStatus(0);	//全部客户类别
			crm.setNodeStatus(0);//全部客户
			crm.setCityId(Integer.valueOf((map.get("cityId").toString())));
			crm.setCusId(getNextCustomerID());
			crmCustomerMapper.save(crm);
		}
	}

}
