package com.up.zpb.service.impl;

import java.util.HashMap;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.pay.wx.ApacheHttpTool;
import com.up.zpb.service.CallCenterService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.QnSignUitl;
import com.up.zpb.vo.CallRequestLog;
import com.up.zpb.vo.ResultObject;


/**
 * 对接400第三方服务客户端
 * @author PJJ       
 * @version 1.0     
 * @created 2019年9月19日 下午7:39:45
 *  企业ID: 1910080003
	企业接入号：1910080003
	企业付费号：01012345678
	企业坐席号：25781428-25781429
	坐席密码：25781428-25781429
	企业分机号：25781428-25781429
	企业门户登录地址：http://newopen.ccod.com/dcms
	企业编号：1910080003
	用户名：admin
	密码：Admin123456
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class CallCenterServiceImpl implements CallCenterService{
	
	private static final Logger logger = LoggerFactory.getLogger(CallCenterServiceImpl.class);
	public final static String entId = "1910080003";//【企业编号】企业开户信息中有
	//public final static String cusShowTel="02467924596";//外显号码
	public final static String cusShowTel="01051348027";//外显号码 
	public final static String Qn_NOTIFY_URL = "http://39.106.34.107:8081/QingNiuCallBack/callBack";
	
	@Autowired
	private LoanMapper loanMapper;
	 
	/**
	 * 无坐席外呼接口
	 * @param agentTel    经纪人手机号
	 * @param customerTel 客户手机号
	 * @param ageShowTel  主叫外显号码
	 * @param cusShowTel  被叫外显号码
	 * @return
	 */
	@Override
	public ResultObject makeNoZuoXiCall(String zhuJiaoTel,String beiJiaoTel,String beiJiaoUserName) {
		ResultObject resultObject=new ResultObject();
		logger.info("【**********************无坐席外呼接口makeNoZuoXiCall()**********************start】");
		String success="";
		JSONObject params=new JSONObject();
		try {
			String auth=QnSignUitl.findAuthorization();
			String sign=QnSignUitl.sign(auth);
			String url_nozuoxi_call="http://open.ccod.com/apiplus/callControl/requestCall?Signature="+sign;
			
			params.put("entId", entId);			//企业ID
			params.put("ani",zhuJiaoTel);	//主叫号码。5至12位纯数字
			params.put("dnis",beiJiaoTel);	//被叫号码。5至12位纯数字
			params.put("dani",cusShowTel);	//主叫外显号码。5至12位纯数字(非必选)
			params.put("ddnis",cusShowTel);	//被叫外显号码。5至12位纯数字(非必选)
			
			params.put("isrecord","0");		//是否录音（目前未使用）。0：录音; 1：不录音(非必选)
			//String callBackUrl=Qn_NOTIFY_URL+"?ani="+zhuJiaoTel+"&dnis="+beiJiaoTel+"&publishUserName="+beiJiaoUserName;
			//params.put("url",callBackUrl);  //非必选	回调地址url(非必选)
			
			Map<String, String> headers=new HashMap<String, String>();
			headers.put("Authorization", auth);
			headers.put("Accept","application/json");
			headers.put("Content-Type","application/json;charset=utf-8");
			JSONObject res=ApacheHttpTool.httpPostWithJson(url_nozuoxi_call, headers, params);
			logger.info("====请求结果："+JSON.toJSONString(resultObject));
			if("0".equals(res.get("result"))){
				success="成功";
				resultObject.put("sessionId", res.get("object"));
			}else{
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("呼叫失败了请检查请求！");
			}
		} catch (Exception e) {
			resultObject.put("result", "999999");
			resultObject.put("desc", "进异常了！");
			e.printStackTrace();
		} finally {
			this.saveLog("无坐席外呼接口:/callControl/requestCall", ""+params, resultObject+"", success);
		}
		
		logger.info("【**********************无坐席外呼接口makeNoZuoXiCall()**********************end】");
		return resultObject;
	}
	
	

	//记录日志
	@Override
	public void saveLog(String title,String param,String resultJson,String success){
		CallRequestLog logEn = new CallRequestLog();
		logEn.setTitle(title);
		logEn.setRequestParam(param);
		logEn.setRequestResult(resultJson);
		logEn.setSuccess(success);
		this.loanMapper.saveCallRequestLog(logEn);
	}

	
	public static void main(String[] args) throws Exception {
		
		CallCenterServiceImpl cal=new CallCenterServiceImpl();
		cal.makeNoZuoXiCall("15210004917","18601394380","白开水");
	}

	
	

	
	
	
	
}
