package com.up.zpb.service.impl;

import java.util.Date;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.LoanService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.Loan;
import com.up.zpb.vo.ResultObject;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class LoanServiceImpl implements LoanService {
	
	private static final Logger logger = LoggerFactory.getLogger(LoanServiceImpl.class);

	@Autowired
	private LoanMapper loanMapper;
	@Autowired
	private RedisBaseDao redisBaseDao;
	
	@Override
	public ResultObject selectPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= loanMapper.selectPage(paraMap);
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject findEntityById(String id){
		ResultObject resultObject=new ResultObject();
		try {
			Loan entity=this.loanMapper.findEntityById(id);
			resultObject.put("data", entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject saveLoan(Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		try {
			String code = String.valueOf(redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + parameters.get("telephone")+""));
	        if ( !code.equals(parameters.get("vCode")+"")) {
	        	 resultObject.setCode(Constant.VALIDCODE_ERROR);
	             resultObject.setMessage("验证码输入错误，请确认后输入。");
	             return resultObject;
	        }
			Loan entity=(Loan)ObjectHelpUtils.setValToObj2(new Loan(), parameters);
			entity.setType("1");
			entity.setCreateTime(new Date());
			this.loanMapper.saveLoan(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	
	@Override
	public ResultObject updateLoan(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Loan entity=this.loanMapper.findEntityById(paraMap.get("id")+"");
			if(entity!=null){
				this.loanMapper.updateLoan((Loan)ObjectHelpUtils.setValToObj2(entity, paraMap));
			}else{
				resultObject.setCode(Constant.CODE_PARAM_ERROR);
				resultObject.setMessage("上送参数有误");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
}
