package com.up.zpb.service.impl;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import com.google.common.collect.Maps;
import com.up.zpb.util.Constant;
import com.up.zpb.util.JWTUtil;
import com.up.zpb.vo.UserApp;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.mapper.MemberMapper;
import com.up.zpb.mapper.MemberOrderMapper;
import com.up.zpb.mapper.MessageMapper;
import com.up.zpb.mapper.ProductMapper;
import com.up.zpb.mapper.ShopMyselfMapper;
import com.up.zpb.mapper.ShopRecordsMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.mapper.UserOperRecordsMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.LoginService;
import com.up.zpb.service.MemberService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.WxUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.ShopMyself;
import com.up.zpb.vo.UserOperRecords;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;

@Service
public class MemberServiceImpl implements MemberService {

    private static final Logger logger = LoggerFactory.getLogger(MemberServiceImpl.class);
    public static final Integer MAXAGE = 3600 * 24 * 15;
    public final static String appId = ConfigurationUtils.getStringValue("appId");
    public final static String img_head = ConfigurationUtils.getStringValue("img_head");

    public final static String totalVIPNum = ConfigurationUtils.getStringValue("totalVIPNum");

    @Autowired
    RedisBaseDao redisBaseDao;

    @Autowired
    MemberMapper memberMapper;

    @Autowired
    ShopMyselfMapper shopMyselfMapper;

    @Autowired
    ProductMapper productMapper;

    @Autowired
    MemberOrderMapper memberOrderMapper;

    @Autowired
    ShopRecordsMapper shopRecordsMapper;

    @Autowired
    MessageMapper messageMapper;

    @Autowired
    private ShowInfoService showInfoService;

    @Autowired
    private UserMapper userMapper;

    @Autowired
    LoginService loginService;

    @Autowired
    UserOperRecordsMapper userOperRecordsMapper;


    @Override
    public int findByUserId(Map<String, Object> mapParams) {
        logger.info("MemberServiceImpl findByUserId mapParams:{}", mapParams);
        return memberMapper.findByUserId(mapParams);
    }

    @Override
    public void createShopCollection(Map<String, Object> parameters) {
        logger.info("MemberServiceImpl createShopCollection parameters:{}", parameters);
        try {
            ShopMyself sc = new ShopMyself();
            sc.setUserId(Integer.valueOf(parameters.get("authentication").toString()));
            sc.setObjectId(Integer.valueOf(parameters.get("shopId").toString()));
            sc.setCreateTime(new Date());
            shopMyselfMapper.insert(sc);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public List<Map<String, Object>> selectProductList(Map<String, Object> parameters) {
        logger.info("MemberServiceImpl selectProductList parameters:{}", parameters);
        return productMapper.selectProductList(parameters);
    }

    @Override
    public ResultObject getMyOrders(Map<String, Object> parameters) {
        logger.info("MemberServiceImpl getMyOrders parameters:{}", parameters);
        ResultObject resultObject = new ResultObject();
        resultObject.put("data", memberOrderMapper.selectOrdersByStatus(parameters));
        return resultObject;
    }

    @Override
    public ResultObject getMyMember(Map<String, Object> parameters) {
        logger.info("MemberServiceImpl getMyMember parameters:{}", parameters);
        ResultObject resultObject = new ResultObject();
        // 计算会员当天剩余查看店铺次数
        int count = shopRecordsMapper.selectCountByAccount(parameters);
        //当天还可查看的剩余数量
        int restNo = Integer.valueOf(totalVIPNum) - count;
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        List<Map<String, Object>> lists = memberMapper.selectMembers(parameters);
        List<Map<String, Object>> list = new ArrayList<Map<String, Object>>();
        for (Map<String, Object> map : lists) {
            map.put("totalNum", totalVIPNum);
            map.put("restNum", restNo);
            list.add(map);
        }
        resultObject.put("data", list);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    @Override
    public ResultObject getMsgStatus(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        int count = messageMapper.getCount(parameters);
        if (count != 0) {
            resultObject.put("count", "1");
        } else {
            resultObject.put("count", "0");
        }
        return resultObject;
    }

    @Override
    public ResultObject selectMsgList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        List<Map<String, Object>> selectMsgList = messageMapper.selectMsgList(parameters);
        List<Map<String, Object>> msgList = new ArrayList<Map<String, Object>>();
        try {
            if (Objects.nonNull(selectMsgList) && selectMsgList.size() != 0) {
                for (Map<String, Object> map : selectMsgList) {
                    map.put("shopid", "");
                    map.put("jcStatus", "");
                    map.put("result", "");
                    //消息类型 0 消息 1 纠错
                    if (StringUtils.equals("0", map.get("type").toString())) {
                        if (StringUtils.equals("1", map.get("effect").toString())) {
                            String createtype = map.get("page_type").toString();
                            if (StringUtils.equals("0", createtype)) {
                                map.put("shopid", map.get("page_id").toString());
                                map.put("createtype", "1");
                            } else if (StringUtils.equals("1", createtype)) {
                                map.put("createtype", "2");
                                map.put("shopid", map.get("page_id").toString());
                            }
                        } else {
                            map.put("createtype", "0");
                        }
                    } else {
                        map.put("createtype", "0");
                        map.put("title", "纠错审核通知");
                        map.put("jcStatus", map.get("scStatus").toString());
                        if (StringUtils.equals("1", map.get("scStatus").toString())) {
                            map.put("content", "纠错通过");
                            map.put("result", "可查看铺子次数+5");
                        } else {
                            map.put("content", "纠错未通过");
                            map.put("result", "与实际情况不符");
                        }
                    }
                    String date = dateToStamp(map.get("create_time").toString());
                    map.put("createTime", update(Long.valueOf(date)));
                    map.remove("effect");
                    map.remove("page_type");
                    map.remove("page_id");
                    map.remove("scStatus");
                    map.remove("create_time");
                    msgList.add(map);
                }
            }
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        resultObject.put("data", msgList);
        return resultObject;
    }

    /**
     * 时间格式化
     *
     * @param time
     * @return
     */
    public String update(long time) {
        Long timestamp = (System.currentTimeMillis() - time) / 60000;
        if (timestamp > 60) {
            SimpleDateFormat times = new SimpleDateFormat("yyyy-MM-dd");
            String nowTime = times.format(time);
            return String.valueOf(nowTime);
        } else if (timestamp == 0) {
            return "刚刚";
        }
        return String.valueOf(timestamp) + "分钟之前";
    }

    /*
     * 将时间转换为时间戳
     */
    public static String dateToStamp(String s) throws Exception {
        String res;
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = simpleDateFormat.parse(s);
        long ts = date.getTime();
        res = String.valueOf(ts);
        return res;
    }

    @Override
    public ResultObject updateMsgStatus(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        int id = Integer.valueOf(parameters.get("id").toString());
        if (id != 0) {
            messageMapper.updateMsgStatus(parameters);
        } else {
            List<Map<String, Object>> selectMsgList = messageMapper.selectMsgList(parameters);
            if (Objects.nonNull(selectMsgList) && selectMsgList.size() > 0) {
                List<Integer> ids = new ArrayList<Integer>();
                for (Map<String, Object> map : selectMsgList) {
                    Integer i = Integer.valueOf(map.get("id").toString());
                    ids.add(i);
                }
                parameters.put("ids", ids);
                messageMapper.updateAll(parameters);
            }
        }
        return resultObject;
    }

    @Override
    public ResultObject selectCollectionList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        //resultObject.put("shopCollections", showInfoService.createShop(shopMyselfMapper.findShopMyselfList(parameters),"1", "0"));
        if (ProjectEnum.ProjectType.SHOP.getValue().equals(parameters.get("projectType") + "")) {
            List<Map<String, Object>> list = shopMyselfMapper.findMyLikeShopList(parameters);
            if (list != null && list.size() > 0) {
                for (Map<String, Object> temp : list) {
                    List<String> labelArr = this.showInfoService.findLabelByObjId(temp.get("id") + "", ProjectEnum.ProjectType.SHOP.getValue(), ShopEnum.SHOP_LABEL_KEY);
                    temp.put("label", labelArr);
                }
            }
            resultObject.put("shopCollections", list);
        } else {
            List<Map<String, Object>> list = shopMyselfMapper.findMyLikeOfficeList(parameters);
            if (list != null && list.size() > 0) {
                for (Map<String, Object> temp : list) {
                    List<String> labelArr = this.showInfoService.findLabelByObjId(temp.get("id") + "", ProjectEnum.ProjectType.OFFICE.getValue(), ShopEnum.SHOP_LABEL_KEY);
                    temp.put("label", labelArr);
                }
            }
            resultObject.put("shopCollections", list);
        }
        return resultObject;
    }

    @Override
    public ResultObject cancelCollection(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        shopMyselfMapper.cancelShopMyself(parameters);
        return resultObject;
    }

    @Override
    public ResultObject deleteCollection(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        List<Integer> ids = new ArrayList<Integer>();
        String[] idStr = parameters.get("shopId").toString().split(",");
        for (int i = 0; i < idStr.length; i++) {
            Integer id = Integer.valueOf(idStr[i]);
            ids.add(id);
        }
        parameters.put("ids", ids);
        shopMyselfMapper.deleteShopMyself(parameters);
        return resultObject;
    }

    @Override
    public ResultObject weChatShare(Map<String, Object> parameters) throws UnsupportedEncodingException {
        ResultObject resultObject = new ResultObject();
        String url = parameters.get("url").toString();//获取分享url
        url = URLDecoder.decode(url, "UTF-8");
        String access_token = StringUtils.EMPTY;
        if (redisBaseDao.exists("access_token")) {
            access_token = redisBaseDao.get("access_token").toString();
        } else {
            access_token = WxUtils.getToken(url, redisBaseDao);
        }
        String nonceStr = WxUtils.uuid();
        int timestamp = WxUtils.getSecondTimestamp(new Date());
        String jsapi_ticket = StringUtils.EMPTY;
        if (redisBaseDao.exists("jsapi_ticket")) {
            jsapi_ticket = redisBaseDao.get("jsapi_ticket").toString();
        } else {
            jsapi_ticket = WxUtils.getjsapi_ticket(access_token, redisBaseDao);
        }
        String sign = "jsapi_ticket=" + jsapi_ticket + "&noncestr=" + nonceStr + "&timestamp=" + timestamp + "&url=" + url + "";
        // 加密
        String signature = WxUtils.SHA1(sign);
        resultObject.put("appId", appId);
        resultObject.put("timestamp", timestamp);
        resultObject.put("nonceStr", nonceStr);
        resultObject.put("signature", signature);

        logger.info("jsapi_ticket:{}", jsapi_ticket);
        logger.info("noncestr:{}", nonceStr);
        logger.info("timestamp:{}", timestamp);
        logger.info("url:{}", url);
        logger.info("signature:{}", signature);
        return resultObject;
    }

    @Override
    public ResultObject weChatLogin(Map<String, Object> parameters) {
        String account = parameters.get("account").toString();
        String validCode = parameters.get("password").toString();
//      String provinceId = parameters.get("provinceId").toString();
        String cityId = parameters.get("cityId").toString();
        String source = parameters.get("channel").toString();
        String userAgent = parameters.get("userAgent").toString();
        String openId = parameters.get("openId").toString();
        ResultObject login = loginService.wxLogin(account, validCode, openId, "", "1", cityId, source, userAgent);
//        UserApp userApp = new UserApp();
//        userApp.setAccount(account);
//        userApp.setWxOpenId(openId);
//        userMapper.updateUser(userApp);
        return login;
    }


//	@Override
//	public ResultObject isWeChatLogin(Map<String, Object> parameters) {
//		ResultObject resultObject = new ResultObject();
//		int flag = userMapper.isWeChatLogin(parameters);
//		resultObject.put("flag",flag );
//		if(0!=flag) {
//			UserApp userApp = userMapper.selectUserByAccount(parameters);
//			//最新登录时间
//			userApp.setUpdateTime(new Date());
//			userApp.setLoginCount(userApp.getLoginCount()+1);
//			//正确，生成token
//			String token=JWTUtil.sign(userApp, MAXAGE);
//			resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
//			resultObject.put("loginFlag", true);
//			if(userApp.getStatus() == 0) {
//				resultObject.setCode(Constant.CODE_EXCEPTION);
//				resultObject.setMessage("您的账户已被冻结，请联系客服");
//				return resultObject;
//			}
//			resultObject.put("memberInfo", userApp);
//			userMapper.updateUser(userApp);
//			//根据用户ID查询该用户是否为会员
//			Map<String,Object> mapParams = Maps.newHashMap();
//			mapParams.put("id", userApp.getId());
//			resultObject.put("id", userApp.getId());
//			resultObject.remove("memberInfo");
//			int count =memberMapper.findByUserId(mapParams);
//			//会员表有记录 并且 状态为有效
//			if(0!= count){
//				resultObject.put("memberType", "0");
//				resultObject.put("pvCount", totalVIPNum);
//			}else {
//				resultObject.put("memberType", 2);// 2普通用户
//				resultObject.put("pvCount", 5);
//			}
//			resultObject.put("channel", userApp.getChannel());
//			resultObject.put("phone", userApp.getAccount());
//		}
//		return resultObject;
//	}

//	@Override
//	public ResultObject weChatLogin(Map<String, Object> parameters) {
//		String account = parameters.get("account").toString();
//		String validCode = parameters.get("password").toString();
//		String provinceId = parameters.get("provinceId").toString();
//		String cityId = parameters.get("cityId").toString();
//		String source = parameters.get("channel").toString();
//		String userAgent = parameters.get("userAgent").toString();
//		String openId = parameters.get("openId").toString();
//		ResultObject login = loginService.login(account, validCode, "", "", provinceId, cityId, source, userAgent);
//		UserApp userApp = new UserApp();
//		userApp.setAccount(account);
//		userApp.setWxOpenId(openId);
//		userMapper.updateUser(userApp);
//		return login;
//	}

    @Override
    public ResultObject shareRecords(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        parameters.put("operType", 3);//一键分享
        int count = userOperRecordsMapper.selectCount(parameters);
        if (0 == count) {
            UserOperRecords uor = new UserOperRecords();
            uor.setCount("+2");
            uor.setType(3);
            uor.setCreateTime(new Date());
            uor.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
            uor.setUserId(Integer.valueOf(parameters.get("authentication").toString()));
            userOperRecordsMapper.insert(uor);
        }
        return resultObject;
    }

    @Override
    public ResultObject selectUserOperList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        resultObject.put("data", userOperRecordsMapper.selectList(parameters));
        return resultObject;
    }

    @Override
    public ResultObject isWeChatLogin(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        int flag = userMapper.isWeChatLogin(parameters);
        resultObject.put("flag", flag);
        if (0 != flag) {
            UserApp userApp = userMapper.selectUserWxOpenId(parameters);
            //最新登录时间
            userApp.setUpdateTime(new Date());
            userApp.setLoginCount(userApp.getLoginCount() + 1);
            //正确，生成token
            String token = JWTUtil.sign(userApp, MAXAGE);
            resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
            resultObject.put("loginFlag", true);
            if (userApp.getStatus() == 0) {
                resultObject.setCode(Constant.CODE_EXCEPTION);
                resultObject.setMessage("您的账户已被冻结，请联系客服");
                return resultObject;
            }
            resultObject.put("data", userApp);
            //userMapper.updateUser(userApp);
            //根据用户ID查询该用户是否为会员
//			Map<String,Object> mapParams = Maps.newHashMap();
//			mapParams.put("id", userApp.getId());
//			resultObject.put("id", userApp.getId());
//			resultObject.remove("memberInfo");
//			int count =memberMapper.findByUserId(mapParams);
//			//会员表有记录 并且 状态为有效
//			if(0!= count){
//				resultObject.put("memberType", "0");
//				resultObject.put("pvCount", totalVIPNum);
//			}else {
//				resultObject.put("memberType", 2);// 2普通用户
//				resultObject.put("pvCount", 5);
//			}
//			resultObject.put("channel", userApp.getChannel());
//			resultObject.put("phone", userApp.getAccount());
        }
        return resultObject;
    }

}
