package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.OfficeDicMapper;
import com.up.zpb.mapper.OfficeExtendMapper;
import com.up.zpb.mapper.OfficeMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.ShopBusinessTypeMapper;
import com.up.zpb.mapper.ShopConditionMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.service.ContractService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.OfficeDicService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.AgentEntity;
import com.up.zpb.vo.Areas;
import com.up.zpb.vo.CommissionEntity;
import com.up.zpb.vo.IfEditResult;
import com.up.zpb.vo.Office;
import com.up.zpb.vo.OfficeDetailApp;
import com.up.zpb.vo.OfficeExtend;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.PublishOfficeVo;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.SumMyFollow;
import com.up.zpb.vo.SysParam;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;
import com.up.zpb.vo.fourhundred.IvrKeyShow;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class OfficeServiceImpl implements OfficeService {

	private static final Logger logger = LoggerFactory.getLogger(OfficeServiceImpl.class);
	
	/*@Autowired
	private RedisBaseDao redisBaseDao;*/
	@Autowired
	private OfficeMapper officeMapper;
	@Autowired
	private  AreasMapper areasMapper;
	@Autowired
	private  BusinessAreaMapper businessAreaMapper;
	@Autowired
	private ShopConditionMapper shopConditionMapper;
	@Autowired
	private DictionaryMapper dictionaryMapper;
	@Autowired
	private DictionaryService dictionaryService;
	@Autowired
	private ShowInfoService showInfoService;
	@Autowired
	private ProjectOrderMapper projectOrderMapper;
	/*@Autowired
	private PhoneRecordMapper phoneRecordMapper;*/
	@Autowired
	private OfficeDicMapper officeDicMapper;
	@Autowired
	private UserMapper userMapper;
	@Autowired
	private ShopBusinessTypeMapper shopBusinessTypeMapper;
	@Autowired
	private ContractService contractService;
	@Autowired
	private OfficeDicService officeDicService;
	@Autowired
	private RegionsMapper regionsMapper;
	@Autowired
	private OfficeExtendMapper officeExtendMapper;
	@Autowired
	private FourHundredService fourHundredService;
	
	
	
	public final static String img_head = ConfigurationUtils.getStringValue("bank_img");

	@Cacheable(expireTime=60*60)
	public Map<String,Object> selectMapByParentKey(String id){
		return this.officeMapper.findEntity(id);
	}

	@Override
	public ResultObject findList(Map<String,Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		List<Map<String,Object>>  listData=this.officeMapper.findList(paraMap);
		resultObject.put("resMap", listData);
		 return resultObject;
	}
	
	
	/**
	 * 解析id位对应的区间
	 * eg：200-400万元  
	 * @param parameter
	 * @return
	 */
	@Override
	public void analysisLeftRight(Map<String, Object> parameters){
		logger.info("【===================开始解析id位对应的左右区间值入参位："+parameters+"】");
		if (Objects.nonNull(parameters.get("titleDailyRentId"))) {
			//1-日租
			parameters.put("type",  Constant.CONDITION_TYPE_DAILY);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleDailyRentId").toString());
			parameters.put("titleDailyRentMin", m.get("price_low"));
			parameters.put("titleDailyRentMax", m.get("price_high"));
		}
		if (Objects.nonNull(parameters.get("titleMonthlyId"))) {
			//2-月租
			parameters.put("type", Constant.CONDITION_TYPE_MONTH);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleMonthlyId").toString());
			parameters.put("monthlyLow", m.get("price_low"));
			parameters.put("monthlyHigh", m.get("price_high"));
		}
		if (Objects.nonNull(parameters.get("titleTransfeeId"))) {
			//3-转让费
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleTransfeeId").toString());
			parameters.put("transfeeLow", m.get("price_low"));
			parameters.put("transfeeHigh", m.get("price_high"));
		}
		if (Objects.nonNull(parameters.get("titleMianjiId"))) {
			//4-面积 
			//parameters.put("type", Constant.CONDITION_TYPE_AREA);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleMianjiId").toString());
			parameters.put("titleMianjiMin", m.get("price_low"));
			parameters.put("titleMianjiMax", m.get("price_high"));
		}
		if (Objects.nonNull(parameters.get("titleTotalPriceId"))) {
			//5-总价 
			parameters.put("type", Constant.CONDITION_TYPE_TOTAL);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleTotalPriceId").toString());
			parameters.put("titlePriceMin", m.get("price_low"));
			parameters.put("titlePriceMax", m.get("price_high"));
		}
		if (Objects.nonNull(parameters.get("titleAvgPriceId"))) {
			//6-均价
			parameters.put("type", Constant.CONDITION_TYPE_AVG);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("titleAvgPriceId").toString());
			parameters.put("titleAvgPriceMin", m.get("price_low"));
			parameters.put("titleAvgPriceMax", m.get("price_high"));
		}
		logger.info("【===================结束解析id位对应的左右区间出差为："+parameters+"】");
	}
	
	@Override
	public ResultObject selectOfficePage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			
			this.analysisLeftRight(paraMap);//解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.officeMapper.selectOfficePage(paraMap);
			if(list!=null && list.size()>0){
				for(Map<String,Object> temp:list){
					temp.put("label",this.showInfoService.findLabelByObjId(temp.get("id")+"", ProjectEnum.ProjectType.OFFICE.getValue(),OfficeEnum.OFFICE_LABEL_KEY));
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	public ResultObject findMyPublishOfficePage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			
			this.analysisLeftRight(paraMap);//解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<PublishOfficeVo> list= this.officeMapper.findMyPublishOfficePage(paraMap);
			if(list!=null && list.size()>0){
				for(PublishOfficeVo temp:list){
					temp.setLabel(this.showInfoService.findLabelByObjId(temp.getId()+"", ProjectEnum.ProjectType.OFFICE.getValue(), OfficeEnum.OFFICE_LABEL_KEY));
					//联系1人+到访1人+认购1人
					//我发布的，是统计所有人的联系次数；我跟进的商铺，是统计我自己点击联系的
					temp.setSumMyFollowList(this.getSumFiveStatusList(temp.getId()+"",ProjectEnum.ProjectType.OFFICE.getValue(),""));
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public List<SumMyFollow> getSumFiveStatusList(String projectId,String projectType,String agentId){
		Map<String,Object> statusMap=new HashMap<String, Object>();
		statusMap.put("projectId", projectId);
		statusMap.put("projectType", projectType);
		if(StringUtils.isNotEmpty(agentId)){
			statusMap.put("agentId", agentId);//我发布的商铺，统计联系次数，是要所有agentId的总次数
		}
		Map<String,Object> numResult=this.projectOrderMapper.sumConcatNumber(statusMap);
		List<SumMyFollow> myNumList=new ArrayList<SumMyFollow>();
		//
		SumMyFollow  myF2=new SumMyFollow();
		myF2.setKey(ProjectEnum.OrderStatus.ORDER_BAOBEI.getValue());
		myF2.setNumber(numResult.get("lianXiNumber")+"");
		
		myNumList.add(myF2);
		SumMyFollow  myF3=new SumMyFollow();
		myF3.setKey(ProjectEnum.OrderStatus.ORDER_DAOFANG.getValue());
		myF3.setNumber(numResult.get("daoFangNumber")+"");
		myNumList.add(myF3);
		SumMyFollow  myF4=new SumMyFollow();
		myF4.setKey(ProjectEnum.OrderStatus.ORDER_RENGOU.getValue());
		myF4.setNumber(numResult.get("renGouNumber")+"");
		myNumList.add(myF4);
		SumMyFollow  myF5=new SumMyFollow();
		myF5.setKey(ProjectEnum.OrderStatus.ORDER_SIGN.getValue());
		myF5.setNumber(numResult.get("qianYueNumber")+"");
		myNumList.add(myF5);
		SumMyFollow  myF6=new SumMyFollow();
		myF6.setKey(ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue());
		myF6.setNumber(numResult.get("jieYongNumber")+"");
		myNumList.add(myF6);
		return myNumList;
	}

	@Override
	public ResultObject crawlerShop(JSONObject jsonObject) {
		ResultObject resultObject = new ResultObject();
		if (Objects.isNull(jsonObject)){
			return resultObject;
		}
		try {
			Office office = new Office();
			String[] imgArray = jsonObject.getJSONArray("img").toArray(new String[] {});
			String shopImgs = Stream.of(imgArray).collect(Collectors.joining(","));
			office.setImgs(shopImgs);//图片
			office.setCoverImg(shopImgs.substring(0,shopImgs.indexOf(",")));
			office.setCityId(jsonObject.getString("cityId"));
			try {
				if (Objects.nonNull(jsonObject.getString("month_rent"))){
					office.setMonthlyRent(new BigDecimal(jsonObject.getString("month_rent").replaceAll("万/月","")));//月租金
				}
				if (Objects.nonNull(jsonObject.getString("day_rent"))){
					office.setDailyRent(new BigDecimal(jsonObject.getString("day_rent").replaceAll("元/m²•天","")));//日租金
				}
				if (Objects.nonNull(jsonObject.getString("buildArea"))){
					office.setBuildArea(new BigDecimal(jsonObject.getString("buildArea").replaceAll("m²","")));//建筑面积
				}
				office.setRealAddress(jsonObject.getString("position"));//详细地址
			}catch (Exception e){
				resultObject.setMessage("空指针...");
				logger.error(e.getMessage(), e);
			}
			//设置区域&&商圈id  大兴区-亦庄-嘉捷科技园
			if (StringUtils.isNotBlank(jsonObject.getString("position"))){
				//区域id
				List<String> area = Arrays.asList(jsonObject.getString("position").split("-"));
				String areaId = areasMapper.selectByName(area.get(0).replaceAll("区",""));
				if (StringUtils.isNotBlank(areaId)){
					office.setAreaId(areaId);
				}else{
					office.setAreaId("110101");
				}
				//商圈id
				String businessAreaId = businessAreaMapper.selectByName(area.get(1));
				if (StringUtils.isNotBlank(businessAreaId)){
					office.setBusinessAreaId(businessAreaId);
				}else{
					office.setBusinessAreaId("2");
				}
			}else{
				//为空的话设置为默认值  朝阳-安贞
				office.setAreaId("110101");
				office.setBusinessAreaId("2");
			}
			String type = jsonObject.getString("type");
			List<String> types = Arrays.asList("写字楼","共享办公","写字楼","写字楼","创意园区","写字楼");
			if (types.contains(type)){
				office.setType(String.valueOf(types.indexOf(type)));//写字楼类型
			}
			List<String> renovations = Arrays.asList("毛坯","简装","精装","豪华装修");
			if (Objects.nonNull(jsonObject.getString("renovation"))){
				if (renovations.contains(jsonObject.getString("renovation"))){
					office.setRentType(String.valueOf(renovations.indexOf(jsonObject.getString("renovation"))));//装修情况
				}
			}
			String station = jsonObject.getString("workstation");
			office.setStation1(station.split("~")[0]);
			office.setStation2(station.split("~")[1].replaceAll("个",""));//最大 最小工位数
			String register = jsonObject.getString("register");
			if (StringUtils.isNotBlank(register)){
				if (register.equals("可注册")){
					office.setRegister("2");
				}else{
					office.setRegister("1");//是否可注册
				}
			}
			String separate = jsonObject.getString("separate");
			if (StringUtils.isNotBlank(separate)){
				if (separate.equals("可分割")){
					office.setSeparate("2");
				}else{
					office.setSeparate("1");//是否可分割
				}
			}
			office.setRentType(jsonObject.getString("rent_type"));//写字楼类别
			String leader = jsonObject.getString("leader");
			if (StringUtils.isNotBlank(leader)){
				office.setDeveloper(leader);//开发商
			}
			String detail = jsonObject.getString("detail");
			if (StringUtils.isNotBlank(detail)){
				office.setIntroduce(detail);//详情
			}
			if (StringUtils.isNotBlank(jsonObject.getString("name"))){
				office.setName(jsonObject.getString("name"));
			}else{
				office.setName("暂无");
			}
			//商铺编号
			office.setOfficeNumber(this.showInfoService.getNextCustomerID("F"));
			//设置经纪人id为1
			office.setAgentId("1");
			//设置测试标题
			office.setTitle("主标题");
			office.setTitleSub("副标题");
			office.setCommission("暂无");
			office.setCommissionValue(new BigDecimal(0.1));
			office.setCreateTime(new Date());
			officeMapper.saveOffice(office);
			String[] supporting = jsonObject.getJSONArray("supporting").toArray(new String[] {});
			List<String> listType = Arrays.asList(supporting);
			List<String> officeSupporting = Arrays.asList("宽带","有线电视","水","电","电话","中央空调","电梯","集中供暖","办公家具","免费停车","员工餐厅","安全监控");
			List<Map<String,Object>> mapList = new ArrayList<>();
			for (String a : listType){
				if (officeSupporting.contains(a)){
					Map<String,Object> map = new HashMap<>();
					map.put("object_id",office.getId());
					map.put("d_value",officeSupporting.indexOf(a));
					map.put("type",2);
					map.put("dic_type",510);
					mapList.add(map);
				}
			}
			if (mapList.size() > 0){
				officeDicService.saveAll(mapList);//写字楼配套
			}
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		return resultObject;
	}

	@Override
	public ResultObject selectOfficeManager(Map<String, Object> paraMap) {
        logger.info("===========================[OfficeServiceImpl][selectOfficeManager],param{}",paraMap);
        ResultObject resultObject = new ResultObject();
        try {
            Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
            Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
            PageHelper.startPage(pageNum, pageSize, true);
            PageInfo<Map<String, Object>> mapPageInfo = new PageInfo<>(this.officeMapper.selectOfficeManager(paraMap));
            List<Map<String, Object>> list = mapPageInfo.getList();
            if(list != null && mapPageInfo.getTotal() > 0) {
                for (Map<String, Object> temp : list) {
                    //获取orderStatus数值对应的name
                    if(null != temp.get("orderStatus")){
                        ProjectEnum.OrderStatus orderStatus = ProjectEnum.OrderStatus.codeOf(temp.get("orderStatus").toString());
                        temp.put("orderStatusStr",orderStatus.getName());
                    }
                    //获取rentType数值对应的name
                    if(null != temp.get("rentType")){
                        ShopEnum.RentType rentType = ShopEnum.RentType.codeOf(temp.get("rentType").toString());
                        temp.put("rentTypeStr",rentType.getName());
                    }
                }
            }
            resultObject.put("list", list);
            resultObject.put("totalCount", mapPageInfo.getTotal());
            return resultObject;
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
	}


	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject selectHotOffice(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			paraMap.put("limit", 5);
			List<Map<String,Object>> list= this.officeMapper.findList(paraMap);
			resultObject.put("list", list);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	@Cacheable(expireTime=30*60)
	public List<Map<String, Object>> appFindAreaAndRegions(String cityId){
		List<Map<String, Object>> areaList = this.areasMapper.selectByParentId(cityId);
		for(Map<String, Object> temp:areaList){
			String pid=temp.get("id")+"";
			if(StringUtils.isEmpty(pid)){
				List<Map<String,Object>> firstList=new ArrayList<Map<String,Object>>();
				Map<String,Object> firstMap=new HashMap<String,Object>();
				firstMap.put("id", "");
				firstMap.put("name", "全部");
				firstList.add(firstMap);
				temp.put("regionsList",firstList);
			}else{
				List<Map<String,Object>> regionsList= businessAreaMapper.selectByAreaId(pid);
				if(regionsList.size() > 0){
					Map<String, Object> stringObjectMap = regionsList.get(0);
					stringObjectMap.put("id",pid);//app当子集为全部时放父id
				}
				temp.put("regionsList", regionsList);//商圈列表
			}
		}
		return areaList;
	}
	
	
	
	/**
	 * 查找区域+商圈   
	 * @param cityId
	 * @return
	 */
	@Override
	@Cacheable(expireTime=30*60)
	public List<Map<String, Object>> findAreaAndRegions(String cityId){
		List<Map<String, Object>> areaList = this.areasMapper.selectByParentId(cityId);
		for(Map<String, Object> temp:areaList){
			String pid=temp.get("id")+"";
			if(StringUtils.isEmpty(pid)){
				List<Map<String,Object>> firstList=new ArrayList<Map<String,Object>>();
				Map<String,Object> firstMap=new HashMap<String,Object>();
				firstMap.put("id", "");
				firstMap.put("name", "全部");
				firstList.add(firstMap);
				temp.put("regionsList",firstList);
			}else{
				List<Map<String,Object>> regionsList= businessAreaMapper.selectByAreaId(pid);
				if(regionsList.size() > 0){
					Map<String, Object> stringObjectMap = regionsList.get(0);
					stringObjectMap.put("id","");
				}
				temp.put("regionsList", regionsList);//商圈列表
			}
		}
		return areaList;
	}
	
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findOfficeSaleSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//1）区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.findAreaAndRegions(parameters.get("cityId")+""));
		}
		//2）面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		//3）总价
		parameters.put("type", Constant.CONDITION_TYPE_TOTAL);
		resultObject.put("priceList", shopConditionMapper.selectByCityId(parameters));
		//4）类型 1-纯写字楼   2-商业综合楼  3-酒店写字楼 4-其他
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.OFFICE_TYPE));
		return resultObject;
	}
	
	
	
	//写字楼出租
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findOfficeRentSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//1）区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.findAreaAndRegions(parameters.get("cityId")+""));
		}
		//2）面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		//3）日租
		parameters.put("type", Constant.CONDITION_TYPE_DAILY);
		resultObject.put("dailyList", shopConditionMapper.selectByCityId(parameters));
		//4）类型: 普通办公、共享办公
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.OFFICE_TYPE));
		return resultObject;
	}
	
	//搜索条件-写字楼新盘   
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findOfficeNewSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		if(OfficeEnum.TypeSale.NEWS_RENT.getValue().equals(parameters.get("typeSale"))){
			//【出租：区域-日租-类型】
			parameters.put("type",Constant.CONDITION_TYPE_DAILY);
			resultObject.put("dailyRentList", shopConditionMapper.selectByCityId(parameters));//日租
		}else {
			//【出售：区域-均价-类型】
			parameters.put("type",Constant.CONDITION_TYPE_AVG);
			resultObject.put("avgPriceList", shopConditionMapper.selectByCityId(parameters));//均价
		}
		//区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.findAreaAndRegions(parameters.get("cityId")+""));
		}
		//类型
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.OFFICE_TYPE));
		//面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		return resultObject;
	}



	@Override
	public ResultObject pcOfficeDetail(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		resultObject.put("myRoleType", "2");//默认我是客源
		resultObject.put("nodes","");
		resultObject.put("recordList", "");
		resultObject.put("renGouList", "");
		resultObject.put("signList", "");
		resultObject.put("jieYongList", "");
		resultObject.put("completeList", "");
		try {
			Map<String,Object> basic=new HashMap<String,Object>();
			String projectId=paraMap.get("projectId")+"";
			String projectType=ProjectEnum.ProjectType.OFFICE.getValue();
			//基本信息：
			basic=this.officeMapper.findEntity(projectId);
			if(basic==null){
				resultObject.setCode(Constant.CODE_PARAM_ERROR);
				resultObject.setMessage("入参id有误，查无数据");
				return resultObject;
			}
			//名称
			basic.put("name",this.jsonDetailOfficeName(basic));
			//金额
            basic.put("totalPrice",basic.get("totalPrice"));
			//主图
			basic.put("imgs", Arrays.asList(String.valueOf(basic.get("imgs")).split(",")));
			//标签
			resultObject.put("labelList", this.showInfoService.findLabelByObjId(projectId,projectType, OfficeEnum.OFFICE_LABEL_KEY));
			//明面图
			if( !ObjectHelpUtils.isMyNull(basic.get("site_imgs")+"")){	
				basic.put("site_imgs",Arrays.asList(String.valueOf(basic.get("site_imgs")).split(",")));
			}else{
				basic.put("site_imgs",new ArrayList<Object>());
			}
			//位置图
			if( !ObjectHelpUtils.isMyNull(basic.get("plane_imgs")+"")){		
				basic.put("plane_imgs", Arrays.asList(String.valueOf(basic.get("plane_imgs")).split(",")));
			}else{
				basic.put("plane_imgs",new ArrayList<Object>());
			}
			if( basic.get("shop_height") ==null){
				basic.put("shop_height", "暂无");
				basic.put("shop_height_u", "");
			}
			if(basic.get("open_time") ==null){
				basic.put("open_time", "暂无");
			}
			
			//查找外显号
			IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(basic.get("phone")+"");
			basic.put("phone", ivrEn.getIvrAll());
			resultObject.put("basic", basic);
			//配套设施：
			resultObject.put("supportingList", this.showInfoService.findLabelByOid2(projectId, projectType, OfficeEnum.OFFICE_MATCHE_KEY));
			//客源控制按钮
			resultObject.put("show", "show");
			//node+
			this.jsonRoleType(resultObject, projectId, projectType, paraMap.get("loginUserId")+"" , basic.get("agent_id")+"");
			//跟进记录-列表
			this.followLog(projectId, projectType,paraMap.get("loginUserId")+"", resultObject);

		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public void jsonRoleType(ResultObject resultObject,String projectId,String projectType,String loginUserId,String agentId){
		//节点：
		resultObject.put("nodes",this.getNodeName(projectId, projectType, loginUserId));
		//myRoleType
		if(loginUserId.equals(agentId)){
			resultObject.put("myRoleType", "1");//我是房源
		}else{
			resultObject.put("myRoleType", "2");//我是客源
		}
	}

	@Override
	public ResultObject crawlerNewDiskOffice(JSONObject jsonObject) {
		ResultObject resultObject = new ResultObject();
		try {
			Office office = new Office();
			office.setAvePrice(new BigDecimal(jsonObject.getString("price")));//写字楼均价
			office.setName(jsonObject.getString("title"));//楼盘标题
			office.setAgentId("1");//暂定经纪人id为1
			office.setRentType("4");
			String[] arr = jsonObject.getJSONArray("label").toArray(new String[]{});
			officeMapper.saveOffice(office);
			List<String> attrs = Arrays.asList(arr);
			//写字楼特殊标签  字典表 410
			List<String> attr = Arrays.asList("繁华地段","交通便利","随时看房","品牌地产","视野开阔","临近地铁","办公独栋","品牌物业","低价急售","成熟商圈");
			List<Map<String,Object>> mapList = new ArrayList<>();
			for (String a : attrs){
				if (attr.contains(a)){
					Map<String,Object> map = new HashMap<>();
					map.put("object_id",office.getId());
					map.put("d_value",attr.indexOf(a));
					map.put("type","2");
					map.put("dic_type",410);
					mapList.add(map);
				}
			}
			if (mapList.size() > 0){
				officeDicService.saveAll(mapList);//写字楼标签
			}
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}


	/**
	 * app写字楼详情   
	 * @param basic
	 * @return
	 */
	@Override
	public ResultObject appOfficeDetail(Map<String,Object> paraMap){
		ResultObject resultObject = new ResultObject();
		try{
			String id=paraMap.get("projectId")+"";
			String projectType=ProjectEnum.ProjectType.OFFICE.getValue();
			Map<String,Object> entityMap=this.officeMapper.findEntity(id);
			OfficeDetailApp entity=new OfficeDetailApp();
			if(ProjectEnum.RentType.NEWS_SALE.getValue().equals(entityMap.get("rent_type")+"")){
				//新盘有均价
				entity.setAve_price(entityMap.get("ave_price")+"");
				entity.setAve_price_u(entityMap.get("ave_price_u")+"");
			}else{
				//出租、出售是单价
				entity.setAve_price(entityMap.get("unit_price")+"");
				entity.setAve_price_u(entityMap.get("unit_price_u")+"");
			}
			entity.setRent_type(entityMap.get("rent_type")+"");
			entity.setUnit_price(entityMap.get("unit_price")+"");
			entity.setUnit_price_u(entityMap.get("unit_price_u")+"");
			entity.setBuild_area(entityMap.get("build_area")+"");
			entity.setBuild_area_u(entityMap.get("build_area_u")+"");
			entity.setTotal_price(entityMap.get("totalPrice")+"");
			entity.setTotalPrice_u(entityMap.get("totalPrice_u")+"");
			entity.setTotal_price_u(entityMap.get("totalPrice_u")+"");
			entity.setCommission(entityMap.get("commission")+"");
			entity.setDeveloper(entityMap.get("developer")+"");
			entity.setImgs(Arrays.asList(String.valueOf(entityMap.get("imgs")).split(",")));
			if( !ObjectHelpUtils.isMyNull((entityMap.get("introduce")+""))){
				entity.setIntroduce(entityMap.get("introduce")+"");//描述
			}
			if( !ObjectHelpUtils.isMyNull((entityMap.get("support_profile")+""))){
				entity.setIntroduceMating(entityMap.get("support_profile")+"");//配套
			}
			entity.setLabel(this.showInfoService.findLabelByObjId(id,projectType, OfficeEnum.OFFICE_LABEL_KEY));
			entity.setPositionx(entityMap.get("positionx")+"");
			entity.setPositiony(entityMap.get("positiony")+"");
			entity.setReal_address(entityMap.get("real_address")+"");
			entity.setShop_number(entityMap.get("office_number")+"");
			entity.setType(entityMap.get("type")+"");
			entity.setExpired("客户签约日期后"+entityMap.get("expired")+"天内");
			//业态
			if(Objects.nonNull(entityMap.get("son_manage_type_id"))){
				entity.setYetai(this.shopBusinessTypeMapper.findNameById(entityMap.get("son_manage_type_id")+""));
			}
			entity.setYetai(entityMap.get("yetai")+"");
			entity.setDaily_rent(entityMap.get("daily_rent")+"");
			entity.setDaily_rent_u(entityMap.get("daily_rent_u")+"");
			entity.setMonthly_rent(entityMap.get("monthly_rent")+"");
			entity.setMonthly_rent_u(entityMap.get("monthly_rent_u")+"");
			entity.setDecorate(entityMap.get("decorate")+"");
			entity.setStation(entityMap.get("station")+"");
			entity.setRegister(entityMap.get("register")+"");
			entity.setSeparate(entityMap.get("separate")+"");
			entity.setPay_method(entityMap.get("pay_method")+"");
			entity.setOpen_time(entityMap.get("open_time")+"");
			if(ObjectHelpUtils.isMyNull(entityMap.get("pay_method")+"")){
				entity.setPay_method("暂无");
			}
			if( ObjectHelpUtils.isMyNull(entityMap.get("shop_height")+"")){
				entityMap.put("shop_height", "暂无");//TODO
				entityMap.put("shop_height_u", "");
			}
			if(ObjectHelpUtils.isMyNull(entityMap.get("open_time")+"")){
				entity.setOpen_time("暂无");
			}
			entity.setFloor_current(entityMap.get("floor_total")+"");
			if("-个".equals(entityMap.get("station")+"") || ObjectHelpUtils.isMyNull(entityMap.get("station")+"")){
				entity.setStation("暂无");
			}
			if(ObjectHelpUtils.isMyNull(entityMap.get("decorate")+"")){
				entity.setDecorate("暂无");
			}
			if(ObjectHelpUtils.isMyNull(entityMap.get("floor_total")+"")){
				entity.setFloor_current("暂无");
			}
			//位置图
			if( !ObjectHelpUtils.isMyNull(entityMap.get("site_imgs")+"")){
				entity.setSite_imgs(Arrays.asList(String.valueOf(entityMap.get("site_imgs")).split(",")) );
			}
			//平面图
			if( !ObjectHelpUtils.isMyNull(entityMap.get("plane_imgs")+"")){
				entity.setPlane_imgs(Arrays.asList(String.valueOf(entityMap.get("plane_imgs")).split(",")) );
			}
			
			entity.setName(this.jsonDetailOfficeName(entityMap));
				

			//配套设施：
			resultObject.put("supportingList", this.showInfoService.findLabelByOid2(id,projectType, OfficeEnum.OFFICE_MATCHE_KEY));
			//铺源动态  
			Map<String,Object> dyMap=new HashMap<String,Object>();
			dyMap.put("projectId", id);
			dyMap.put("projectType", ProjectEnum.ProjectType.OFFICE.getValue());
			entity.setDynamicList(this.projectOrderMapper.findDynamicList(dyMap));

			//为你推荐
			List<Map<String,Object>> recommendedList=new ArrayList<Map<String,Object>>();
			if("1".equals(entityMap.get("online_status")+"") && "2".equals(entityMap.get("audit_status")+"")){
				//只有上架才展示为你推荐
				Map<String,Object> recoMap=new HashMap<String,Object>();
				recoMap.put("pageNum", "1");
				recoMap.put("pageSize", "5");
				recoMap.put("rentType", entityMap.get("rent_type")+"");
				ResultObject tjResult=this.selectOfficePage(recoMap);
				recommendedList=(List<Map<String,Object>>)tjResult.get("list");
			}
			entity.setRecommendedList(recommendedList);
			resultObject.put("basic",entity);
			this.jsonRoleType(resultObject, id, projectType, paraMap.get("loginUserId")+"" , entityMap.get("agent_id")+"");
			
			AgentEntity agEn=this.findAgentEntity(entityMap.get("agent_id")+"");
			agEn.setName(entityMap.get("linkman")+"");//联系人姓名
			//agEn.setTel(entityMap.get("phone")+"");//联系人电话（商客通400号）
			IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(entityMap.get("phone")+"");
			if(ivrEn !=null){
				agEn.setIvrType(ivrEn.getIvrType());
				agEn.setIvrPhone(ivrEn.getIvrPhone());
				agEn.setIvrKey(ivrEn.getIvrKey());
			}
			resultObject.put("agentEntiy",  agEn);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 写字楼详情页标题优化
	 * 写字楼出售	{区域+商圈+面积+写字楼出售}
	         写字楼出租	{区域+商圈+面积+写字楼出租}
	         写字楼新盘出售	{楼盘名称}
	         写字楼新盘出租	{楼盘名称}
	 * @param entityMap
	 * @return
	 */
	public String jsonDetailOfficeName(Map<String,Object> entityMap){
		String rentType=entityMap.get("rent_type")+"";
		String officeName="";
		String areaName =this.areasMapper.selectById(entityMap.get("area_id")+"");
		String regionName = this.regionsMapper.findNameById(entityMap.get("business_area_id")+"");
		String mianJi=entityMap.get("build_area")+""+entityMap.get("build_area_u");
		if(OfficeEnum.TypeSale.RENT.getValue().equals(rentType)){
			officeName=areaName+regionName+mianJi+"写字楼出租";
		}else if(OfficeEnum.TypeSale.SALE.getValue().equals(rentType)){
			officeName=areaName+regionName+mianJi+"写字楼出售";
		}else {
			officeName=entityMap.get("name")+"";
		}
		return officeName;
	}
	
	
	@Override
	public String getNodeName(String projectId,String projectType,String agentId){
		if(Objects.nonNull(agentId)){
			Map<String,Object> paraMap=new HashMap<String,Object>();
			paraMap.put("projectId", projectId);
			paraMap.put("projectType", projectType);
			paraMap.put("agentId", agentId);
			ProjectOrder projectEn=this.projectOrderMapper.findProjectEntity(paraMap);
			if(Objects.nonNull(projectEn)){
				return projectEn.getOrderStatus();
			}else{
				return "2";
			}
		}else{
			return "2";//普通用户登录
		}
	}

	
	@Override
	public void followLog(String projectId,String projectType,String loginUserId,ResultObject resultObject){
		logger.info("【查询跟进记录列表-开始==============入参projectType："+projectId+"=========projectType:"+projectType+"===resultObject:"+resultObject+"】");
		String nodes=resultObject.get("nodes")+"";
		String show=resultObject.get("show")+"";
		String myRoleType=resultObject.get("myRoleType")+"";//1-房源(发布者)；2-客源(跟进者)
		//查看列表
		resultObject.put("seeList", this.followTitleList(projectId, projectType, "2",nodes,show,"1",loginUserId));//联系可以看所有，不区分角色，所以默认为1
		//到访列表
		resultObject.put("recordList", this.followTitleList(projectId, projectType, "3",nodes,show,myRoleType,loginUserId));
		
		if(Objects.nonNull(loginUserId)){
			//经纪人登录
			//认购列表
			resultObject.put("renGouList", this.followTitleList(projectId, projectType, "4",nodes,show,myRoleType,loginUserId));
			//签约列表
			resultObject.put("signList", this.followTitleList(projectId, projectType, "5",nodes,show,myRoleType,loginUserId));
			//结佣列表
			resultObject.put("jieYongList", this.followTitleList(projectId, projectType, "6",nodes,show,myRoleType,loginUserId));
			//终止列表
			resultObject.put("completeList", this.followTitleList(projectId, projectType, "0",nodes,show,myRoleType,loginUserId));
		}else{
			//普通用户或者未登录用户
			resultObject.put("renGouList",new ArrayList<>());
			resultObject.put("signList",new ArrayList<>());
			resultObject.put("jieYongList",new ArrayList<>());
			resultObject.put("completeList",new ArrayList<>());
		}
		logger.info("【查询跟进记录列表-结束***************】");
	}

	/**
	 * 格式化标题
	 * @param orderStatus
	 * @param paraMap
	 * @param resultObject
	 * @myRoleType:1-房源；2-客源
	 * @return
	 */
	public List<Map<String,Object>>  followTitleList(String projectId,String projectType,String logStatus,
			String mainStatus,String show,String myRoleType,String loginUserId){
		List<Map<String,Object>> list=new ArrayList<Map<String,Object>>();
		Map<String,Object> paraMap=new HashMap<String,Object>();
		paraMap.put("orderStatus", logStatus);
		paraMap.put("projectId", projectId);
		paraMap.put("projectType", projectType);
		//如果是发布人-能看到所有人的到访-认购等记录；如果是跟进人-只能看到自己的到访记录
		if("2".equals(myRoleType)){
			paraMap.put("agentId", loginUserId);
		}
		List<Map<String,Object>> listA=this.projectOrderMapper.findTrackListByOid(paraMap);
		if(listA!=null && listA.size()>0 && listA.get(0) !=null){
			for(Map<String,Object> temp:listA){
				Map<String,Object> mapItem=new HashMap<String,Object>();
				mapItem.put("show",show);
				mapItem.put("orderNo", temp.get("order_no"));
				if("3".equals(logStatus)){
					//3到访
					mapItem.put("title", temp.get("customer_name")+"，到访成功");
				}else if("4".equals(logStatus)){
					//4认购
					mapItem.put("title", temp.get("customer_name")+"，认购成功");
				}else if("5".equals(logStatus)){
					//5签约
					mapItem.put("title", temp.get("customer_name")+"，成功签约");
				}else if("6".equals(logStatus)){
					//6结佣列表:王一博，结佣成功
					mapItem.put("title", temp.get("customer_name")+"，结佣成功");
				}else if("0".equals(logStatus)){
					//7终止列表:王一博：终止跟进[写字楼不满意]
					mapItem.put("title", temp.get("customer_name")+"，终止跟进["+temp.get("description")+"]");
				}else{
					//2查看：王一博，查看了经纪人的信息
					mapItem.put("title", temp.get("customer_name")+"，查看了经纪人的信息");
				}
				mapItem.put("agentId", temp.get("agent_id"));
				mapItem.put("imgs", temp.get("pic_path")==null?new ArrayList<>():Arrays.asList(String.valueOf(temp.get("pic_path")).split(",")));
				mapItem.put("createTime", temp.get("create_time"));
				list.add(mapItem);
			}
		}
		return list;
	}
	
	

	@Override
	public ResultObject findMyFollowOfficePage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			this.analysisLeftRight(paraMap);// 解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String) paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String) paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<PublishOfficeVo> list = this.officeMapper.findMyFollowOfficePage(paraMap);
			if (list != null && list.size() > 0) {
				for (PublishOfficeVo temp : list) {
					temp.setLabel(this.showInfoService.findLabelByObjId(temp.getId() + "", ProjectEnum.ProjectType.OFFICE.getValue(), OfficeEnum.OFFICE_LABEL_KEY));
					temp.setSumMyFollowList(this.getSumFiveStatusList(temp.getId()+"",ProjectEnum.ProjectType.OFFICE.getValue(),paraMap.get("agentId")+""));//联系1人+到访1人+认购1人
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}

	@Override
	@Transactional
	public ResultObject publishOffice(Map<String, Object> parameters,Office entity){
		ResultObject resultObject = new ResultObject();
		try {
			if("2".equals(parameters.get("singleFamily")+"") ){
				parameters.remove("floorCurrent");
			}
			String officeId="";
			//添加
			entity.setOfficeNumber(this.showInfoService.getNextCustomerID("F"));
			if(StringUtils.isNotEmpty(parameters.get("imgs")+"")){
				String[] imgsArr=String.valueOf(parameters.get("imgs")).split(",");
				entity.setCoverImg(imgsArr[0]);
			}
			if(parameters.get("rentType").equals("1") || parameters.get("rentType").equals("3")){
				entity.setMonthlyRent(this.jsMonthRent(parameters.get("dailyRent")+"", parameters.get("buildArea")+""));
			}
			CommissionEntity commEn=this.jsonCommission(parameters.get("channel")+"" , entity.getRentType()+"",parameters.get("commission")+"",parameters.get("commissionType")+"");
			if(commEn!=null){
				entity.setCommissionValue(commEn.getCommissionValue());
				entity.setCommission(commEn.getCommission());
			}
			if(Objects.isNull(entity.getName())){
				entity.setName(entity.getDeveloper());//app没有楼盘名称，所有填开发商
			}
			if( !ObjectHelpUtils.isMyNull(parameters.get("registers")+"")){
				entity.setRegister(parameters.get("registers")+"");//app ios特殊字符
			}
			//entity.setRegister(parameters.get("register")+"");
			//格式化标题-处理分页列表显示的特殊标题
			/*Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId());
				entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
				entity.setRegionName(this.regionsMapper.findNameById(entity.getBusinessAreaId()));
				Map<String,String> pcRes=this.jsonPcPageOfficeTitle(entity);
				entity.setTitlePc(pcRes.get("titlePc"));
				entity.setTitlePcSub(pcRes.get("titlePcSub"));
				Map<String,String> appRes=this.jsonAppPageOfficeTitle(entity);
				entity.setTitle(appRes.get("title"));
				entity.setTitleSub(appRes.get("titleSub"));*/
			this.formatting(entity);//格式化标题-处理分页列表显示的特殊标题
			entity.setCreateTime(new Date());
			this.officeMapper.saveOffice(entity);
			resultObject.put("id", entity.getId());
			officeId=entity.getId()+"";

			//配套
			if(!Objects.isNull(parameters.get("matchArr"))){
				List<Map<String, Object>> dicList=new ArrayList<Map<String, Object>>();
				String[] matchArr=String.valueOf(parameters.get("matchArr")).split(",");
				for(String d_value:matchArr){
					Map<String,Object> mapItem=new HashMap<String,Object>();
					mapItem.put("object_id", officeId);
					mapItem.put("d_value", d_value);
					mapItem.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
					mapItem.put("dic_type", OfficeEnum.OFFICE_MATCHE_KEY);
					dicList.add(mapItem);
				}
				this.officeDicMapper.saveAll(dicList);
			}
			//特色标签			
			List<Map<String, Object>> labelList=new ArrayList<Map<String, Object>>();
			String[] labelArr=String.valueOf(parameters.get("labelArr")).split(",");
			for(String d_value:labelArr){
				Map<String,Object> mapItem=new HashMap<String,Object>();
				mapItem.put("object_id", officeId);
				mapItem.put("d_value", d_value);
				mapItem.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
				mapItem.put("dic_type", OfficeEnum.OFFICE_LABEL_KEY);
				labelList.add(mapItem);
			}
			this.officeDicMapper.saveAll(labelList);
			Map<String, Object> approveStatus = this.contractService.selectApproveStatus(Integer.valueOf(parameters.get("agentId") + ""));
			if(null != approveStatus && !approveStatus.isEmpty()){
				String status = approveStatus.get("status")+"";
				logger.info("【是否电子签了，标识signFlag： "+status+"】");
				resultObject.put("signFlag",status);
				resultObject.put("url",approveStatus.get("url"));
			}

			//添加扩展表
			OfficeExtend officeExtend=new OfficeExtend();
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId());
			officeExtend.setOfficeId(Integer.valueOf(officeId));
			officeExtend.setAreaName(areasEn==null?"":areasEn.getAreaname());
			officeExtend.setBusinessName(this.regionsMapper.findNameById(entity.getBusinessAreaId()));
			officeExtend.setEditCount(0);
			this.officeExtendMapper.insertOfficeExtend(officeExtend);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	//app标题
	public Map<String,String> jsonAppPageOfficeTitle(Office entity)throws Exception{
		String rentType=entity.getRentType();
		Map<String,String> resMap=new HashMap<String,String>();
		String title="";
		String titleSub="";
		String areaName=entity.getAreaName();
		String resionsName=entity.getRegionName();
		String buildArea=entity.getBuildArea()+"";
		Map<String,Object> typeMap=new HashMap<String,Object>();
		typeMap.put("dValue", entity.getType());
		typeMap.put("parentKey", OfficeEnum.OFFICE_TYPE);
		String typeName=this.dictionaryMapper.selectByDValue(typeMap);
		String register="不可注册";
		if("2".equals(entity.getRegister())){
			register="可注册";
		}
		if(OfficeEnum.TypeSale.RENT.getValue().equals(rentType)){
			//租写字楼：区域+商圈l面积   [副标题]写字楼类型+可注册+类型（出租） areaRegion
			title=areaName+resionsName+"|"+buildArea+"㎡";
			titleSub=typeName+"|"+register+"出租";
		}else if(OfficeEnum.TypeSale.SALE.getValue().equals(rentType)){
			//买写字楼：区域+商圈l面积   [副标题]写字楼类型+可注册+类型（出售）
			title=areaName+resionsName+"|"+buildArea+"㎡";
			titleSub=typeName+"|"+register+"出售";
		}else {
			//楼盘名称  [副标题]区域-商圈|建面
			title=entity.getName(); 
			titleSub=areaName+resionsName+"|"+buildArea+"㎡";
		}
		resMap.put("title", title);
		resMap.put("titleSub", titleSub);
		logger.info("【格式主化标题为："+title+"】");
		logger.info("【格式主化标题为："+titleSub+"】");
		return resMap;
	}
	
	/**
	 * 	pc分页标题
	 * 	写字楼出售：	标题：楼盘/面积/可注册/可分割（不可注册、不可分割不显示）;副标题1：区域商圈;副标题2：写字楼类型
	 *	写字楼出租：	标题：楼盘/面积/可分割（不可分割不显示）;副标题1：区域商圈;副标题2：写字楼类型
	 *	写字楼新盘:		标题：楼盘;	副标题1：详细地址;副标题2：写字楼类型
	 * @param entity
	 * @return
	 * @throws Exception
	 */
	public Map<String,String> jsonPcPageOfficeTitle(Office entity)throws Exception{
		String rentType=entity.getRentType();
		Map<String,String> resMap=new HashMap<String,String>();
		String titlePc="";
		String buildArea=entity.getBuildArea()+"";
		String areaName=entity.getAreaName();
		String resionsName=entity.getRegionName();
		String register="";
		String separate="";
		if("2".equals(entity.getSeparate())){
			separate="/可分割";
		}
		if("2".equals(entity.getRegister())){
			register="/可注册";
		}
		
		if(OfficeEnum.TypeSale.RENT.getValue().equals(rentType)){
			//写字楼出售：	标题：楼盘/面积/可注册/可分割（不可注册、不可分割不显示）;副标题：区域商圈;
			titlePc=entity.getName()+"/"+buildArea+"㎡"+register+separate;
		}else if(OfficeEnum.TypeSale.SALE.getValue().equals(rentType)){
			//写字楼出租：	标题：楼盘/面积/可分割（不可分割不显示）;副标题：区域商圈;
			titlePc=entity.getName()+"/"+buildArea+"㎡"+separate;
		}else {
			//写字楼新盘:	标题：楼盘;	副标题：详细地址;
			titlePc=entity.getName(); 
		}
		resMap.put("titlePc", titlePc);
		resMap.put("titlePcSub", areaName+"，"+resionsName);
		return resMap;
	}
	
	
	
	
	//月租=日租*面积*365/12
	@Override
	public BigDecimal jsMonthRent(String dailyRent,String buildArea){
		logger.info("dailyRent:"+dailyRent+"===buildArea:"+buildArea);
		if( dailyRent !=null && !"".equals(dailyRent) && Objects.nonNull(dailyRent) && Objects.nonNull(buildArea)){
			BigDecimal dailyPrice=new BigDecimal(dailyRent);
			BigDecimal baPrice=new BigDecimal(buildArea);
			if(dailyPrice.compareTo(BigDecimal.ZERO)>0){
				BigDecimal mon=dailyPrice.multiply(baPrice).multiply(new BigDecimal(365)).divide(new BigDecimal(12),2,BigDecimal.ROUND_HALF_UP);
				logger.info("【月租=日租*面积*365/12     即    月租="+dailyPrice+"*"+baPrice+"*365/12="+mon+"】");
				return mon;
			}
			return new BigDecimal(0.00);
		}
		return new BigDecimal(0.00);
	}
	
	/**
	 * 发布的时候，格式化佣金
	 * @param rentType
	 * @param commission
	 * @param commissionType 佣金类型：1-百分比 2-直接填金额
	 * @return
	 */
	@Override
	public CommissionEntity jsonCommission(String channel,String rentType,String commission,String commissionType){
		CommissionEntity entity=new CommissionEntity();
		if("2".equals(commissionType)){
			entity.setCommission(commission+"元");
			entity.setCommissionValue(new BigDecimal(commission));
		}else{
			if(ShopEnum.RentType.RENT.getValue().equals(rentType) || ShopEnum.RentType.NEWS_RENT.getValue().equals(rentType)){
				entity.setCommission(commission+"个月的租金");
				entity.setCommissionValue(new BigDecimal(commission));
			}else{
				//出售，成本价
				entity.setCommission("成交价的"+commission+"%");
				BigDecimal valueLess=new BigDecimal(commission).divide(new BigDecimal(100),4, BigDecimal.ROUND_HALF_DOWN);
				entity.setCommissionValue(valueLess);//除100 佣金比
			}
		}
		return entity;
	}

	@Override
	public AgentEntity findAgentEntity(String agentId){
		AgentEntity entity=new AgentEntity();
		//经纪人信息
		Map<String, Object> aMap=this.userMapper.findAgentEntityById(agentId);
		if(aMap!=null){
			entity.setName(aMap.get("account_name")+"");
			entity.setCompany(aMap.get("corporate_name")+"");
			entity.setTel(aMap.get("account")+"");
			entity.setVip("已认证");
			if(ObjectHelpUtils.isMyNull(entity.getCompany())){
				entity.setCompany("经纪人");
			}
		}else{
			entity.setName("张三");
			entity.setTel("15200000000");
		}
		return entity;
	}
	
	
	@Override
	public ResultObject officeOut(Map<String,Object> params) {
		ResultObject resultObject=new ResultObject();
		try {
			officeMapper.updateOfficeOnlineStatus(params);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_ERROR);
			resultObject.setMessage("异常");
			e.printStackTrace();
		}
		return resultObject;
	}
	
	//格式化标题-处理分页列表显示的特殊标题
	public void formatting(Office entity)throws Exception{
		Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId());
		entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
		entity.setRegionName(this.regionsMapper.findNameById(entity.getBusinessAreaId()));
		Map<String,String> pcRes=this.jsonPcPageOfficeTitle(entity);
		entity.setTitlePc(pcRes.get("titlePc"));
		entity.setTitlePcSub(pcRes.get("titlePcSub"));
		Map<String,String> appRes=this.jsonAppPageOfficeTitle(entity);
		entity.setTitle(appRes.get("title"));
		entity.setTitleSub(appRes.get("titleSub"));
	}
	
	
	@Override
	@Transactional
	public ResultObject updatePublishOffice(Map<String, Object> parameters,Office entity){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> offMap=this.officeMapper.findEntity(parameters.get("id")+"");
			if(Objects.isNull(offMap)){
				resultObject.setCode(Constant.CODE_PARAM_ERROR);
				resultObject.setMessage("上送参数id["+parameters.get("id")+"]有误，查无数据");
				return resultObject;
			}
			
			/*IfEditResult iffEn=this.ifLimit(parameters.get("id")+"");
			if(!iffEn.getFalg()){
				resultObject.setCode(Constant.CODE_WARN);
				resultObject.setMessage("不可编辑，已达修改上限["+iffEn.getUpdNum()+"]");
				return resultObject;
			} */
			
			//Office entity=(Office)ObjectHelpUtils.setValToObj2(new Office(), offMap);
			//entity.setId(Integer.valueOf(parameters.get("id")+""));
			if("2".equals(parameters.get("singleFamily")+"") ){
				parameters.remove("floorCurrent");
			}
			if(StringUtils.isNotEmpty(parameters.get("imgs")+"")){
				String[] imgsArr=String.valueOf(parameters.get("imgs")).split(",");
				entity.setCoverImg(imgsArr[0]);
			}
			if(parameters.get("rentType").equals("1") || parameters.get("rentType").equals("3")){
				entity.setMonthlyRent(this.jsMonthRent(parameters.get("dailyRent")+"", parameters.get("buildArea")+""));
			}
			CommissionEntity commEn=this.jsonCommission(parameters.get("channel")+"" , entity.getRentType()+"",parameters.get("commission")+"",parameters.get("commissionType")+"");
			if(commEn!=null){
				entity.setCommissionValue(commEn.getCommissionValue());
				entity.setCommission(commEn.getCommission());
			}
			if(Objects.isNull(entity.getName())){
				entity.setName(entity.getDeveloper());//app没有楼盘名称，所有填开发商
			}
			if(!ObjectHelpUtils.isMyNull(parameters.get("registers")+"")){
				entity.setRegister(parameters.get("registers")+"");//app ios特殊字符
			}
			this.formatting(entity);//格式化标题
			//this.officeMapper.updateOffice(entity);
			
			if(!Objects.isNull(parameters.get("matchArr"))){
				//删掉之前的配套，重新插入关系表
				Map<String,Object>  delMap=new HashMap<String,Object>();
				delMap.put("objectId", parameters.get("id")+"");
				delMap.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
				delMap.put("dicType", OfficeEnum.OFFICE_MATCHE_KEY);
				this.officeDicMapper.deleteByOfficeId(delMap);
				//
				List<Map<String, Object>> dicList=new ArrayList<Map<String, Object>>();
				String[] matchArr=String.valueOf(parameters.get("matchArr")).split(",");
				for(String d_value:matchArr){
					Map<String,Object> mapItem=new HashMap<String,Object>();
					mapItem.put("object_id", parameters.get("id")+"");
					mapItem.put("d_value", d_value);
					mapItem.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
					mapItem.put("dic_type", OfficeEnum.OFFICE_MATCHE_KEY);
					dicList.add(mapItem);
				}
				this.officeDicMapper.saveAll(dicList);
			}
			
			if(!Objects.isNull(parameters.get("labelArr"))){
				//删掉之前的标签
				Map<String,Object>  delMap=new HashMap<String,Object>();
				delMap.put("objectId", parameters.get("id")+"");
				delMap.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
				delMap.put("dicType", OfficeEnum.OFFICE_LABEL_KEY);
				this.officeDicMapper.deleteByOfficeId(delMap);
				//
				List<Map<String, Object>> labelList=new ArrayList<Map<String, Object>>();
				String[] labelArr=String.valueOf(parameters.get("labelArr")).split(",");
				for(String d_value:labelArr){
					Map<String,Object> mapItem=new HashMap<String,Object>();
					mapItem.put("object_id", parameters.get("id")+"");
					mapItem.put("d_value", d_value);
					mapItem.put("type", ProjectEnum.ProjectType.OFFICE.getValue());
					mapItem.put("dic_type", OfficeEnum.OFFICE_LABEL_KEY);
					labelList.add(mapItem);
				}
				this.officeDicMapper.saveAll(labelList);
			}

		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 * 判断是否还允许编辑房源
	 * true-可以编辑；false-不可编辑
	 * @param officeId
	 * @return
	 */
	public IfEditResult ifLimit(String officeId){
		IfEditResult  res=new IfEditResult();
		OfficeExtend entity=this.officeExtendMapper.findEntityById(officeId);
		Integer  editCount=entity.getEditCount();
		if(entity!=null && entity.getEditCount() >0){
			SysParam sysParam=this.dictionaryMapper.findSysParam();
			if(sysParam !=null && sysParam.getUpdNum() !=0){
				if(editCount>=sysParam.getUpdNum()){
					res.setFalg(false);
				}
				res.setUpdNum(sysParam.getUpdNum());
			}
		}
		return res;
	}
	
	
		
}

