package com.up.zpb.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.mapper.ProjectConcatMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.service.AliPayService;
import com.up.zpb.service.CallCenterService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.NewsService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.OrderService;
import com.up.zpb.service.ProjectOrderService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.AgentEntity;
import com.up.zpb.vo.CallAgentInfo;
import com.up.zpb.vo.CallRecording;
import com.up.zpb.vo.ComShopNum;
import com.up.zpb.vo.JsCommission;
import com.up.zpb.vo.ProjectConcat;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.ProjectOrderTrack;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import com.up.zpb.vo.enums.ProjectEnum;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class OrderServiceImpl implements OrderService {

	private static final Logger logger = LoggerFactory.getLogger(OrderServiceImpl.class);

	@Autowired
	private ProjectOrderMapper projectOrderMapper;
	@Autowired
	private ProjectOrderService projectOrderService;
	@Autowired
	private UserMapper userMapper;
	@Autowired
	private ProjectConcatMapper projectConcatMapper;
	@Autowired
	private OfficeService  officeService;
	@Autowired
	private AliPayService aliPayService;
	@Autowired
	private CallCenterService callCenterService;
	@Autowired
	private LoanMapper loanMapper;
	@Autowired
	private DictionaryService dictionaryService;
	@Autowired
	private NewsService newsService;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private RegionsMapper regionsMapper;
	
	

	/**
	 * 查看一次生成一次记录
	 * 电话记录
	 */
	@Override
	public ResultObject seeProjectPhone(Map<String, Object> parameters,UserApp  loginUser){
		logger.info("【seeProjectPhone()=================================start】");
		ResultObject resultObject = new ResultObject();
		try {
			String channel=parameters.get("channel")+"";
			String loginUserId=parameters.get("agentId")+"";
			if(loginUser ==null){
				//如果从token里取不到，再从库里取
				AgentEntity loginCustUser=this.officeService.findAgentEntity(parameters.get("agentId")+"");
				if(loginCustUser==null){
					resultObject.setCode(Constant.CODE_WARN);
					resultObject.setMessage("登录人id("+parameters.get("agentId")+""+")有误，查无数据");
					return resultObject;
				}
				loginUser=new UserApp();
				loginUser.setId(Integer.valueOf(loginUserId));
				loginUser.setAccount(loginCustUser.getTel());
				loginUser.setAccountName(loginCustUser.getName());
			}
			
			
			ProjectConcat entity=new ProjectConcat();
			entity.setProjectId(Integer.valueOf(parameters.get("projectId")+""));
			entity.setProjectType(Integer.valueOf(parameters.get("projectType")+""));
			entity.setAgentId(Integer.valueOf(loginUserId));
			entity.setAgentName(loginUser.getAccountName());//登录人
			entity.setExt1(loginUser.getAccountName()+"查看了 联系人信息！");
			entity.setCreateTime(new Date());
			entity.setOrderStatus(ProjectEnum.OrderStatus.ORDER_BAOBEI.getValue());
			this.projectConcatMapper.saveEntity(entity);
			
			//生成一条projectOrder数据，【注意：在到访接口处理，访以后，必须删除第一条记录，否则我跟进的会重复有两条数据】
			ProjectOrder  order=this.projectOrderService.ifHaveCustomerProjectOrder(parameters.get("projectId")+"", parameters.get("projectType")+"", loginUserId);
			if(order==null){
				parameters.put("orderStatus", ProjectEnum.OrderStatus.ORDER_BAOBEI.getValue());
				parameters.put("payStatus", "-2");//为了删除重复记录
				order=(ProjectOrder)ObjectHelpUtils.setValToObj2(new ProjectOrder(), parameters);
				this.submitOrder(parameters,order);
			}
		
			//对接400 start
			ResultObject callResult=this.processAllCall(parameters.get("projectId")+"",parameters.get("projectType")+"",
					loginUser.getAccount(),null,channel,loginUser);
			resultObject.put("makeCallCode", callResult.getCode());
			resultObject.put("makeCallMsg", callResult.getMessage());
			//对接400 end
			
			//发一条站内信给联系人
			this.newsService.lianXiMsg(loginUserId, order.getProjectName(), order.getShopNumber(),order.getProjectType());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【seeProjectPhone()=================================end】");
		return resultObject;
	}
	
	/**
	 * 调用青牛400外呼接口
	 * @param projectId
	 * @param projectType
	 * @param customerPhone
	 * 1-我跟进的商铺：主叫-当前登录用户；被叫-发布人【传1个手机号，是当前登录人的手机号】
	 * 2-我发布的商铺：主叫-发布人；被叫-查勘人  【传两个手机号】
	 * 3-委托：主叫-分配到的当前经纪人；被叫-求购客户；【传两个手机号】
	 * @return
	 */
	@Override
	public ResultObject processAllCall(String projectId,String projectType,String zhuJiaoTel,String beiJiaoTel,
			String channel,UserApp  loginUser) {
		ResultObject resultObject = new ResultObject();
		logger.info("【===============================开始调processAllCall()接口啦=====start】");
		try {
			ComShopNum  numEn=this.projectOrderService.findComShopNum(projectId,projectType);
			if(numEn ==null){
				resultObject.setCode(Constant.CODE_WARN);
				resultObject.setMessage("项目id["+projectId+"]或项目类型["+projectType+"]有误，查无数据");
				return resultObject;
			}
			String shopNumber=numEn.getShopNumber();
			String pulishUserId=numEn.getPublishUserId();
			//商铺和写字楼联系电话打发布时填的联系人
			String dnisName=numEn.getLinkMan();
			beiJiaoTel=numEn.getLinkManTel();

			CallRecording record=new CallRecording();
			String sjType=this.dictionaryService.findByKey("549");
			if("2".equals(sjType)){
				//商客通
				record.setSjType("2");
			}else{
				//青牛
				resultObject=this.callCenterService.makeNoZuoXiCall(zhuJiaoTel, beiJiaoTel,dnisName);	
				record.setUuid(resultObject.get("sessionId")==null?"888"+System.currentTimeMillis():resultObject.get("sessionId")+"");
				record.setSjType("1");
			}
			//记录外呼录音，以便查看
			record.setCallNo(this.projectOrderService.findCallRecordingMaxId());//线索ID
			record.setProjectId(projectId);
			record.setProjectType(projectType);
			record.setShopNumber(shopNumber);
			record.setShopName(numEn.getProjectName()==null?"":numEn.getProjectName());
			record.setRentType(numEn.getRentType());

			//主叫人
			String shouUserId="";
			String aniName="未填";
			Map<String,Object> uMap=new HashMap<String,Object>();
			uMap.put("account", zhuJiaoTel);
			UserApp  userEn=this.userMapper.selectUserByAccount(uMap);
			if(userEn !=null){
				shouUserId=userEn.getId()+"";
				//加“内部”还是“外部”
				zhuJiaoTel=zhuJiaoTel+ this.getOwnStr(userEn.getOwn()+"");
				if(!StringUtils.isEmpty(userEn.getAccountName())){
					aniName=userEn.getAccountName();
				}else{
					aniName="未填";
				}
			}
			//（主叫人）受佣人
			record.setShouUserId(shouUserId);
			record.setAni(zhuJiaoTel);
			record.setAniName(aniName);
			
			//（被叫人）联系人
			record.setDnis(beiJiaoTel);
			record.setDnisName(dnisName);
			
			//让佣人
			String agentName="李四";
			String agentPhone="15210000000";
			UserApp  aUser=this.userMapper.selectById(Integer.valueOf(pulishUserId));
			if(aUser !=null && !StringUtils.isEmpty(aUser.getAccountName())){
				agentName=aUser.getAccountName();
				agentPhone=aUser.getAccount()+ this.getOwnStr(aUser.getOwn()+"");
			}
			record.setAgentId(pulishUserId);
			record.setAgentName(agentName);
			record.setAgentPhone(agentPhone);
			
			if(!ObjectHelpUtils.isMyNull(channel)){
				record.setChannel(channel);
			}
			record.setCityId(numEn.getCityId());
			record.setAreaId(numEn.getAreaId());
			record.setBusinessAreaId(numEn.getBusinessAreaId());
			String areaName =this.areasMapper.selectById(record.getAreaId());
			String businessName = this.regionsMapper.findNameById(record.getBusinessAreaId());
			record.setAreaName(areaName);
			record.setBusinessName(businessName);
			
			this.loanMapper.saveCallRecording(record);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【===============================结束调processAllCall()接口啦=====end】");
		//resultObject.put("zhuJiaoTel", zhuJiaoTel);
		return resultObject;
	}
	
	
	//0：外部 ；1：内部
	public String getOwnStr(String own){
		if("1".equals(own)){
			return "(内部)";
		}else{
			return "(外部) ";
		}
	}
	
	
	
	/**
	 * 新增到访
	 */
	@Override
	public ResultObject submitOrder(Map<String, Object> parameters,ProjectOrder project){
		logger.info("【首次到访=================================start】");
		ResultObject resultObject = new ResultObject();
		try {
			//删除联系生成的那条临时订单
			Map<String,Object> poMap=new HashMap<String,Object>();
			poMap.put("projectId",parameters.get("projectId") );
			poMap.put("projectType",parameters.get("projectType") );
			poMap.put("agentId",parameters.get("agentId") );
			poMap.put("payStatus","-2");
			ProjectOrder order=this.projectOrderMapper.findProjectEntity(poMap);
			if(order !=null){
				//到访的时候，删除查看的那条订单，重新生成新订单
				this.projectOrderMapper.deleteByPrimaryKey(order.getOrderNo());
				project.setOrderNo(order.getOrderNo());//能查询到就用旧的订单号
			}else{
				//新的订单号
				project.setOrderNo(ObjectHelpUtils.getRondam(12));
			}

			String orderNo=project.getOrderNo();
			if(ProjectEnum.ProjectType.SHOP.getValue().equals(project.getProjectType())){
				resultObject=this.projectOrderService.loadingShop(project,resultObject);
				if(Constant.CODE_SUCCESS != resultObject.getCode()){
					return resultObject;
				}
			}else if(ProjectEnum.ProjectType.OFFICE.getValue().equals(project.getProjectType())){
				this.projectOrderService.loadingOffice(project,resultObject);
				if(Constant.CODE_SUCCESS != resultObject.getCode()){
					return resultObject;
				}
			}else{
				this.projectOrderService.loadingCustomer(project,resultObject);
				if(Constant.CODE_SUCCESS != resultObject.getCode()){
					return resultObject;
				}
			}
			//获取经纪人名称
			AgentEntity agentEn=this.officeService.findAgentEntity(project.getAgentId());
			if(agentEn!=null){
				project.setAgentName(agentEn.getName());
			}
			//将订单号关联到联系表和勾搭表
			this.batchUpdateOrderNo(orderNo, project.getProjectId(), project.getProjectType(), project.getAgentId());
			this.batchCallRecordingOrderNo(orderNo, project.getProjectId(), project.getProjectType(), project.getAgentId());
			
			project.setAppointmentTime(new Date());
			project.setCreateTime(new Date());
			project.setUpdateTime(new Date());
			this.projectOrderMapper.saveProject(project);//新增主表
			//记录日志
			this.saveOrderLog(project, parameters);
			
			//发站内信 -到访
			if("3".equals(project.getOrderStatus())){
				Map<String,String> dyParam=new HashMap<String,String>();
				dyParam.put("appTitle", project.getProjectName());
				dyParam.put("projectName", project.getProjectName());
				dyParam.put("shopNumber", project.getShopNumber());
				dyParam.put("projectType", project.getProjectType());
				//让佣人-到访
				this.newsService.sendTouchMsg(project.getOrderStatus(), project.getPublishUserId(), dyParam);
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【首次到访=================================end】"+project.getOrderNo());
		return resultObject;
	}

	
	//将订单号关联到[查看]表(project_concat)
	public void batchUpdateOrderNo(String orderNo,String projectId,String projectType,String agentId){
		ProjectConcat  concatEn=new ProjectConcat();
		concatEn.setProjectId(Integer.valueOf(projectId));
		concatEn.setProjectType(Integer.valueOf(projectType));
		concatEn.setAgentId(Integer.valueOf(agentId));
		concatEn.setOrderNo(orderNo);
		this.projectConcatMapper.batchUpdateOrderNo(concatEn);
	}
	//将订单号关联到[勾搭]表(call_recording)
	public void batchCallRecordingOrderNo(String orderNo,String projectId,String projectType,String agentId){
		CallRecording  calEn=new CallRecording();
		calEn.setProjectId(projectId);
		calEn.setProjectType(projectType);
		calEn.setAgentId(agentId);
		calEn.setOrderNo(orderNo);
		this.projectOrderMapper.batchCallOrderNo(calEn);
	}
	
	
	/**
	 * 认购-签约-结佣
	 */
	@Override
	public ResultObject exchangeOrder(Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		logger.info("【exchangeOrder节点流转=================================start】");
		try {
			String orderNo=parameters.get("orderNo")+"";
			String orderStatus=parameters.get("orderStatus")+"";
			ProjectOrder  oldOrder=this.projectOrderService.findOrderByOrderSn(orderNo);
			if(oldOrder==null){
				resultObject.setCode(Constant.CODE_WARN);
				resultObject.setMessage("订单编号["+parameters.get("orderNo")+"]有误，查无数据");
				return resultObject;
			}
			
			oldOrder=(ProjectOrder)ObjectHelpUtils.setValToObj2(oldOrder, parameters);
			if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue() .equals(orderStatus)
					&& ("1".equals(oldOrder.getProjectType()) ||"2".equals(oldOrder.getProjectType()))
					&& "1".equals(oldOrder.getCommissionType())){
					//【1-百分比】签约，就必须传佣金比例+月租/成本价
					if(oldOrder.getRentType().equals(ProjectEnum.RentType.RENT.getValue())  || oldOrder.getRentType().equals(ProjectEnum.RentType.NEWS_RENT.getValue())){
						//月租
						if(Objects.isNull(parameters.get("monthlyRent"))){
							resultObject.setCode(Constant.CODE_PARAM_NULL);
							resultObject.setMessage("签约必须填写[月租]");
							return resultObject;
						}
					}else{
						if(Objects.isNull(parameters.get("price"))){
							resultObject.setCode(Constant.CODE_PARAM_NULL);
							resultObject.setMessage("签约必须填写[成本价]");
							return resultObject;
						}
					}
			}
			if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue() .equals(oldOrder.getOrderStatus())){
				//签约-计算佣金
				JsCommission jsEntity=this.projectOrderService.jsCommission(oldOrder.getProjectType(), oldOrder.getRentType(),oldOrder.getCommissionValue(),oldOrder.getMonthlyRent(), oldOrder.getPrice(),oldOrder.getCommissionType());
				if(jsEntity !=null){
					oldOrder.setCommissionTotal(jsEntity.getCommissionTotal());
					oldOrder.setFeeService(jsEntity.getFeeService());
					oldOrder.setTotalPrice(jsEntity.getTotalPrice());
				}
				//签约生成支付订单
				this.creteMemberOrder(oldOrder);
			}
			
			this.noticePhone(oldOrder);//结佣提醒
			
			//时间这一块儿处理  start
			if(ProjectEnum.OrderStatus.ORDER_BAOBEI.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setAppointmentTime(new Date());
			}else if(ProjectEnum.OrderStatus.ORDER_DAOFANG.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setVisitTime(new Date());
			}else if(ProjectEnum.OrderStatus.ORDER_RENGOU.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setSubscribeTime(new Date());
			}else if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setSignTime(new Date());
			}else if(ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setSettleTime(new Date());
			}else if(ProjectEnum.OrderStatus.ORDER_JIESU.getValue() .equals(oldOrder.getOrderStatus())){
				oldOrder.setFinishTime(new Date());
			}
			//时间这一块儿处理 end
			
			this.projectOrderMapper.updateProject(oldOrder);
			if("0".equals(parameters.get("channel")+"")){
				//更新状态,pc所有状态，包括终止都删除
				this.projectOrderMapper.updateIsDelByOrderNo(orderNo);
			}else{
				//更新状态 (删除之前的记录，除了终止合同保留记录),app;
				if( ! ProjectEnum.OrderStatus.ORDER_JIESU.getValue().equals(orderStatus)){
					this.projectOrderMapper.updateIsDelByOrderNo(orderNo);
				}
			}
			//记录日志
			this.saveOrderLog(oldOrder, parameters);
			//发站内信
			Map<String,String> dyParam=new HashMap<String,String>();
			dyParam.put("appTitle", oldOrder.getProjectName());
			dyParam.put("projectName", oldOrder.getProjectName());
			dyParam.put("shopNumber", oldOrder.getShopNumber());
			dyParam.put("projectType", oldOrder.getProjectType());
			
			if( ProjectEnum.OrderStatus.ORDER_SIGN.getValue().equals(orderStatus)){
				if(oldOrder.getPublishUserId().equals(parameters.get("loginUserId")+"") ){
					//1)签约：如果是“让”发起的签约，则站内信发给“受佣人”
					this.newsService.sendTouchMsg("9", oldOrder.getAgentId(), dyParam);
				}else{
					//2)签约：如果是“受”发起的签约，则站内信发给“让佣人”
					this.newsService.sendTouchMsg(orderStatus, oldOrder.getPublishUserId(), dyParam);
				}
			}else{
				//让佣人,每个节点都要发
				this.newsService.sendTouchMsg(orderStatus, oldOrder.getPublishUserId(), dyParam);
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【exchangeOrder节点流转=================================start】");
		return resultObject;
	}
	
	

	@Override
	public ResultObject jyExchangeOrder(String orderNo) {
		ResultObject resultObject = new ResultObject();
		try {
			ProjectOrder order = this.projectOrderService.findOrderByOrderSn(orderNo);
			if (order == null) {
				resultObject.setCode(Constant.CODE_WARN);
				resultObject.setMessage("订单编号[" + orderNo + "]有误，查无数据");
				return resultObject;
			}
			// 更新订单状态
			order.setOrderStatus("6");
			this.projectOrderMapper.updateProject(order);
			// 删除旧的记录日志
			this.projectOrderMapper.updateIsDelByOrderNo(orderNo);
			// 添加新的记录日志
			ProjectOrderTrack track = new ProjectOrderTrack();
			track.setOrderNo(orderNo);
			track.setCreateTime(new Date());
			track.setProjectName(order.getProjectName());
			Map<String, Object> aMap = this.userMapper.findAgentEntityById(order.getAgentId());
			if (Objects.nonNull(aMap) && Objects.nonNull(aMap.get("account_name"))) {
				track.setCustomerName(aMap.get("account_name") + "");
			} else {
				track.setCustomerName("张三");
			}
			track.setOrderStatus(order.getOrderStatus());
			track.setProjectId(order.getProjectId());
			track.setProjectType(order.getProjectType());
			track.setAgentId(order.getAgentId());
			this.projectOrderMapper.saveTrackLog(track);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}

		return resultObject;
	}
	
	
	
	
	/**
	 * 结佣生成支付订单
	 * @param order
	 */
	public void  creteMemberOrder(ProjectOrder order){
		if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue() .equals(order.getOrderStatus())){
			this.aliPayService.createOrder(Integer.valueOf(order.getAgentId()),null,null,Double.valueOf(order.getTotalPrice()+""),4,4,110100,order.getOrderNo());
			order.setPayMethod("2");
		}
	}
	
	public void noticePhone(ProjectOrder order){
		if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue().equals(order.getOrderStatus())){
			/*Map<String,String> msgMap=new HashMap<>();
			msgMap.put("name", order.getAgentName());
			msgMap.put("nameTwo", order.getAgentName());
			msgMap.put("money", order.getAgentName());
			AliSMS.sendCode(msgMap, mobiles, Constant.MLS_KEYUANQIANYUE_CODE);*/
		}
	}
	
	public void saveOrderLog(ProjectOrder  order,Map<String,Object> parameters){
		ProjectOrderTrack track=new ProjectOrderTrack();
		track.setOrderNo(order.getOrderNo());
		track.setCreateTime(new Date());
		track.setProjectName(order.getProjectName());
		Map<String, Object> aMap=this.userMapper.findAgentEntityById(order.getAgentId());
		if(Objects.nonNull(aMap) && Objects.nonNull(aMap.get("account_name"))){
			track.setCustomerName(aMap.get("account_name")+"");
		}else{
			track.setCustomerName("张三");
		}
		if(Objects.nonNull(parameters.get("description"))){
			track.setDescription(parameters.get("description")+"");
		}
		if(Objects.nonNull(parameters.get("picPath"))){
			track.setPicPath(parameters.get("picPath")+"");
		}
		track.setOrderStatus(order.getOrderStatus());
		track.setProjectId(order.getProjectId());
		track.setProjectType(order.getProjectType());
		track.setAgentId(order.getAgentId());
		this.projectOrderMapper.saveTrackLog(track);
	}
	
	
	
	
	
}

