package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.LookOfficeMapper;
import com.up.zpb.mapper.LookShopMapper;
import com.up.zpb.mapper.OfficeMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.mapper.customer.CustomerMapper;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.NewsService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ProjectOrderService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.AgentEntity;
import com.up.zpb.vo.Areas;
import com.up.zpb.vo.ComShopNum;
import com.up.zpb.vo.ConcatCustomerDetailsListVo;
import com.up.zpb.vo.ConcatDetailsListVo;
import com.up.zpb.vo.JsCommission;
import com.up.zpb.vo.LookOffice;
import com.up.zpb.vo.LookShop;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.ProjectOrderTrack;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.ShowYongJinDetail;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;
import com.up.zpb.vo.fourhundred.IvrKeyShow;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class ProjectOrderServiceImpl implements ProjectOrderService {

	private static final Logger logger = LoggerFactory.getLogger(ProjectOrderServiceImpl.class);

	@Autowired
	private ProjectOrderMapper projectOrderMapper;
	@Autowired
	private OfficeMapper officeMapper;
	@Autowired
	private ShopMapper shopMapper;
	@Autowired
	private CustomerMapper customerMapper;
	@Autowired
	private OfficeService officeService;
	@Autowired
	private ShowInfoService showInfoService;
	@Autowired
	private UserMapper userMapper;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private RegionsMapper regionsMapper;
	@Autowired
	private LookShopMapper lookShopMapper;
	@Autowired
	private LookOfficeMapper lookOfficeMapper;
	@Autowired
	private NewsService newsService;
	@Autowired
	private FourHundredService fourHundredService;
	@Autowired
	private DictionaryService dictionaryService;
	
	
	
	
	@Override
	public ResultObject saveTrackLog(Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		try {
			ProjectOrder  oldOrder=this.ifHaveCustomerProjectOrder(parameters.get("projectId")+"",parameters.get("projectType")+"",parameters.get("agentId")+"");
			if(oldOrder ==null ){
				logger.info("【首次到访=================================start】");
				ProjectOrder project=(ProjectOrder)ObjectHelpUtils.setValToObj2(new ProjectOrder(), parameters);
				project.setOrderNo(ObjectHelpUtils.getRondam(12));

				if(ProjectEnum.ProjectType.SHOP.getValue().equals(project.getProjectType())){
					this.loadingShop(project,resultObject);
					if(Constant.CODE_SUCCESS != resultObject.getCode()){
						return resultObject;
					}
				}else if(ProjectEnum.ProjectType.OFFICE.getValue().equals(project.getProjectType())){
					this.loadingOffice(project,resultObject);
					if(Constant.CODE_SUCCESS != resultObject.getCode()){
						return resultObject;
					}
				}else{
					this.loadingCustomer(project,resultObject);
					if(Constant.CODE_SUCCESS != resultObject.getCode()){
						return resultObject;
					}
				}
				
				project.setAppointmentTime(new Date());
				project.setCreateTime(new Date());
				project.setUpdateTime(new Date());
				this.projectOrderMapper.saveProject(project);//新增主表
				this.saveTrackLogItem(project,parameters);
				logger.info("【首次到访=================================end】");
			}else{
				logger.info("【非首次到访=================================start】");
				this.saveTrackLogItem(oldOrder,parameters);
				//更改状态
				ProjectOrder updateProjectEn=(ProjectOrder)ObjectHelpUtils.setValToObj2(oldOrder, parameters);
				String orderStatus=updateProjectEn.getOrderStatus().trim();
				if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue().equals(orderStatus)){
					JsCommission jsEntity=this.jsCommission(updateProjectEn.getProjectType(), updateProjectEn.getRentType(), updateProjectEn.getCommissionValue(),updateProjectEn.getMonthlyRent(), updateProjectEn.getPrice(),updateProjectEn.getCommissionType());
					if(jsEntity !=null){
						updateProjectEn.setCommissionTotal(jsEntity.getCommissionTotal());
						updateProjectEn.setFeeService(jsEntity.getFeeService());
						updateProjectEn.setTotalPrice(jsEntity.getTotalPrice());
					}
				}
                this.projectOrderMapper.updateProject(updateProjectEn);
				logger.info("【非首次到访=================================start】");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	//计算佣金值
	@Override
	public JsCommission jsCommission(String projectType, String rentType,BigDecimal commissionValue,
			BigDecimal monthlyRent,BigDecimal chengBenPrice,String commissionType){
		JsCommission entity=new JsCommission();
		BigDecimal commissionTotal=new BigDecimal(0.00);
		
		if("2".equals(commissionType)){//2-直接填金额
			commissionTotal=commissionValue;
		}else{
			if(ProjectEnum.ProjectType.SHOP.getValue().equals(projectType) ||ProjectEnum.ProjectType.OFFICE.getValue().equals(projectType) ){
				if(ProjectEnum.RentType.RENT.getValue().equals(rentType) || ProjectEnum.RentType.NEWS_RENT.getValue().equals(rentType)){
					//认购-月租金
					commissionTotal=monthlyRent.multiply(commissionValue);
					logger.info("【=============["+ProjectEnum.ProjectType.codeOf(projectType).getName()+"]佣金总额为["+commissionTotal+"]=月租["+monthlyRent+"]*["+commissionValue+"]】");
				}else{
					//认购 -成本价
					commissionTotal=chengBenPrice.multiply(commissionValue);
					logger.info("【=============["+ProjectEnum.ProjectType.codeOf(projectType).getName()+"]佣金总额为["+commissionTotal+"]=百分之["+commissionValue+"]的*成本价["+chengBenPrice+"]】");
				}
			}else{
				//认购-客源佣金值
				commissionTotal=commissionValue;
				logger.info("【=============[客源]佣金总额为["+commissionValue+"]】");
			}
		}
		//服务费=佣金*8%
		BigDecimal feeService=commissionTotal.multiply(new BigDecimal(0.08)).setScale(2,BigDecimal.ROUND_HALF_UP);
		logger.info("【服务费["+feeService+"]=佣金["+commissionTotal+"]*[8%]");
		//总价=佣金
		BigDecimal totalPrice=commissionTotal;
		
		entity.setCommissionTotal(commissionTotal);
		entity.setCommissionValue(commissionValue);
		entity.setFeeService(feeService);
		entity.setTotalPrice(totalPrice);
		return entity;
	}
	
	
	
	
	
	
	
	
	public void saveTrackLogItem(ProjectOrder  order,Map<String,Object> parameters){
		ProjectOrderTrack track=(ProjectOrderTrack)ObjectHelpUtils.setValToObj2(new ProjectOrderTrack(), parameters);
		track.setOrderNo(order.getOrderNo());
		track.setCreateTime(new Date());
		track.setProjectName(order.getProjectName());
		Map<String, Object> aMap=this.userMapper.findAgentEntityById(order.getAgentId());
		if(Objects.nonNull(aMap) && Objects.nonNull(aMap.get("account_name"))){
			track.setCustomerName(aMap.get("account_name")+"");
		}else{
			track.setCustomerName("张三");
		}
		//track.setOrderStatus(order.getOrderStatus());
		//track.setProjectId(order.getProjectId());
		//track.setProjectType(order.getProjectType());
		//track.setAgentId(order.getAgentId());
		this.projectOrderMapper.saveTrackLog(track);
	}
	
	
	//装载-商铺
	@Override
	public ResultObject loadingShop(ProjectOrder project,ResultObject resultObject){
		Map<String,Object> shopEn=this.shopMapper.findEntityById(project.getProjectId());
		if(shopEn==null){
			resultObject.setCode(Constant.CODE_WARN);
			resultObject.setMessage("项目id["+project.getProjectId()+"]或者商铺类型["+project.getProjectType()+"]有误，查无数据");
			logger.error("项目id["+project.getProjectId()+"]或者商铺类型["+project.getProjectType()+"]有误，查无数据");
			return resultObject;
		}
		project.setProjectName(shopEn.get("title")+"");
		project.setCommission(shopEn.get("commission")+"");
		if(Objects.nonNull(shopEn.get("commission_value"))){
			project.setCommissionValue(new BigDecimal(String.valueOf(shopEn.get("commission_value"))));
		}
		project.setCommissionType(shopEn.get("commission_type")+"");
		project.setRentType(shopEn.get("rent_type")+"");
		project.setShopNumber(shopEn.get("shop_number")+"");
		project.setPublishUserId(shopEn.get("agent_id")+"");
		project.setMobile(shopEn.get("phone")+"");
		return resultObject;
	}
	
	//装载-写字楼
	@Override
	public ResultObject loadingOffice(ProjectOrder project,ResultObject resultObject){
		Map<String,Object> officeEn=this.officeMapper.findEntity(project.getProjectId());
		if(officeEn==null){
			resultObject.setCode(Constant.CODE_WARN);
			resultObject.setMessage("项目id["+project.getProjectId()+"]或者写字楼类型["+project.getProjectType()+"]有误，查无数据");
			logger.error("项目id["+project.getProjectId()+"]或者写字楼类型["+project.getProjectType()+"]有误，查无数据");
			return resultObject;
		}
		project.setProjectName(officeEn.get("title")+"");
		project.setCommission(officeEn.get("commission")+"");
		if(Objects.nonNull(officeEn.get("commission_value"))){
			project.setCommissionValue(new BigDecimal(String.valueOf(officeEn.get("commission_value"))));
		}
		project.setCommissionType(officeEn.get("commission_type")+"");
		project.setRentType(officeEn.get("rent_type")+"");
		project.setShopNumber(officeEn.get("office_number")+"");
		project.setPublishUserId(officeEn.get("agent_id")+"");
		project.setMobile(officeEn.get("phone")+"");
		return resultObject;
	}
	
	//装载-客源
	@Override
	public ResultObject loadingCustomer(ProjectOrder project,ResultObject resultObject){
		Map<String,Object> customerEn =this.customerMapper.findEntityById(project.getProjectId());
		if(customerEn==null){
			resultObject.setCode(Constant.CODE_WARN);
			resultObject.setMessage("客源id["+project.getProjectId()+"]有误，查无数据");
			logger.error("客源id["+project.getProjectId()+"]有误，查无数据");
			return resultObject;
		}
		if( !ObjectHelpUtils.isMyNull(customerEn.get("city_id")+"") 
				&& !ObjectHelpUtils.isMyNull(customerEn.get("want_region")+"")){
			String city_id=String.valueOf(customerEn.get("city_id")).split(",")[0];
			String region_id=String.valueOf(customerEn.get("want_region")).split(",")[0];
			Areas areasEn = this.areasMapper.selectProvinceIdByCityId(city_id);
			String regionName = this.regionsMapper.findNameById(region_id);
			if (areasEn != null) {
				project.setProjectName(areasEn.getAreaname() + "|" + regionName);
			}
		}
		project.setCommission(customerEn.get("commission")+"元");
		project.setCommissionValue(new BigDecimal(customerEn.get("commission")+""));
		project.setCommissionType("2");
		project.setRentType(customerEn.get("rent_type")+"");
		project.setShopNumber("C"+project.getProjectId());
		project.setPublishUserId(customerEn.get("create_id")+"");
		project.setMobile(customerEn.get("create_tel")+"");
		return resultObject;
	}
	
	
	
	/**
	 * 查用某个用户，对某个项目是否已经到访过
	 * @param parameters
	 * @return
	 */
	@Override
	public ProjectOrder ifHaveCustomerProjectOrder(String projectId,String projectType,String agentId){
		Map<String,Object> poMap=new HashMap<String,Object>();
		poMap.put("projectId", projectId);
		poMap.put("projectType", projectType);
		poMap.put("agentId",agentId);
		ProjectOrder projectEn=this.projectOrderMapper.findProjectEntity(poMap);
		return projectEn;
	}
	
	
	@Override
	public ProjectOrder findOrderByOrderSn(String orderNo){
		Map<String,Object> oMap=new HashMap<String,Object>();
		oMap.put("orderNo", orderNo);
		return this.projectOrderMapper.findProjectEntity(oMap);
	}
	
	@Override
	public ResultObject remindMsg(Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		ProjectOrder order=this.findOrderByOrderSn(parameters.get("orderNo")+"");
		if(order ==null){
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage("订单编号("+parameters.get("orderNo")+")有误，查无数据");
			return resultObject;
		}
		
		Map<String,String>  dyParam=new HashMap<>();
		dyParam.put("shopNumber",order.getShopNumber());
		dyParam.put("appTitle",order.getProjectName());
		dyParam.put("projectType",order.getProjectType());
		resultObject=this.newsService.sendTouchMsg("6", order.getPublishUserId(), dyParam);
		/*
			 logger.info("【开始发短信接口，入参为：============================"+parameters+"】");
		try {
			String orderStatus=order.getOrderStatus();
			String projectType=order.getProjectType();//1-商铺 2-写字楼 3-客源
			String shopNumber=order.getShopNumber();
			String telephone=order.getMobile();
			String agentName=order.getAgentName();
			String content="";

			if(projectType.equals(ProjectEnum.ProjectType.SHOP.getValue()) || projectType.equals(ProjectEnum.ProjectType.OFFICE.getValue())){
				if(ProjectEnum.OrderStatus.ORDER_RENGOU.getValue().equals(orderStatus)){
					//4-认购
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）已认购房源（编号："+shopNumber+"）";
				}else if(ProjectEnum.OrderStatus.ORDER_SIGN.getValue().equals(orderStatus)){
					//5-签约
					content="【中国商办联卖联租平台】房源（编号："+parameters.get("shopNumber")+"）签约成功";
				}else if(ProjectEnum.OrderStatus.ORDER_JIESU.getValue().equals(orderStatus)){
					//0-终止流程	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）终止房源（编号："+shopNumber+"）的跟进";
				}else if(ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue().equals(orderStatus)){
					//6-提醒结佣	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）提醒您支付合作佣金（房源："+shopNumber+"））";
				}else if(ProjectEnum.OrderStatus.ORDER_COMPLETE.getValue().equals(orderStatus)){
					//7-结佣	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）已经结佣成功";
				}else{
					content="其他";
				}
			}else{
				//客源
				String customerName=order.getCustomerName();
				if(CustomerEnum.OrderStatus.CUSTOMER_RENGOU.getValue().equals(orderStatus)){
					//认购		
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）对客户"+customerName+"已认购";
				}else if(CustomerEnum.OrderStatus.CUSTOMER_SIGN.getValue().equals(orderStatus)){
					//签约	
					content="【中国商办联卖联租平台】客户XXX签约成功";
				}else if(CustomerEnum.OrderStatus.CUSTOMER_JIESU.getValue().equals(orderStatus)){
					//终止流程	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）终止客户"+customerName+"的跟进";
				}else if(CustomerEnum.OrderStatus.CUSTOMER_JIEYONG.getValue().equals(orderStatus)){
					//提醒结佣	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）提醒您支付合作佣金（客源："+customerName+"）";
				}else if(CustomerEnum.OrderStatus.CUSTOMER_COMPLETE.getValue().equals(orderStatus)){
					//结佣	
					content="【中国商办联卖联租平台】"+agentName+"经纪人（"+telephone+"）已经结佣成功";
				}else{
					content="其他";
				}
			}
			logger.info("remindMsg()发短信内容为：==========="+content);

		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【结束发短信接口，结果为：============================"+resultObject+"】");*/
		return resultObject;
	}
	
	@Override
	public ResultObject findProjectOrderPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			
			this.officeService.analysisLeftRight(paraMap);//解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.projectOrderMapper.findProjectOrderPage(paraMap);
			if(list!=null && list.size()>0){
				for(Map<String,Object> temp:list){
					temp.put("label",this.showInfoService.findLabelByObjId(temp.get("id")+"", ProjectEnum.ProjectType.OFFICE.getValue(), ShopEnum.SHOP_LABEL_KEY));
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * APP-follow
	 * 我跟进的商铺-联系-到访-认购-签约-结佣-详情列表接口
	 */
	@Override
	public ResultObject findConcatList(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		List<ConcatDetailsListVo> conCatList=new ArrayList<ConcatDetailsListVo>();
		try {
			List<Map<String,Object>> list= this.projectOrderMapper.findTrackListByOid(paraMap);
			String ifShow=this.jsonCustomerOnlyOne(paraMap.get("projectId")+"",paraMap.get("projectType")+"");
			if(list!=null && list.size()>0){
				for(Map<String,Object> temp:list){
					ConcatDetailsListVo entity=new ConcatDetailsListVo();
					entity.setRenGouUserId(temp.get("agent_id")+"");
					if( !ObjectHelpUtils.isMyNull(temp.get("description")+"")){
						entity.setTitle(temp.get("description")+"");
					}
					entity.setOrder_no(temp.get("order_no")+"");
					entity.setPot_id(temp.get("id")+"");
					entity.setCreate_time(temp.get("create_time")+"");
					if(Objects.nonNull(temp.get("pic_path"))){
						entity.setImgs(Arrays.asList(String.valueOf(temp.get("pic_path")).split(",")));
					}
					if(ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue().equals(temp.get("order_status")+"")){
						//结佣列表没有图片，所以显示签约的图片
						paraMap.put("orderNo", entity.getOrder_no());
						paraMap.put("orderStatus", ProjectEnum.OrderStatus.ORDER_SIGN.getValue());
						List<Map<String,Object>> listSign= this.projectOrderMapper.findSignImgs(paraMap);
						if(listSign!=null && listSign.size()>0 && Objects.nonNull(listSign.get(0).get("pic_path"))){
							entity.setImgs(Arrays.asList(String.valueOf(listSign.get(0).get("pic_path")).split(",")));
						}
					}
					
					ProjectOrder order=this.findOrderByOrderSn(entity.getOrder_no());
					if(order!=null){
						String price="0.00";
						if(ProjectEnum.RentType.RENT.getValue().equals(order.getRentType()) || ProjectEnum.RentType.NEWS_RENT.getValue().equals(order.getRentType())){
							price=order.getMonthlyRent()+"元";
						}else{
							price=order.getPrice()+"元";//成本价
						}
						if( ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue().equals(order.getOrderStatus())){
							price=order.getCommissionTotal()+"元";
						}
						entity.setPrice(price);
						entity.setRent_type(order.getRentType());
						entity.setOrderStatus(order.getOrderStatus());//订单状态，不是当前log日志状态，这样就是最新的终止状态
						entity.setCommissionType(order.getCommissionType());
					}
					
					entity.setIfShow(ifShow);
					conCatList.add(entity);
				}
			}
			AgentEntity  agenEntity=this.jsonPublishPeopleTel(paraMap.get("projectId")+"", paraMap.get("projectType")+"");
			resultObject.put("agentEntity",agenEntity);
			resultObject.put("ifShow",ifShow);
			resultObject.put("list", conCatList);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	//如果projectType=3，客源，需要判断有一人认购，则其他人不可以再认购，按钮隐藏。
	@Override
	public String jsonCustomerOnlyOne(String projectId,String projectType){
		String flag="show";
		if(ProjectEnum.ProjectType.CUSTOMER.getValue().equals(projectType)){
			//判断这个projectId是否已经有人购买了
			Map<String,Object> paraMap=new HashMap<String,Object>();
			paraMap.put("onlyOneCustomer","onlyOneCustomer");
			paraMap.put("projectId",projectId);
			paraMap.put("projectType",projectType);
			List<Map<String,Object>> list= this.projectOrderMapper.findTrackListByOid(paraMap);
			if(list !=null && list.size()>0){
				flag="hidden";
			}
		}
		return flag;
	}
	
	
	
	/**
	 * APP-publish
	 * 我【发布】的商铺-联系-到访-认购-签约-结佣-详情列表接口
	 * 除了签约能操作，其他节点都只能看看
	 * 我发布的商铺，看的是跟进人的电话（我跟进的商铺，看的是发布人的电话）
	 * @param 
	 */
	@Override
	public ResultObject findConcatBySeeList(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		List<ConcatCustomerDetailsListVo> conCatList=new ArrayList<ConcatCustomerDetailsListVo>();
		try {
			
			Map<String, Object> listMap =new HashMap<String, Object>();
			listMap.put("projectId", paraMap.get("projectId"));
			listMap.put("projectType", paraMap.get("projectType"));
			listMap.put("orderStatus", paraMap.get("orderStatus"));
			List<Map<String,Object>> list= this.projectOrderMapper.findTrackListByOid(listMap);
			if(list!=null && list.size()>0){
				for(Map<String,Object> temp:list){
					ConcatCustomerDetailsListVo entity=new ConcatCustomerDetailsListVo();
					entity.setOrder_no(temp.get("order_no")+"");
					entity.setPot_id(temp.get("id")+"");
					entity.setCreate_time(temp.get("create_time")+"");
					ProjectOrder order=this.findOrderByOrderSn(entity.getOrder_no());
					if(order !=null){
						String price="0.00";
						if(ProjectEnum.RentType.RENT.getValue().equals(order.getRentType()) || ProjectEnum.RentType.NEWS_RENT.getValue().equals(order.getRentType())){
							price=order.getMonthlyRent()+"元";
						}else{
							price=order.getPrice()+"元";//成本价
						}
						if( ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue().equals(order.getOrderStatus())){
							price=order.getCommission()+"元";
						}
						entity.setPrice(price);
						entity.setRent_type(order.getRentType());
						entity.setCommissionType(order.getCommissionType());
					}else{
						logger.info("【是联系次数，点进去不需要订单列表的，这是订单编号唯一为空的情况】");
					}
					entity.setOrderStatus(temp.get("order_status")+"");
					AgentEntity agentEntity=this.officeService.findAgentEntity(temp.get("agent_id")+"");
					if(agentEntity!=null){
						entity.setCompany(agentEntity.getCompany());
						entity.setName(agentEntity.getName());
						String sjType=this.dictionaryService.findByKey("549");
						if("2".equals(sjType)){
							//查找外显号
							IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(agentEntity.getTel());
							if(ivrEn !=null){
								entity.setIvrType(ivrEn.getIvrType());
								entity.setIvrPhone(ivrEn.getIvrPhone());
								entity.setIvrKey(ivrEn.getIvrKey());
							}
						}
						entity.setTel(agentEntity.getTel());//不同跟进人的电话(每一个跟进人的)
						entity.setVip(agentEntity.getVip());
					}
					conCatList.add(entity);
				}
			}
			resultObject.put("list", conCatList);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 格式化发布人的联系电话
	 * @param projectId
	 * @param projectType
	 * @return
	 */
	public AgentEntity jsonPublishPeopleTel(String projectId,String projectType){
		AgentEntity agentEntity=null;
		if(ProjectEnum.ProjectType.SHOP.getValue().equals(projectType)){
			//商铺发布人的电话(从我跟进的商铺进去)
			Map<String,Object> shopEn=this.shopMapper.findEntityById(projectId);
			if(Objects.nonNull(shopEn)){
				agentEntity=this.officeService.findAgentEntity(shopEn.get("agent_id")+"");
				agentEntity.setTel(shopEn.get("phone")+"");
			}
		}else if(ProjectEnum.ProjectType.OFFICE.getValue().equals(projectType)){
			//写字楼发布人的电话(从我跟进的商铺进去)
			Map<String,Object> officeEn=this.officeMapper.findEntity(projectId);
			if(Objects.nonNull(officeEn)){
				agentEntity=this.officeService.findAgentEntity(officeEn.get("agent_id")+"");
				agentEntity.setTel(officeEn.get("phone")+"");
			}
		}else{
			Map<String, Object> customerEn=this.customerMapper.findEntityById(projectId);
			if(Objects.nonNull(customerEn)){
				agentEntity=this.officeService.findAgentEntity(customerEn.get("create_id")+"");
				agentEntity.setTel(customerEn.get("create_tel")+"");
			}
		}
		String sjType=this.dictionaryService.findByKey("549");
		if("2".equals(sjType)){
			//查找外显号
			IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(agentEntity.getTel());
			if(ivrEn !=null){
				agentEntity.setIvrType(ivrEn.getIvrType());
				agentEntity.setIvrPhone(ivrEn.getIvrPhone());
				agentEntity.setIvrKey(ivrEn.getIvrKey());
			}
		}
		return agentEntity;
	}
	
	
	@Override
	public ResultObject findYjByOrderNo(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			ShowYongJinDetail entity=new ShowYongJinDetail();
			String orderNo=paraMap.get("orderNo")+"";
			ProjectOrder project=this.findOrderByOrderSn(orderNo);
			if(project==null){
				resultObject.setCode(Constant.CODE_PARAM_ERROR);
				resultObject.setMessage("上送参数有误，查无数据！");
				return resultObject;
			}
			entity.setCommissionText(project.getCommission());
			entity.setCommissionValue(project.getCommissionTotal());
			entity.setProjectName(project.getProjectName()+"["+ProjectEnum.ProjectType.codeOf(project.getProjectType()).getName()+"]"+ProjectEnum.RentType.codeOf(project.getRentType()).getName());
			entity.setFeeService(project.getFeeService());
			entity.setFeeServiceText("合作佣金*8%");
			entity.setOrderNo(project.getOrderNo());
			entity.setTotalPrice(project.getTotalPrice());
			resultObject.put("list", entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject signDetail(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			String pot_id=paraMap.get("pot_id")+"";
			ProjectOrderTrack entity=this.projectOrderMapper.findOrderLogEntityById(pot_id);
			Map<String,Object> resMap=new HashMap<String,Object>();
			if(entity!=null){
				if(StringUtils.isNotEmpty(entity.getPicPath())){
					resMap.put("picPathList",Arrays.asList(entity.getPicPath().split(",")));
				}else{
					resMap.put("picPathList","");
				}
				resMap.put("description", entity.getDescription());
				if(ProjectEnum.RentType.RENT.getValue().equals(entity.getRentType())
						 || ProjectEnum.RentType.NEWS_RENT.getValue().equals(entity.getRentType())){
					resMap.put("price", entity.getMonthlyRent()+"元");
				}else{
					resMap.put("price", entity.getPrice()+"元");
				}
				if(ProjectEnum.OrderStatus.ORDER_JIEYONG.getValue().equals(entity.getOrderStatus())){
					resMap.put("price", entity.getCommission()+"元");
				}
				resMap.put("rentType",entity.getRentType());
				resMap.put("createTime", entity.getCreateTime());
			}else{
				resMap.put("picPathList","");
				resMap.put("description","");
				resMap.put("price","");
				resMap.put("createTime","");
				resMap.put("rentType","");
			}
			resultObject.put("entity", resMap);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 
	[商铺]1、房源-租商铺;2、房源-买商铺;3、房源-租商业新盘;4、房源-买商业新盘
	[写字楼]5、房源-租写字楼;6、房源-买写字楼;7、房源-租写字楼新盘;8、房源-买写字楼新盘
	[客源]11、客源-买商铺;12、客源-租商铺;13、客源-租写字楼;14、客源-买写字楼;15、客源-租商业新盘;16、客源-买商业新盘;17、客源-租写字楼新盘;18、客源-买写字楼新盘
	 */
	@Override
	public ComShopNum findComShopNum(String projectId,String projectType){
		ComShopNum  entity=new ComShopNum();
		ProjectOrder project=new ProjectOrder();
		project.setProjectId(projectId);
		project.setProjectType(projectType);
		if(ProjectEnum.ProjectType.SHOP.getValue().equals(projectType)){
			Map<String,Object> shopEn=this.shopMapper.findEntityById(project.getProjectId());
			if(shopEn !=null){
				if( !ObjectHelpUtils.isMyNull(shopEn.get("mainName")+"")){
					//新盘楼盘名称1
					entity.setProjectName(shopEn.get("mainName")+"");
				}else if(!ObjectHelpUtils.isMyNull(shopEn.get("floor_name")+"")){
					//新盘楼盘名称2
					entity.setProjectName(shopEn.get("floor_name")+"");
				}else{
					entity.setProjectName(shopEn.get("shop_name")+"");
				}
				entity.setShopNumber(shopEn.get("shop_number")+"");
				entity.setCityId(shopEn.get("city_id")+"");
				entity.setAreaId(shopEn.get("area_id")+"");
				entity.setBusinessAreaId(shopEn.get("business_area_id")+"");
				entity.setRentType(shopEn.get("rent_type")+"");
				entity.setPublishUserId(shopEn.get("agent_id")+"");
				entity.setLinkManTel(shopEn.get("phone")+"");
				entity.setLinkMan(shopEn.get("linkman")+"");
			}else{
				logger.error("项目id["+project.getProjectId()+"]或者商铺类型["+project.getProjectType()+"]有误，查无数据");
			}
		}else if(ProjectEnum.ProjectType.OFFICE.getValue().equals(projectType)){
			Map<String,Object> officeEn=this.officeMapper.findEntity(project.getProjectId());
			if(officeEn !=null){
				entity.setProjectName(officeEn.get("name")+"");
				entity.setShopNumber(officeEn.get("office_number")+"");
				entity.setCityId(officeEn.get("city_id")+"");
				entity.setAreaId(officeEn.get("area_id")+"");
				entity.setBusinessAreaId(officeEn.get("business_area_id")+"");
				
				if(StringUtils.isNotEmpty(officeEn.get("rent_type")+"")){
					Integer typeIn=Integer.valueOf(officeEn.get("rent_type")+"")+4;
					//5、房源-租写字楼;6、房源-买写字楼;7、房源-租写字楼新盘;8、房源-买写字楼新盘
					entity.setRentType(typeIn+"");
				}
				entity.setPublishUserId(officeEn.get("agent_id")+"");
				entity.setLinkManTel(officeEn.get("phone")+"");
				entity.setLinkMan(officeEn.get("linkman")+"");
			}else{
				logger.error("项目id["+project.getProjectId()+"]或者写字楼类型["+project.getProjectType()+"]有误，查无数据");
			}
			
		}else if(ProjectEnum.ProjectType.CUSTOMER.getValue().equals(projectType)){
			
			Map<String,Object> customerEn =this.customerMapper.findEntityById(project.getProjectId());
			if(customerEn !=null){
				String qStr=customerEn.get("want_area")+"";
				String sStr=customerEn.get("want_region")+"";
				String quYu="";
				String shangQuan="";
				if( !ObjectHelpUtils.isMyNull(qStr) && !ObjectHelpUtils.isMyNull(sStr)){
					quYu=qStr.split(",")[0];
					shangQuan=sStr.split(",")[0];
					Areas areasEn = this.areasMapper.selectProvinceIdByCityId(quYu);
					String regionName = this.regionsMapper.findNameById(shangQuan);
					if (areasEn != null) {
						project.setProjectName(areasEn.getAreaname() + "|" + regionName);
					}
				}
				
				//11、客源-商铺求购；12、客源-商铺求租；13、客源-写字楼求租；14、客源-写字楼求购；
				String rentTypeAll="";
				//if_shop 1-商铺 2-写字楼
				//request_type  1-求租 2-求购
				String if_shop=customerEn.get("if_shop")+"";
				String request_type=customerEn.get("request_type")+"";
				//String rent_type=customerEn.get("rent_type")+"";
				if("1".equals(if_shop)){
					if("1".equals(request_type)){
						//求租
						rentTypeAll="12";
					}else{
						//求购
						rentTypeAll="11";
					}
				}else{
					if("1".equals(request_type)){
						//求租
						rentTypeAll="13";
					}else{
						//求购
						rentTypeAll="14";
					}
				}
				
				entity.setRentType(rentTypeAll);
				entity.setProjectName("客源"+project.getProjectId());
				entity.setShopNumber(project.getProjectId());
				entity.setCityId("110100");//客源现在只能委托北京
				entity.setAreaId(quYu);
				entity.setBusinessAreaId(shangQuan);
				entity.setPublishUserId(customerEn.get("create_id")+"");
				entity.setLinkManTel(customerEn.get("create_tel")+"");
				entity.setLinkMan(customerEn.get("create_user")+"");
			}else{
				logger.error("客源id["+project.getProjectId()+"]有误，查无数据");
			}
		}else{
			String rentType="0";
			String projectName="";
			String areaId="";
			String businessAreaId="";
			String publishUserId="";
			String linkman="王五";
			String linkmanTel="18810000000";
			if(projectId.contains("ls")){
				//look_shop----------------start
				String lookId=projectId.substring(projectId.indexOf("_")+1,projectId.length());
				LookShop  lsEn=this.lookShopMapper.findEntityById(lookId);
				if("1".equals(lsEn.getHelpType())){
					//(帮我找铺) 20-委托-(帮我找铺)买商铺;21-委托-(帮我找铺)租商铺;22-委托-(帮我找铺)买商业新盘;23-委托-(帮我找铺)租商业新盘
					Integer tt=Integer.valueOf(lsEn.getTypes())+19;
					rentType=tt+"";
				}else{
					//(帮我出租) 30-委托-(帮我出租)买商铺;31-委托-(帮我出租)租商铺;32-委托-(帮我出租)买商业新盘;33-委托-(帮我出租)租商业新盘;
					Integer tt=Integer.valueOf(lsEn.getTypes())+29;
					rentType=tt+"";
				}
				
				projectName=lsEn.getAreaName()+lsEn.getRegionsName()+ShopEnum.LookShopTypes.codeOf(lsEn.getTypes()).getName();
				areaId=lsEn.getAreaId()+"";
				businessAreaId=lsEn.getRegionsId()+"";
				publishUserId=lsEn.getUserId()+"";
				linkman=lsEn.getUserName();
				linkmanTel=lsEn.getTelephone();
				//look_shop----------------end
			}else{
				//look_office----------------start
				String lookId=projectId.substring(projectId.indexOf("_")+1,projectId.length());
				LookOffice  lsOf=this.lookOfficeMapper.findEntityById(lookId);
				if(projectId.contains("ls")){
					//(帮我找铺) 24-委托-(帮我找铺)买写字楼;25-委托-(帮我找铺)租写字楼;26-委托-(帮我找铺)买写字楼新盘;27-委托-(帮我找铺)租写字楼新盘;
					Integer tt=Integer.valueOf(lsOf.getTypes())+23;
					rentType=tt+"";
				}else{
					//(帮我找铺) 34-委托-(帮我出租)买写字楼;35-委托-(帮我出租)租写字楼;36-委托-(帮我出租)买写字楼新盘;37-委托-(帮我出租)租写字楼新盘;
					Integer tt=Integer.valueOf(lsOf.getTypes())+33;
					rentType=tt+"";
				}
				projectName=lsOf.getAreaName()+lsOf.getRegionsName()+OfficeEnum.LookOfficeTypes.codeOf(lsOf.getTypes()).getName();
				areaId=lsOf.getAreaId()+"";
				businessAreaId=lsOf.getRegionsId()+"";
				publishUserId=lsOf.getUserId()+"";
				linkman=lsOf.getUserName();
				linkmanTel=lsOf.getTelephone();
				//look_office----------------end
			}
			entity.setRentType(rentType);
			entity.setProjectName(projectName);
			entity.setShopNumber(project.getProjectId());
			entity.setCityId("110100");//委托目前前台页面不支持切换城市，只有北京
			entity.setAreaId(areaId);
			entity.setBusinessAreaId(businessAreaId);
			entity.setPublishUserId(publishUserId);
			entity.setLinkManTel(linkmanTel);
			entity.setLinkMan(linkman);
		}
		return entity;
	}
	
	/**
	 * 获取录音表下一个流水号
	 * @return
	 */
	@Override
	public String findCallRecordingMaxId(){
		String orderCall="";
	    SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyMMdd");//yyyyMMddHHmmssSSS
    	String generateDate = simpleDateFormat.format(new Date());
    	String  maxId=this.projectOrderMapper.findCallRecordingMaxId();
    	if(maxId.length()<11){
    		//今天的第一条，需要用日期+5位数字
    		String five= ObjectHelpUtils.formatFiveNum(Integer.valueOf(maxId));
    		orderCall=generateDate+five;
    	}else{
    		//今天之后的每一条直接增1
    		orderCall=maxId+"";
    	}
    	return orderCall;
	}
	
	
	
	
}

