package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AppDataMapper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.CrmCustomerMapper;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.ShopBusinessTypeMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.ShopRentingMapper;
import com.up.zpb.service.AsynSaveCrmService;
import com.up.zpb.service.ShopPublishService;
import com.up.zpb.util.UpzlUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.ShopRenting;

@Service
public class ShopPublishServiceImpl implements ShopPublishService{
	
	private static final Logger logger = LoggerFactory.getLogger(ShopPublishServiceImpl.class);
	
	private final String default_shop_img = "https://youpu-global.oss-cn-beijing.aliyuncs.com/shop_default.jpg";
	
	@Autowired
	private ShopMapper shopMapper;
	
	@Autowired
	private ShopRentingMapper shopRentingMapper;
	
	@Autowired
	private AreasMapper areasMapper;
	
	@Autowired
	private BusinessAreaMapper businessAreaMapper;
	
	@Autowired
	private ShopBusinessTypeMapper shopBusinessTypeMapper;
	
	@Autowired
	private DictionaryMapper dictionaryMapper;
	
	@Autowired
	private AsynSaveCrmService asynSaveCrmService;
	
	@Autowired
	private CrmCustomerMapper crmCustomerMapper;
	
	@Autowired
	private AppDataMapper appDataMapper;

	@Override
	public ResultObject getPublishCount(Map<String, Object> parameters) {
		logger.info("ShopPublishServiceImpl getPublishCount parameters:{}",parameters);
		ResultObject resultObject = new ResultObject();
		try {
			int publishCount =0;
			SimpleDateFormat format=new SimpleDateFormat("yyyy-MM-dd");
			Calendar c = Calendar.getInstance();    
			c.add(Calendar.MONTH, 0);
			c.set(Calendar.DAY_OF_MONTH,1);//设置为1号,当前日期既为本月第一天 
			String first = format.format(c.getTime());
			Date begin = format.parse(first);
			begin = UpzlUtils.beginTimeHelper(begin);
			Calendar ca = Calendar.getInstance();    
			ca.set(Calendar.DAY_OF_MONTH, ca.getActualMaximum(Calendar.DAY_OF_MONTH));//获取当前月最后一天
			String last = format.format(ca.getTime());
			Date end = format.parse(last);
			end = UpzlUtils.endTimeHelper(end);
			parameters.put("begin", begin);
			parameters.put("end", end);
			parameters.put("flag", 0);
			String type = parameters.get("type").toString();
			//0:商铺出租 1:商铺转让 2:商铺求租
			if(StringUtils.equals("0", type) || StringUtils.equals("1", type) ) {
			    publishCount = shopMapper.getPublishCount(parameters);
			}else if(StringUtils.equals("2", type)){
				publishCount =shopRentingMapper.getRentingCount(parameters);
	         }
			boolean b=true;
			if(publishCount< 3) {//小于3次可以发布
				resultObject.put("flag", b);
			}else {
				b=false;
				resultObject.put("flag", b);
				resultObject.put("msg", "您当月的转让和出租发布权限已用尽，不可以再次发布！");
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return resultObject;
	}

	@Override
	public ResultObject createShop(Map<String, Object> parameters) {
		logger.info("ShopPublishServiceImpl createShop parameters:{}",parameters);
		ResultObject resultObject = new ResultObject();
		Integer areaId = Integer.valueOf(parameters.get("areaId").toString());
		Integer businessAreaId = Integer.valueOf(parameters.get("businessAreaId").toString());
		Integer cityId = Integer.valueOf(parameters.get("cityId").toString());
		String phone = parameters.get("paramPhone").toString();
		String linkMan = parameters.get("linkMan").toString();
		if(StringUtils.equals("2", parameters.get("type").toString())) {
			//求租
			ShopRenting sr = new ShopRenting();
			//区域
			sr.setAreaId(areaId);
			//商圈
			sr.setBusinessAreaId(businessAreaId);
			//手机号
			sr.setPhone(phone);
			//联系人
			sr.setName(linkMan);
			// 面积下限
			sr.setAreaLower(new BigDecimal(parameters.get("areaLower").toString()));
			// 面积上限
			sr.setAreaUpper(new BigDecimal(parameters.get("areaUpper").toString()));
			//市
			sr.setCityId(cityId);
			//发布时间
			sr.setCreateTime(new Date());
			// 月租金下限
			sr.setMonthlyRentLower(new BigDecimal(parameters.get("monthlyRentLower").toString()));
			// 月租金上限
			sr.setMonthlyRentUpper(new BigDecimal(parameters.get("monthlyRentUpper").toString()));
			// 一级业态
			sr.setParentManageTypeId(Integer.valueOf(parameters.get("parentManageType").toString()));
			// 二级业态
			sr.setSonManageTypeId(Integer.valueOf(parameters.get("sonManageType").toString()));
			// 商铺类型
			sr.setType(Integer.valueOf(parameters.get("shopType").toString()));
			shopRentingMapper.createShopRenting(sr);
			int count = crmCustomerMapper.selectByPhone(parameters);
			if(0==count) {
				asynSaveCrmService.saveCrm(sr);
			}
		}else {
			//出租/转让
			Shop sp = new Shop();
			//区域
			sp.setAreaId(areaId);
			//手机号
			sp.setPhone(phone);
			//商圈
			sp.setBusinessAreaId(businessAreaId);
			//城市
			sp.setCityId(cityId);
			//地址
			sp.setRealAddress(parameters.get("address").toString());
			//面积
			sp.setBuildArea(new BigDecimal(parameters.get("area").toString()));
			//月租金
			sp.setMonthlyRent(new BigDecimal(parameters.get("monthlyRent").toString()));
			//联系人
			sp.setLinkman(linkMan);
			//转让费
			if(StringUtils.equals("1", parameters.get("type").toString())) {
				if(StringUtils.equals("1", parameters.get("transfeeFlag").toString())) {
					sp.setTransferFee(new BigDecimal("-2"));
				}else {
					BigDecimal fee = new BigDecimal(parameters.get("transfee").toString());
					sp.setTransferFee(fee);
				}
			}
			//图片
			sp.setImgs(parameters.get("imgs").toString());
			//租售类型(0:商铺出租 1:商铺转租/生意转让)
			sp.setRentType(Integer.parseInt(parameters.get("type").toString()));
			//发布时间
			sp.setCreateTime(new Date());
			//商铺来源 9 发布
			sp.setCreateType(9);
			//商铺状态 待认领
			sp.setShopFlow(0);
			//1 展示
			sp.setShowFlag(1);
			//商铺租售状态(默认租赁中)
			sp.setStatus(0);
			//分时出租(默认为否)
			sp.setTimeRent(0);
			//是否分隔(默认为否)
			sp.setSeparate(false);
			//是否临主干道/两车道以上道路(默认为是)
			sp.setFrontage(true);
			//经营状态(默认营业中)
			sp.setManageStatus(1);
			shopMapper.createShop(sp);
		}
		return resultObject;
	}

	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject getAreas(Map<String, Object> parameters) {
		logger.info("ShopPublishServiceImpl getAreas parameters:{}",parameters);
		ResultObject resultObject = new ResultObject();
		List<Map<?, ?>> areas = Lists.newArrayList();
		areasMapper.selectByParentId(parameters.get("cityId").toString()).forEach(a -> {
				Map<String, Object> c1 = Maps.newHashMap();
				c1.put("id", a.get("id"));
				c1.put("name", a.get("area_name"));
				List<Map<?, ?>> childList = Lists.newArrayList();
				businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
					Map<String, Object> c2 = Maps.newHashMap();
					c2.put("childId", ba.get("id"));
					c2.put("childName", ba.get("name"));
					childList.add(c2);
				});
			 //出租/转让移除不限	
				if(StringUtils.equals("0", parameters.get("type").toString())) {
					for(int i=0;i<childList.size();i++) {
						String name = (String) childList.get(i).get("childName");
						if(StringUtils.equals("不限", name)) {
							childList.remove(i);
						}
					}
				}
				c1.put("childList", childList);
				areas.add(c1);
			});
			resultObject.put("areas", areas);
		 
		  if(StringUtils.equals("2", parameters.get("type").toString())) {
			  List<Map<?, ?>> shopBusinessTypes = Lists.newArrayList();
			  shopBusinessTypeMapper.selectByPid("").forEach(b -> {
				Map<String, Object> c1 = Maps.newHashMap();
				c1.put("id", b.get("id"));
				c1.put("name", b.get("name"));
				List<Map<?, ?>> childList = Lists.newArrayList();
				Map<String, Object> topMap = Maps.newHashMap();
				topMap.put("childId", b.get("id"));
				topMap.put("childName", "不限");
				childList.add(topMap);
				shopBusinessTypeMapper.selectByPid(b.get("id").toString()).forEach(bb -> {
					Map<String, Object> c2 = Maps.newHashMap();
					c2.put("childId", bb.get("id"));
					c2.put("childName", bb.get("name"));
					childList.add(c2);
				});
				c1.put("childList", childList);
				shopBusinessTypes.add(c1);
			});
				resultObject.put("shopBusinessTypes", shopBusinessTypes);
				resultObject.put("type",dictionaryMapper.selectMapByParentKey("133"));
			}
		return resultObject;
	}

	@Override
	public ResultObject getPublishList(Map<String, Object> parameters) {
		logger.info("ShopPublishServiceImpl getPublishList parameters:{}",parameters);
		ResultObject resultObject = new ResultObject();
		List<Map<String, Object>> publishList= new ArrayList<Map<String, Object>>();
		Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
		resultObject.put("serviceTel", appData.get("service_tel"));//咨询服务热线
		Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
		Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
		Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
		if(StringUtils.equals("2", parameters.get("type").toString())) {
			List<Map<String, Object>> list = shopRentingMapper.selectPublishList(parameters);
			for(Map<String, Object> map :list) {
				map.put("monthlyRentLower", new BigDecimal(map.get("monthly_rent_lower").toString()).divide(new BigDecimal(10000)).setScale(2, BigDecimal.ROUND_HALF_UP));// 月租金下限
				map.put("monthlyRentUpper", new BigDecimal(map.get("monthly_rent_upper").toString()).divide(new BigDecimal(10000)).setScale(2, BigDecimal.ROUND_HALF_UP));// 月租金上限
				map.remove("monthly_rent_lower");
				map.remove("monthly_rent_upper");
				publishList.add(map);
			   }
			resultObject.put("publishList", publishList);
		}else {
			List<Map<String, Object>> list = shopMapper.selectPublishList(parameters);	
			// 商铺图片
			String img = StringUtils.EMPTY;
			for(Map<String, Object> map :list) {
				if (Objects.nonNull(map.get("cover"))) {
					 img = map.get("cover").toString();
				 } else if (Objects.nonNull(map.get("imgs"))) {
					String imgStr = map.get("imgs").toString();
					String[] split = imgStr.split(",");
					img = split[0].replace("style/watermark", "style/thumbnail");
				} else {
					img = default_shop_img;
				}
				map.put("img", img);
				map.remove("cover");
				map.remove("imgs");
				publishList.add(map);
			}
			resultObject.put("publishList", publishList);
		}
		resultObject.put("totalCount", startPage.getTotal());
		return resultObject;
	}

	@Override
	public ResultObject delShop(Map<String, Object> parameters) {
		logger.info("ShopPublishServiceImpl delShop parameters:{}",parameters);
		ResultObject resultObject = new ResultObject();
		if(StringUtils.equals("2", parameters.get("type").toString())) {
			shopRentingMapper.delShop(parameters);
		}else {
			shopMapper.delShop(parameters);
		}
		return resultObject;
	}
	

}
