package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.RandomUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AppDataMapper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BrowseRecordsMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.CrmCustomerMapper;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.MemberMapper;
import com.up.zpb.mapper.OfficeDicMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.ShopBusinessTypeMapper;
import com.up.zpb.mapper.ShopConditionMapper;
import com.up.zpb.mapper.ShopCorrectionMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.ShopMyselfMapper;
import com.up.zpb.mapper.ShopRecordsMapper;
import com.up.zpb.mapper.ShopRentingMapper;
import com.up.zpb.mapper.SolicitingRecordMapper;
import com.up.zpb.mapper.UserCorrectMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.mapper.UserOperRecordsMapper;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.OfficeDicService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ProjectOrderService;
import com.up.zpb.service.ShopService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.AgentEntity;
import com.up.zpb.vo.BrowseRecords;
import com.up.zpb.vo.MyPublishPC;
import com.up.zpb.vo.OfficeDetailApp;
import com.up.zpb.vo.PublishShopVo;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.ShopCorrection;
import com.up.zpb.vo.ShopMyself;
import com.up.zpb.vo.ShopRecords;
import com.up.zpb.vo.SolicitingRecord;
import com.up.zpb.vo.UserCorrect;
import com.up.zpb.vo.UserOperRecords;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;
import com.up.zpb.vo.fourhundred.IvrKeyShow;

/**
 * 商铺相关
 * 
 * @author gust
 *
 */
@Service
public class ShopServiceImpl implements ShopService {

	private static final Logger logger = LoggerFactory.getLogger(ShopServiceImpl.class);

	public final static String img_head = ConfigurationUtils.getStringValue("bank_img");
	
	//private final String default_shop_img = "https://youpu-global.oss-cn-beijing.aliyuncs.com/shop_default.jpg";

	@Autowired
	private ShopMapper shopMapper;

	@Autowired
	private AreasMapper areasMapper;
	
	@Autowired
	private RegionsMapper regionsMapper;

	@Autowired
	private BusinessAreaMapper businessAreaMapper;

	@Autowired
	private ShopBusinessTypeMapper shopBusinessTypeMapper;

	@Autowired
	private ShopConditionMapper shopConditionMapper;

	@Autowired
	private ShowInfoService showInfoService;

	@Autowired
	private AppDataMapper appDataMapper;
	
	@Autowired
	private BrowseRecordsMapper browseRecordsMapper;
	
	@Autowired
	private ShopCorrectionMapper shopCorrectionMapper;
	
	@Autowired
	private MemberMapper memberMapper;
	
	@Autowired
	private UserCorrectMapper userCorrectMapper;
	
	@Autowired
	private ShopMyselfMapper  shopMyselfMapper;
	
	@Autowired
	private ShopRecordsMapper shopRecordsMapper;
	
	@Autowired
	private CrmCustomerMapper crmCustomerMapper;
	
	@Autowired
	private SolicitingRecordMapper solicitingRecordMapper;
	
	@Autowired
	private ShopRentingMapper shopRentingMapper;

	@Autowired
	UserMapper userMapper;
	
	@Autowired
	UserOperRecordsMapper userOperRecordsMapper;
	@Autowired
	private DictionaryMapper dictionaryMapper;
	@Autowired
	private OfficeService officeService;
	@Autowired
	private OfficeDicService officeDicService;
	@Autowired
	private ProjectOrderMapper projectOrderMapper;
	@Autowired
	private ProjectOrderService projectOrderService;
	@Autowired
	private OfficeDicMapper officeDicMapper;
	@Autowired
	private FourHundredService fourHundredService;
	
	
	/**
	 * 无限一二级菜单构造
	 * 
	 * @return
	 */
	/*private static Map<String, Object> getUnlimited() {
		Map<String, Object> topMap = Maps.newHashMap();
		topMap.put("id", -1);
		topMap.put("name", "不限");
		List<Map<?, ?>> childList = Lists.newArrayList();
		Map<String, Object> childMap = Maps.newHashMap();
		childMap.put("childId", -1);
		childMap.put("childName", "不限");
		childList.add(childMap);
		topMap.put("childList", childList);
		return topMap;
	}*/

	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject getSearchConditon(Map<String, Object> parameters) {
		logger.info("ShopServiceImpl getSearchConditon parameters:{}", parameters);
		ResultObject resultObject = new ResultObject();
		/*parameters.put("type", 4);
		resultObject.put("acreageList", shopConditionMapper.selectByCityId(parameters));
		parameters.put("type", 2);
		resultObject.put("monthlyList", shopConditionMapper.selectByCityId(parameters));
		parameters.put("type", 3);
		resultObject.put("transferList", shopConditionMapper.selectByCityId(parameters));
		List<Map<?, ?>> areas = Lists.newArrayList(getUnlimited());
		List<Map<?, ?>> shopBusinessTypes = Lists.newArrayList(getUnlimited());
		areasMapper.selectByParentId(parameters.get("cityId").toString()).forEach(a -> {
			Map<String, Object> c1 = Maps.newHashMap();
			c1.put("id", a.get("id"));
			c1.put("name", a.get("area_name"));
			List<Map<?, ?>> childList = Lists.newArrayList();
			businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
				Map<String, Object> c2 = Maps.newHashMap();
				c2.put("childId", ba.get("id"));
				c2.put("childName", ba.get("name"));
				childList.add(c2);
			});
			c1.put("id", childList.get(0).get("childId"));
			c1.put("childList", childList);
			areas.add(c1);
		});
		resultObject.put("areas", areas);
		shopBusinessTypeMapper.selectByPid("").forEach(b -> {
			Map<String, Object> c1 = Maps.newHashMap();
			c1.put("id", b.get("id"));
			c1.put("name", b.get("name"));
			List<Map<?, ?>> childList = Lists.newArrayList();
			Map<String, Object> topMap = Maps.newHashMap();
			topMap.put("childId", b.get("id"));
			topMap.put("childName", "不限");
			childList.add(topMap);
			shopBusinessTypeMapper.selectByPid(b.get("id").toString()).forEach(bb -> {
				Map<String, Object> c2 = Maps.newHashMap();
				c2.put("childId", bb.get("id"));
				c2.put("childName", bb.get("name"));
				childList.add(c2);
			});
			c1.put("childList", childList);
			shopBusinessTypes.add(c1);
		});
		resultObject.put("shopBusinessTypes", shopBusinessTypes);*/
		return resultObject;
	}

	@Override
	//@Cacheable(key = "#monthlyId+'.'+#businessCircleId+'.'+#businessTypeId+'.'+#areaId+'.'+#transfeeId", expireTime=20*60)
	public ResultObject getShopList(Map<String, Object> parameters) {
		logger.info("ShopServiceImpl getShopList parameters:{}", parameters);
		ResultObject resultObject = new ResultObject();
		if (Objects.nonNull(parameters.get("areaId"))) {
			parameters.put("type", 4);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("areaId").toString());
			parameters.put("areaHigh", m.get("price_high").toString());
			parameters.put("areaLow", m.get("price_low").toString());
		}
		if (Objects.nonNull(parameters.get("monthlyId"))) {
			parameters.put("type", 2);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("monthlyId").toString());
			parameters.put("monthlyHigh", m.get("price_high").toString());
			parameters.put("monthlyLow", m.get("price_low").toString());
		}
		if (Objects.nonNull(parameters.get("transfeeId"))) {
			parameters.put("type", 3);
			Map<String, Object> m = shopConditionMapper.selectById(parameters.get("transfeeId").toString());
			if (StringUtils.equals("不限", m.get("show_text").toString())) {
				parameters.put("transfeeId", null);
			}
			if (StringUtils.equals("无转让费", m.get("show_text").toString())) {
				parameters.put("transfeeId", null);
				parameters.put("type", -1);
				parameters.put("transfeeHigh", m.get("price_high").toString());
			} else {
				parameters.put("transfeeHigh", m.get("price_high").toString());
				parameters.put("transfeeLow", m.get("price_low").toString());
			}
		}
		Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
		resultObject.put("shopLineNum", Integer.valueOf(appData.get("shopLineNum").toString()));	
		
		if (Objects.nonNull(parameters.get("businessCircleId"))
				&& !StringUtils.equals("-1", parameters.get("businessCircleId").toString())) {
			Map<String, Object> map = businessAreaMapper.selectById(parameters);
			if (StringUtils.equals("不限", map.get("name").toString())) {
				parameters.put("businessType", 0);
				parameters.put("businessCircleId", map.get("area_id").toString());
			}
		}
		if (Objects.nonNull(parameters.get("businessTypeId"))
				&& !StringUtils.equals("-1", parameters.get("businessTypeId").toString())) {
			Map<String, Object> map = shopBusinessTypeMapper.selectById(parameters);
			if (Objects.isNull(map.get("pid"))) {
				parameters.put("type", 1);
				parameters.put("businessTypeId", map.get("id").toString());
			}
		}
		List<Map<String, Object>> topList = new ArrayList<Map<String, Object>>();
		if(StringUtils.equals("1", parameters.get("pageNum").toString())) {
			if(Objects.isNull(parameters.get("search"))) {
				//随机获取3个置顶商铺 - 最新购买（10分钟以内）
				List<Map<String, Object>> topListNew = shopMapper.getShopListRand3(parameters);
				//随机获取3个置顶商铺（10分钟以后）
				if(Objects.isNull(topListNew)) {
					parameters.put("randTime", 10);
					topList =shopMapper.getShopListRand3(parameters);
				}
				topList = topFilter(topList,topListNew);
				int size =topList.size(); 
			    parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
			    Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
				Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
			    parameters.put("startRows", pageSize*(pageNum-1));
				List<Map<String, Object>> shopList = shopMapper.getShopList(parameters);
				topList.addAll(shopList);
				if(Objects.isNull(parameters.get("source"))) {
					resultObject.put("shopList", showInfoService.createShop(topList, "1", "1"));
				}else {
					resultObject.put("shopList", showInfoService.createShop(topList, "1", "0"));
					resultObject.put("totalCount", shopMapper.totalCount(parameters));
				}
			}else if(Objects.isNull(parameters.get("search")) && Objects.isNull(parameters.get("source"))){
				List<Map<String, Object>> topListNew = shopMapper.selectBySearchRand3(parameters);
				//随机获取3个置顶商铺（10分钟以后）
				if(Objects.isNull(topListNew)) {
					parameters.put("randTime", 10);
					topList =shopMapper.selectBySearchRand3(parameters);
				     }
				topList = topFilter(topList,topListNew);
				int size =topList.size(); 
				parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
			    Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
				Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
			    parameters.put("startRows", pageSize*(pageNum-1));
				List<Map<String, Object>> shopList = shopMapper.selectBySearch(parameters);
				topList.addAll(shopList);
				resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
			   }else {
				     if(Objects.isNull(parameters.get("source"))) {
				    	 List<Map<String, Object>> topListNew = shopMapper.selectBySearchRand3(parameters);
							//随机获取3个置顶商铺（10分钟以后）
								if(Objects.isNull(topListNew)) {
									parameters.put("randTime", 10);
									topList =shopMapper.selectBySearchRand3(parameters);
								}
								topList = topFilter(topList,topListNew);
								int size =topList.size(); 
								parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
								Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
								Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
							    parameters.put("startRows", pageSize*(pageNum-1));
								List<Map<String, Object>> shopList = shopMapper.selectBySearch(parameters);
								topList.addAll(shopList);
								resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
				     }
			   }
			}else {
				   if(Objects.nonNull(parameters.get("search")) && Objects.isNull(parameters.get("source"))) {
					    Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
						Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
					    parameters.put("startRows", pageSize*(pageNum-1));
					    List<Map<String, Object>> shopList = shopMapper.selectBySearch(parameters);
						topList.addAll(shopList);
						resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
						return resultObject;
				   }else if(Objects.isNull(parameters.get("search")) && Objects.isNull(parameters.get("source"))) {
					   Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
						Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
						parameters.put("startRows", pageSize*(pageNum-1));
						topList = shopMapper.getShopList(parameters);
						if(Objects.isNull(parameters.get("source"))) {
							parameters.put("source", 1);
				       }
				   }
			}
		  if (Objects.nonNull(parameters.get("source")) && StringUtils.equals("2", parameters.get("source").toString())) {
			  if(Objects.nonNull(parameters.get("search"))) {//官网查询
				  List<Map<String, Object>> topListNew = shopMapper.selectBySearchRand3(parameters);
				//随机获取3个置顶商铺（10分钟以后）
					if(Objects.isNull(topListNew)) {
						parameters.put("randTime", 10);
						topList =shopMapper.selectBySearchRand3(parameters);
					}
					topList = topFilter(topList,topListNew);
					int size =topList.size(); 
					parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
					Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
					Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
				    parameters.put("startRows", pageSize*(pageNum-1));
					List<Map<String, Object>> shopList = shopMapper.selectBySearch(parameters);
					topList.addAll(shopList);
					resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
					resultObject.put("totalCount", shopMapper.selectBySearchCount(parameters));
			  }else {
				//随机获取3个置顶商铺 - 最新购买（10分钟以内）
				  if(!StringUtils.equals("1", parameters.get("pageNum").toString())) {
					  List<Map<String, Object>> topListNew = shopMapper.getShopListRand3(parameters);
						//随机获取3个置顶商铺（10分钟以后）
						if(Objects.isNull(topListNew)) {
							parameters.put("randTime", 10);
							topList =shopMapper.getShopListRand3(parameters);
						}
						topList = topFilter(topList,topListNew);
						int size =topList.size(); 
						if(Integer.valueOf(parameters.get("pageSize").toString())>4) {
							parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
							resultObject.put("totalCount", shopMapper.totalCount(parameters));
						}
						 Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
						Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
						parameters.put("startRows", pageSize*(pageNum-1));
						List<Map<String, Object>> shopList = shopMapper.getShopList(parameters);
						topList.addAll(shopList);
						resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
				  }
				  
					
			  }
		  	} else if(Objects.nonNull(parameters.get("source")) && StringUtils.equals("1", parameters.get("source").toString())) {
			resultObject.put("shopList", showInfoService.createShop(topList, "1", "0"));
		}

		return resultObject;
	}

	@Override
	public ResultObject getShopDetail(Map<String, Object> parameters) {		
		logger.info("ShopServiceImpl getShopDetail parameters:{}", parameters);
		ResultObject resultObject = new ResultObject();
		/********** 返回数据对象map ***********/
		/*Map<String, Object> map = shopMapper.selectById(parameters);
		String unitMonthRent = StringUtils.EMPTY;
		List<String> shopTags = new ArrayList<String>();
		List<String> imgs = Lists.newArrayList();
		List<String> shopSupportings = Lists.newArrayList();
		List<String> shopPapers = Lists.newArrayList();
		String video =StringUtils.EMPTY;
		if(Objects.nonNull(map.get("video"))) {
			video = map.get("video").toString();
		}
		if (Objects.nonNull(map.get("imgs")) && StringUtils.isNotBlank(map.get("imgs").toString())) {
			String imgStr = map.get("imgs").toString();
			List<String> list = Lists.newArrayList();
			Stream.of(imgStr.split(",")).forEach(s -> {
				if (s.contains("aliyuncs")) {
					s = s.replace("up-img.oss-cn-beijing.aliyuncs.com", "cdn.youpuchina.com");
					if (!s.contains("x-oss-process")) {
						s += "?x-oss-process=style/watermark";
					}
				}
				list.add(s);
			});
			String createType = map.get("create_type").toString();
			if (StringUtils.equals("5", createType) && list.size() >= 4) {
			     list.remove(3);
			}
			
			if(Objects.nonNull(map.get("video")) && StringUtils.isNotBlank(map.get("video").toString())) {
				list.add(0,video.concat("?x-oss-process=video/snapshot,t_0,m_fast"));
			}
			map.put("imgs", list.toArray(new String[] {}));
		} else {
			if(Objects.nonNull(map.get("video")) && StringUtils.isNotBlank(map.get("video").toString())) {
				imgs.add(0,video.concat("?x-oss-process=video/snapshot,t_0,m_fast"));
				
			}else {
				imgs.add(default_shop_img);
			}
			map.put("imgs", imgs);
		}
		// 月租金
		if (Objects.nonNull(map.get("monthly_rent"))) {
			BigDecimal monthlyRent = new BigDecimal(map.get("monthly_rent").toString());
			if (monthlyRent.intValue() == -2) {
				map.put("monthlyRent", "面议");
			} else {
				if (Objects.nonNull(monthlyRent) && monthlyRent.longValue() > 9999) {
					unitMonthRent = "万/月";
					monthlyRent = monthlyRent.divide(new BigDecimal(10000)).setScale(2, BigDecimal.ROUND_HALF_UP);
				} else {
					unitMonthRent = "元/月";
				}
				map.put("monthlyRent", monthlyRent.toString().replace(".00", ""));
			}
		} else if ((Objects.isNull((map.get("monthly_rent"))) && (Objects.nonNull(map.get("turnover_share")) && StringUtils.isNotEmpty(map.get("turnover_share").toString())))) {
			unitMonthRent = "";
			map.put("monthlyRent", "月收益流水的" + map.get("turnover_share").toString());
		} else {
			map.put("monthlyRent", StringUtils.EMPTY);
		}

		// 日租金
		String unitDailyRent = StringUtils.EMPTY;
		if (Objects.nonNull(map.get("daily_rent"))) {
			BigDecimal dailyRent = new BigDecimal(map.get("daily_rent").toString());
			if (dailyRent.intValue() == -2) {
				map.put("dailyRent", "面议");
			} else {
				map.put("dailyRent", dailyRent.setScale(2, BigDecimal.ROUND_HALF_UP).toString().replace(".00", ""));
				unitDailyRent = "元/天/㎡";
			}
		} else {
			unitDailyRent = StringUtils.EMPTY;
		}
		// 日租金单位
		map.put("unitDailyRent", unitDailyRent);
		// 月租金单位
		map.put("unitMonthRent", unitMonthRent);
		
		String transferFee = StringUtils.EMPTY;
		// 转让费单位
		String unitTransFerfee = StringUtils.EMPTY;
		// 转让费
		if (Objects.nonNull(map.get("transfer_fee"))) {
			BigDecimal fee = new BigDecimal(map.get("transfer_fee").toString());
			if (fee.intValue() == -1) {
				transferFee = "无";
			} else if (fee.intValue() == -2) {
				transferFee = "面议";
			} else {
				transferFee = fee.setScale(2, BigDecimal.ROUND_HALF_UP).toString().replace(".00", "");
				unitTransFerfee = "万元";
			}
		} else {
			transferFee = "无";
		}
		
		map.put("unitTransFerfee", unitTransFerfee);
		// 特色标签
		if (Objects.nonNull(map.get("tag")) && StringUtils.isNotBlank(map.get("tag").toString())) {
			String tags = map.get("tag").toString();
			map.put("shopTags", Arrays.asList(tags.split(",")));
		} else {
			map.put("shopTags", shopTags);
		}
		// 配套
		if (Objects.nonNull(map.get("supporting")) && StringUtils.isNotBlank(map.get("supporting").toString())) {
			String supportings = map.get("supporting").toString();
			map.put("shopSupportings", Arrays.asList(supportings.split(",")));
		} else {
			map.put("shopSupportings", shopSupportings);
		}
		// 已有证件
		if (Objects.nonNull(map.get("paper")) && StringUtils.isNotBlank(map.get("paper").toString())) {
			String papers = map.get("paper").toString();
			map.put("shopPapers", Arrays.asList(papers.split(",")));
		} else {
			map.put("shopPapers", shopPapers);
		}

		map.put("transferFee", transferFee);
		// 楼层 （一层、二层、三层、四层、高层、半地下)
		StringBuilder floor = new StringBuilder(StringUtils.EMPTY);
		if (Objects.nonNull(map.get("floor1")) && StringUtils.equals("true", map.get("floor1").toString())) {
			floor.append("一层 ");
		}
		if (Objects.nonNull(map.get("floor2")) && StringUtils.equals("true", map.get("floor2").toString())) {
			floor.append("二层 ");
		}
		if (Objects.nonNull(map.get("floor3")) && StringUtils.equals("true", map.get("floor3").toString())) {
			floor.append("三层 ");
		}
		if (Objects.nonNull(map.get("floor4")) && StringUtils.equals("true", map.get("floor4").toString())) {
			floor.append("四层 ");
		}
		if (Objects.nonNull(map.get("floor_high")) && StringUtils.equals("true", map.get("floor_high").toString())) {
			floor.append("高层 ");
		}
		if (Objects.nonNull(map.get("floor_under")) && StringUtils.equals("true", map.get("floor_under").toString())) {
			floor.append("半地下 ");
		}

		String linkman = "*老板";
		if (Objects.nonNull(map.get("linkman")) && map.get("linkman").toString().endsWith("先生")
				|| map.get("linkman").toString().endsWith("女士")) {
			linkman = map.get("linkman").toString().toLowerCase();
		}
		// 分享地址
		map.put("shareUrl", "http://m.youpuchina.com");
		// 推荐列表
		parameters.put("limit", 4);
		parameters.put("businessAreaId", map.get("businessAreaId"));
		parameters.put("cityId", map.get("cityId"));
		map.put("recommendList", showInfoService.createShop(shopMapper.selectRecommendList(parameters),"1", "0"));
		String labe=StringUtils.EMPTY;
		if(Objects.nonNull(map.get("shopType")) && StringUtils.isNotBlank(map.get("shopType").toString())) {
			if(map.get("shopType").toString().contains("4")) {
				labe="4";
			}else if(map.get("shopType").toString().contains("3") && !map.get("shopType").toString().contains("4")) {
				labe="3";
			}else if(map.get("shopType").toString().contains("2") && !map.get("shopType").toString().contains("3")
				&& !map.get("shopType").toString().contains("4")) {
				labe="2";
			}else if(Arrays.asList(map.get("shopType").toString()).contains("1") && !map.get("shopType").toString().contains("3")
					&& !map.get("shopType").toString().contains("4") && !map.get("shopType").toString().contains("2")) {
				labe="1";
				}
		}
		if(Objects.nonNull(map.get("topStatus")) && StringUtils.equals("1", map.get("topStatus").toString())) {
			labe="4";
		}
		// 浏览商铺数量
		Integer count = browseRecordsCount(Integer.valueOf(parameters.get("shopId").toString()));
		map.put("browseCount", count);
		map.put("linkman", linkman);
		map.put("floor", floor.toString());
		map.put("shopType", labe);
		map.remove("floor1");
		map.remove("floor2");
		map.remove("floor3");
		map.remove("floor4");
		map.remove("floor_high");
		map.remove("floor_under");
		map.remove("transfer_fee");
		map.remove("paper");
		map.remove("tag");
		map.remove("supporting");
		map.remove("monthly_rent");
		map.remove("daily_rent");
		resultObject.put("shopDetail", map);*/
		return resultObject;
	}
	
	
	public Integer browseRecordsCount(Integer shopId) {
		Integer defaultCount = 0;
		Integer brCount = 0;
		try {
//			Object pvCounnt = redisBaseDao.get("");
//			if (Objects.isNull(pvCounnt)) {
				BrowseRecords br = browseRecordsMapper.selectByShopId(shopId);
				if (Objects.nonNull(br)) {
					Integer count = br.getCount();
					brCount =count+1;
					browseRecordsMapper.updateBrowseRecords(brCount, shopId);
				} else {
					BrowseRecords browseRecords = new BrowseRecords();
					browseRecords.setShopId(shopId);
					defaultCount = RandomUtils.nextInt(50, 100);
					brCount += defaultCount;
					browseRecords.setCount(brCount);
					browseRecordsMapper.save(browseRecords);
				}
//			} else {
//				return 0;
//			}
		} catch (Exception e) {
			return 50;
		}
		return brCount;
	}

	@Override
	public ResultObject getCorrectionInfo(Map<String, Object> parameters) {
		    ResultObject resultObject = new ResultObject();
		    List<Map<String,Object>> list = new ArrayList<Map<String,Object>>();
			int count = shopCorrectionMapper.selectByUserId(parameters);
			int correctionCount = shopCorrectionMapper.getCorrectionCount(parameters);
			//先判断状态
			if(0!=correctionCount) {
				resultObject.put("count", true);//次数超限
				resultObject.put("flag", false);//纠错中
				resultObject.put("shop", list);//集合为空
			}
			if(10 <=count && 0 ==correctionCount) {
				resultObject.put("count", true);//次数超限
				resultObject.put("flag", true);//不在纠错中
				resultObject.put("shop", list);//集合为空
				return resultObject;
			}else {
				resultObject.put("count", false);//次数满足小于10次
				if(0==correctionCount) {//该商铺不在纠错审核中
					resultObject.put("flag", true);
					resultObject.put("shop", showInfoService.createShop(shopMapper.getJCShopList(parameters),"1", "0").get(0));
				}else {
					resultObject.put("flag", false);
					resultObject.put("shop", list);
				}
			}
		logger.info("getCorrectionList end");
		return resultObject;
	}

	@Override
	public ResultObject submitCorrectionInfo(Map<String, Object> parameters) {
		 ResultObject resultObject = new ResultObject();
		 ShopCorrection sc = new ShopCorrection();
		 sc.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
		 sc.setCreateTime(new Date());
		 if(Objects.nonNull(parameters.get("content"))) {
			 sc.setContent(parameters.get("content").toString());
		 }else {
			 sc.setContent("");
		 }
		 sc.setShopId(Integer.valueOf(parameters.get("shopId").toString()));
		 sc.setUserId(Integer.valueOf(parameters.get("authentication").toString()));
		 sc.setReason(Integer.valueOf(parameters.get("reason").toString()));
		 shopCorrectionMapper.save(sc);
		 return resultObject;
	}
	
	  // 普通商户可查看10套商铺
	  private static final int totalCommonNum = 5;
	  // VIP用户可查看50套
	  private static final int totalVIPNum = 30;
	
	  @Override
		public ResultObject shopCheckedRecords(Map<String, Object> parameters) {
			 ResultObject map = new ResultObject();
			 int totalCount=0;
			  // 根据手机号查询用户角色，普通商户可查看5套商铺，VIP用户可查看30套
				//根据用户角色查询可查看商铺次数
				int count = memberMapper.selectByUserId(parameters);//会员
			    UserCorrect user = userCorrectMapper.selectByUserId(parameters);//纠错次数
			    parameters.put("operType", 3);//一键分享
			    int operCount=0;
			    int userOperCount = userOperRecordsMapper.selectCount(parameters);//查询是否当前城市有分享
			    if(1==userOperCount) {
			    	   operCount=2;
			    }
			    int corrcetCount= 0;
			    if(Objects.nonNull(user)) {
				   corrcetCount= user.getCorrectCount();
			    }
				if(0!=count) {
					List<String> members = memberMapper.selectMemberLevel(parameters);
					for(String type : members) {
						if(StringUtils.equals("2", type) || StringUtils.equals("4", type)) {
							 map.put("memberLevel", 1);
						}
						if(StringUtils.equals("0", type) || StringUtils.equals("1", type)) {
							 map.put("memberLevel", 0);
						}
					}
					 totalCount= totalVIPNum + corrcetCount + operCount;
					 map.put("memberType", "0");
					 map.put("pvCount", totalCount);
				}else {
					 totalCount= totalCommonNum + corrcetCount + operCount;
					 map.put("memberType", "2");
					 map.put("pvCount", totalCount);
					 map.put("memberLevel", 2);
				}
				//查询商铺是否为热门
				String shopType ="0";
				Map<String, Object> shop = shopMapper.selectById(parameters);
				if(Objects.nonNull(shop.get("shopType")) && shop.get("shopType").toString().contains("2")) {
					shopType="1";
				}
				// 根据手机号和商铺Id查询是否有收藏记录
				ShopMyself shopCollection = shopMyselfMapper.selectShopMyself(parameters);
				Integer id = Integer.valueOf(parameters.get("shopId").toString());
				// 根据手机号和商铺id 来查询是否看过该套商铺
				int recordsCount = shopRecordsMapper.selectShopRecordsByAccount(parameters);
				ShopRecords record = new ShopRecords();
				// 获取手机号今天查询的总记录
				int sumCount = shopRecordsMapper.getSumCount(parameters);
				// 判读次数是否满足
				int sub = sub(totalCount, sumCount);
				//限制次数为3
				int limitCount=3;
				if(Objects.isNull(parameters.get("roof"))) {
					limitCount=5+corrcetCount;
				}
				// type值为0，判断是否有记录，如果记录为空，返回未查看状态，记录数不变
				String type = parameters.get("type").toString();
				if ("0".equals(type)) {
					map.put("count", sub);
					// 收藏记录不为空
					if (Objects.nonNull(shopCollection)) {
						// 收藏状态返回 未收藏
						map.put("shopId", shopCollection.getObjectId());
						map.put("collectionStatus", "true");
					} else {
						// 收藏状态返回 已收藏
						map.put("collectionStatus", "false");
					}
					// 记录数为空 表示 未查看过该商铺
					if (recordsCount == 0) {
						map.put("checkedStatus", "false");
					} else {
						map.put("checkedStatus", "true");
					}
					return map;
				}
				
				//根据渠道查询商铺查看次数
				int sumCountByRoof = shopRecordsMapper.getSumCount(parameters);
				int countM = sub(limitCount,sumCountByRoof);
				//非会员
			    if(0==count && StringUtils.equals("0", shopType)) {
			    	map.put("isHot", true);
				// 记录为空，该商铺今日首次查看 并且 type值为1，表示要进行记录修改（M站，官网次数小于3次）
				 if ((0 == recordsCount) && "1".equals(type) && sumCount < totalCount && limitCount > sumCountByRoof) {
					// 满足--返回可看商铺记录数
					if (sub > 0 && sub <= totalCount) {
						if (id == 0) {
							map.put("count", sub);
						} else {
							map.put("count", sub - 1);
						   if(0 == (sub-1) && sub!=1) {
							  map.put("countStatus", false);								
						    }else if(sub ==1){
						    	  map.put("countStatus", true);	
						    }else {
						    	  map.put("countStatus", true);		
						    }
						}
					} 
					if (Objects.nonNull(shopCollection)) {
						// 收藏状态返回 已收藏
						map.put("shopId", shopCollection.getObjectId());
						map.put("collectionStatus", "true");
					} else {
						map.put("collectionStatus", "false");
					}
				int realSub =0;
				if(Objects.nonNull(map.get("count"))) {
					 Object object = map.get("count");
					 String s =String.valueOf(object);
					 realSub=Integer.parseInt(s);
					 if(realSub == 0 ) {
						 realSub = sub;
					 }
				}
				if(realSub > 0 && realSub <= totalCount && Objects.nonNull(parameters.get("roof")) && 0==count ){
						if(countM >0 && countM<=limitCount && StringUtils.equals("0", parameters.get("roof").toString())) {
							if(id == 0) {
								map.put("MlimitCount", limitCount);
							}else {
								map.put("MlimitCount", countM-1);
								map.put("MlimitCountStatus", true);	
								
							}
						   }else if(countM >0 && countM<=limitCount && StringUtils.equals("1", parameters.get("roof").toString())){
							   if(id == 0) {
									map.put("PClimitCount", limitCount);
								}else {
									map.put("PClimitCount", countM-1);
									map.put("PClimitCountStatus", true);
								} 
						   }else {
							   if(StringUtils.equals("1", parameters.get("roof").toString())) {
									map.put("PClimitCount", countM);
									if(0==countM || countM < 0) {
										map.put("PClimitCountStatus", false);	
									}else {
										map.put("PClimitCountStatus", true);	
									}
									
							   }
							   if(StringUtils.equals("0", parameters.get("roof").toString())) {
								   map.put("MlimitCount", countM);
								   if(0==countM || countM < 0) {
									   map.put("MlimitCountStatus", false);  
								   }else {
									   map.put("MlimitCountStatus", true);  
								   }
									
							   }
								map.put("checkedStatus", "true");
								return map;
							}
					}
					//官网，M站渠道查看商铺记录标识   M站, PC, APP
					if(Objects.nonNull(parameters.get("roof"))) {
						if(StringUtils.equals("0", parameters.get("roof").toString())) {
							record.setChannel(0);
						}else if(StringUtils.equals("1", parameters.get("roof").toString())) {
							record.setChannel(1);
						}
					}else {
						record.setChannel(2);
					}
					record.setAccount(parameters.get("paramPhone").toString());
					record.setShopId(id);
					record.setCreateTime(new Date());
					// 保存记录入库
					shopRecordsMapper.save(record);
					//记录操作次数表
					UserOperRecords uor = new UserOperRecords();
					uor.setCount("-1");
					uor.setCreateTime(new Date());
					uor.setType(5);
					uor.setUserId(Integer.valueOf(parameters.get("authentication").toString()));
					uor.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
					userOperRecordsMapper.insert(uor);
					map.put("checkedStatus", "true");
				  }else if((0 == recordsCount) && "1".equals(type) && sumCount < totalCount && limitCount == sumCountByRoof) {
						if(0==sub || sub<0){
							map.put("count", 0);
							map.put("countStatus", false);
						}else {
							map.put("count", sub);	
							map.put("countStatus", true);
						}
						if(Objects.nonNull(parameters.get("roof"))) {
							if(StringUtils.equals("0", parameters.get("roof").toString())) {
								map.put("MlimitCountStatus", false);  
						     }else if(StringUtils.equals("1", parameters.get("roof").toString())) {
								map.put("PClimitCountStatus", false);
						     }
						}
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
				  } else if((0 == recordsCount) && "1".equals(type) && sumCount == totalCount && limitCount == sumCountByRoof) {
					  if(0==sub || sub<0){
							map.put("count", 0);
							map.put("countStatus", false);
						}else {
							map.put("count", sub);	
							map.put("countStatus", true);
						}
						if(Objects.nonNull(parameters.get("roof"))) {
							if(StringUtils.equals("0", parameters.get("roof").toString())) {
								map.put("MlimitCountStatus", false);  
						     }else if(StringUtils.equals("1", parameters.get("roof").toString())) {
								map.put("PClimitCountStatus", false);
						     }
						}
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
						map.put("checkedStatus", "false");
				  } else {// 如果记录不为空，该商铺Id对应的商铺已被查看，返回已查看标识，不保存入库。
						if(0==sub || sub<0){
							map.put("count", 0);
							map.put("countStatus", false);
						}else {
							map.put("count", sub);
							map.put("countStatus", true);	
						}
						map.put("checkedStatus", "true");
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
					}
			}else if(0==count && StringUtils.equals("1", shopType)) {
				map.put("checkedStatus", "false"); 
				// 收藏记录不为空
				if (Objects.nonNull(shopCollection)) {
					// 收藏状态返回 未收藏
					map.put("shopId", shopCollection.getId());
					map.put("collectionStatus", "true");
				} else {
					// 收藏状态返回 已收藏
					map.put("collectionStatus", "false");
				}
				if(0==sub || sub<0){
					map.put("count", 0);
					map.put("countStatus", false);
				}else {
					map.put("count", sub);
					map.put("countStatus", true);	
				}
				map.put("isHot", false);
			}
			 else{//会员没有查看次数限制
				 map.put("isHot", true);
				 if((0==recordsCount) && "1".equals(type) && sumCount < totalCount) {
					// 满足--返回可看商铺记录数
					 if (sub > 0 && sub <= totalCount) {
							if (id == 0) {
								map.put("count", sub);
							} else {
								map.put("count", sub - 1);
								 if(0 == (sub-1) && sub!=1) {
									  map.put("countStatus", false);								
								    }else if(sub ==1){
								    	  map.put("countStatus", true);	
								    }else {
								    	  map.put("countStatus", true);		
								    }
							}
						} 
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getObjectId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
						//官网，M站渠道查看商铺记录标识
						if(Objects.nonNull(parameters.get("roof"))) {
							if(StringUtils.equals("0", parameters.get("roof").toString())) {
								record.setChannel(0);
							}else if(StringUtils.equals("1", parameters.get("roof").toString())) {
								record.setChannel(1);
							}
						}else {
							record.setChannel(2);
						}
						record.setAccount(parameters.get("paramPhone").toString());
						record.setShopId(id);
						record.setCreateTime(new Date());
						// 保存记录入库
						shopRecordsMapper.save(record);
						//记录操作次数表
						UserOperRecords uor = new UserOperRecords();
						uor.setCount("-1");
						uor.setCreateTime(new Date());
						uor.setType(5);
						uor.setUserId(Integer.valueOf(parameters.get("authentication").toString()));
						uor.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
						userOperRecordsMapper.insert(uor);
						map.put("checkedStatus", "true"); 
				 }else if((0==recordsCount) && "1".equals(type) && sumCount == totalCount){
					 	if(0==sub || sub<0){
							map.put("count", 0);
							map.put("countStatus", false);
						}else {
							map.put("count", sub);	
							map.put("countStatus", true);
						}
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
						map.put("checkedStatus", "false");
				 }else {// 如果记录不为空，该商铺Id对应的商铺已被查看，返回已查看标识，不保存入库。
						if(0==sub || sub<0){
							map.put("count", 0);
							map.put("countStatus", false);
						}else {
							map.put("count", sub);
							map.put("countStatus", true);	
						}
						map.put("checkedStatus", "true");
						if (Objects.nonNull(shopCollection)) {
							// 收藏状态返回 已收藏
							map.put("shopId", shopCollection.getId());
							map.put("collectionStatus", "true");
						} else {
							map.put("collectionStatus", "false");
						}
					}
			  }
			logger.info("shopCheckedRecords end");
			 return map;
		}
	
	  /**
		 * 提供精确的减法运算。
		 * 
		 * @param v1
		 *            被减数
		 * @param v2
		 *            减数
		 * @return 两个参数的差
		 */
		public static int sub(int v1, int v2) {
			BigDecimal b1 = new BigDecimal(Integer.toString(v1));
			BigDecimal b2 = new BigDecimal(Integer.toString(v2));
			return b1.subtract(b2).intValue();
		}

	@Override
	public ResultObject selectPhone(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		if(StringUtils.equals("0", parameters.get("type").toString())) {
			resultObject.put("phone", shopMapper.selectPhone(parameters));
		}else {
			resultObject.put("phone", crmCustomerMapper.selectPhone(parameters));
		}
		return resultObject;
	}

	@Override
	public ResultObject selectSolicit(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		//resultObject.put("shopList", crmCustomerMapper.selectSolictingList(parameters));
		resultObject.put("shopList", shopRentingMapper.selectAll(parameters));
		return resultObject;
	}

	@Override
	public ResultObject selectSolicitDetail(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
//		crmCustomerMapper.updateCount(Integer.valueOf(parameters.get("id").toString()));
//		Map<String, Object> map = crmCustomerMapper.selectSolicitDetail(parameters);
		shopRentingMapper.updateCount(Integer.valueOf(parameters.get("id").toString()));
		Map<String, Object> map = shopRentingMapper.selectSolicitDetail(parameters);
		parameters.put("cityId", map.get("cityId"));
		Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
		map.put("serviceTel", appData.get("service_tel"));//咨询服务热线
		map.remove("cityId");
		resultObject.put("detail",map );
		return resultObject;
	}

	@Override
	public ResultObject isVip(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		int count = memberMapper.selectIsVip(parameters);//是否为会员
		if(0!=count) {//会员
			int checkedCount = solicitingRecordMapper.selectByPhone(parameters);//是否查看过该商铺
			if(0!=checkedCount) {
				resultObject.put("status", "ok");
			}else {
				int dayCount = solicitingRecordMapper.selectCurrentCount(parameters);
				if(dayCount>=30) {//会员次数超了
					resultObject.put("status", "exceed");
				}else {
					SolicitingRecord solicitingRecord = new SolicitingRecord();
					solicitingRecord.setPhone(parameters.get("paramPhone").toString());
					solicitingRecord.setShopId(parameters.get("id").toString());
					solicitingRecord.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
					solicitingRecord.setCreateTime(new Date());
					solicitingRecordMapper.insert(solicitingRecord);
					resultObject.put("status", "ok");
				}
			}
		}else {
			int publishCount = shopMapper.getPublishCount(parameters);//是否发布(出租/转让)
			int rentingCount = shopRentingMapper.getRentingCount(parameters);//是否发(求租)
			if(0!=publishCount || 0!=rentingCount) {//发布过铺子但不是会员
				resultObject.put("status", "fail");	
			}
			if(0==publishCount && 0==rentingCount) {//没发过铺子 也不是会员
				resultObject.put("status", "release");
				return resultObject;
			}
		}
		return resultObject;
	}

	/**
	 * 置顶 - 最新置顶 
	 * @param topList
	 * @param topNewList
	 * @return List
	 */
	public List<Map<String, Object>> topFilter(List<Map<String, Object>> topList,List<Map<String, Object>> topNewList){
		if(topList == null) { topList = new ArrayList<Map<String, Object>>();}
		if(topNewList == null) { topNewList = new ArrayList<Map<String, Object>>();}
		if(topList.size() > 0) {
			for(int i=0;i<topNewList.size();i++) {
				topList.add(i, topNewList.get(i));
			}
		}else {
			topList.addAll(topNewList);
		}
		if(topList.size() > 3) {
			topList.subList(3, topList.size()).clear();
		}
		return topList;
	}

	@Override
	public ResultObject getShopSearch(Map<String, Object> parameters) {
		 ResultObject resultObject = new ResultObject();
	     List<Map<String, Object>> topListNew = shopMapper.selectBySearchRand3(parameters);
	 	 List<Map<String, Object>> topList = new ArrayList<Map<String, Object>>();
	     Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
		 resultObject.put("shopLineNum", appData.get("shopLineNum"));
		//随机获取3个置顶商铺（10分钟以后）
		if(Objects.isNull(topListNew)) {
			parameters.put("randTime", 10);
			topList =shopMapper.selectBySearchRand3(parameters);
		}
		topList = topFilter(topList,topListNew);
		int size =topList.size(); 
		parameters.put("pageSize", Integer.valueOf(parameters.get("pageSize").toString())-size);
		Integer pageSize = Integer.valueOf(parameters.get("pageSize").toString());
		Integer pageNum = Integer.valueOf(parameters.get("pageNum").toString());
	    parameters.put("startRows", pageSize*(pageNum-1));
		List<Map<String, Object>> shopList = shopMapper.selectBySearch(parameters);
		topList.addAll(shopList);
		resultObject.put("shopList", showInfoService.createShop(topList, "1", "0")); 
		return resultObject;
	}
	
	
	/**
	 * 区域+商圈
	 * @param parameters
	 * @return
	 */
	@Override
	public ResultObject findShangBanSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//区域列表 areas
	     List<Map<String, Object>> areaList = this.areasMapper.selectByParentId(parameters.get("cityId")+"");
	     for(Map<String, Object> temp:areaList){
	    	 String areaId=temp.get("id")+"";
	    	//商圈列表 business_area
	    	 List<Map<String,Object>> regionsList= businessAreaMapper.selectByAreaId(areaId);
	    	 temp.put("regionsList", regionsList);
	     }
	     resultObject.put("areaList", areaList);
		return resultObject;
	}
	
	
	
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findShopSaleSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//1）区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.officeService.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.officeService.findAreaAndRegions(parameters.get("cityId")+""));
		}
		//2）面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		//3）总价
		parameters.put("type", Constant.CONDITION_TYPE_TOTAL);
		resultObject.put("priceList", shopConditionMapper.selectByCityId(parameters));
		//4）类型 1-纯写字楼   2-商业综合楼  3-酒店写字楼 4-其他
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.SHOP_TYPE));
		
		return resultObject;
	}



	//区域-业态-面积-月租-转让费-类型
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findShopRentTitle(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//1）区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.officeService.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.officeService.findAreaAndRegions(parameters.get("cityId")+""));
		}

		//商铺业态
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("yeTaiList", this.getAppShopYeTaiList());
		}else{
			resultObject.put("yeTaiList", this.getPcShopYeTaiList());
		}
		//2）面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		//月租
		parameters.put("type", Constant.CONDITION_TYPE_MONTH);
		resultObject.put("monthlyRentList", shopConditionMapper.selectByCityId(parameters));
		//转让费
		parameters.put("type", Constant.CONDITION_TYPE_TRANSFEE);
		resultObject.put("transFeeList", shopConditionMapper.selectByCityId(parameters));
		//4）类型
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.SHOP_TYPE));
		return resultObject;
	}

	//查询商铺出租业态方法-app
	public List<Map<String, Object>> getAppShopYeTaiList(){
		List<Map<String, Object>> parentList=this.shopBusinessTypeMapper.selectByPid("");
		if(parentList!=null && parentList.size()>0){
			for(Map<String, Object> temp:parentList){
				String pid=temp.get("id")+"";
				if(StringUtils.isEmpty(pid)){
					pid="-1";
				} 
				List<Map<String, Object>>  childrenList=this.shopBusinessTypeMapper.selectByPid(pid);
				for(Map<String, Object> chilItem:childrenList){
					if("全部".equals(chilItem.get("name")+"")){
						chilItem.put("id", pid);//当子集全部时，id重新赋值为pid
					}
				}
				temp.put("childrenList",childrenList);
			}
		}
		return parentList;
	}
	//查询商铺业态方法
	public List<Map<String, Object>> getPcShopYeTaiList(){
		List<Map<String, Object>> parentList=this.shopBusinessTypeMapper.selectByPid("");
		if(parentList!=null && parentList.size()>0){
			for(Map<String, Object> temp:parentList){
				String pid=temp.get("id")+"";
				if(StringUtils.isEmpty(pid)){
					pid="-1";
				}
				temp.put("childrenList", this.shopBusinessTypeMapper.selectByPid(pid));
			}
		}
		return parentList;
	}

	
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject findShopNewSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		if(ShopEnum.RentType.NEWS_RENT.getValue().equals(parameters.get("typeSale"))){
			//【出租：区域-日租-类型】
			parameters.put("type",Constant.CONDITION_TYPE_DAILY);
			resultObject.put("dailyRentList", shopConditionMapper.selectByCityId(parameters));//日租
		}else {
			//【出售：区域-均价-类型】
			parameters.put("type",Constant.CONDITION_TYPE_AVG);
			resultObject.put("avgPriceList", shopConditionMapper.selectByCityId(parameters));//均价
			
			//总价
			parameters.put("type",Constant.CONDITION_TYPE_TOTAL);
			resultObject.put("totalPriceList", shopConditionMapper.selectByCityId(parameters));
		}
		//1)区域
		if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
			resultObject.put("areaList",this.officeService.appFindAreaAndRegions(parameters.get("cityId")+""));
		}else{
			resultObject.put("areaList", this.officeService.findAreaAndRegions(parameters.get("cityId")+""));
		}
		//3）类型
		resultObject.put("typeList", this.dictionaryMapper.findItem(Constant.SHOP_TYPE));
		
		//面积
		parameters.put("type",Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		return resultObject;
	}

	
	@Override
	public ResultObject selectShopPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			this.officeService.analysisLeftRight(paraMap);//解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.shopMapper.selectShopPage(paraMap);
			if(list!=null && list.size()>0){
				for(Map<String,Object> temp:list){
					temp.put("label",this.showInfoService.findLabelByObjId(temp.get("id")+"", ProjectEnum.ProjectType.SHOP.getValue(), ShopEnum.SHOP_LABEL_KEY));
					//商铺出租列表页，如果日租金为空的话，则显示面议
					if (String.valueOf(temp.get("monthly_rent")).equals("-2") || Objects.isNull(temp.get("monthly_rent"))){
						temp.put("monthly_rent","面议");
						temp.put("monthly_rent_u","");
					}
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 	租商铺：区域+商圈|面积     [副标题]商铺类型+类型（出租/转让）
		买商铺：区域+商圈|面积    [副标题] 商铺类型+楼层+类型（出售）
		商业新盘出售：楼盘名称     [副标题]区域-商圈
		商业新盘出租：楼盘名称     [副标题]区域-商圈
	 * @param temp
	 * @return
	 */
//	public Map<String,String> jsonPageShopName(Map<String,Object> temp){
//		String rentType=temp.get("rent_type")+"";
//		Map<String,String> resMap=new HashMap<String,String>();
//		String title="";//主标题
//		String titleSub="";//副标题
//		if(ShopEnum.RentType.RENT.getValue().equals(rentType)){
//			//租商铺：区域+商圈|面积    [副标题] 商铺类型+类型（出租/转让）
//			title=temp.get("name")+"|"+temp.get("build_area");
//			titleSub=temp.get("type")+"出租";
//		}else if(ShopEnum.RentType.SALE.getValue().equals(rentType)){
//			//买商铺：区域+商圈|面积    [副标题] 商铺类型+楼层+类型（出售）
//			title=temp.get("name")+"|"+temp.get("build_area");
//			titleSub=temp.get("type")+""+temp.get("floor_name")+"出售";
//		}else {
//			//商业新盘出售：楼盘名称    [副标题] 区域-商圈
//			title=temp.get("floor_name")+"";
//			titleSub=temp.get("name")+"";
//		}
//		resMap.put("title", title);
//		resMap.put("titleSub", titleSub);
//		return resMap;
//	}
	
	
	
	
	@Override
	@Cacheable(expireTime=60*60)
	public ResultObject selectHotShop(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			if(Objects.nonNull(paraMap.get("typeSale"))){
				paraMap.put("rentType", paraMap.get("typeSale"));
			}
			List<Map<String,Object>> list=this.shopMapper.selectHotShop(paraMap);
			if(list !=null && list.size()>0){
				for(Map<String,Object> temp:list){
					if(ShopEnum.RentType.RENT.getValue().equals(temp.get("rent_type")+"")){
						temp.put("customer_price", temp.get("monthly_rent"));
						temp.put("customer_price_u", temp.get("monthly_rent_u"));
					}else if(ShopEnum.RentType.SALE.getValue().equals(temp.get("rent_type")+"")){
						temp.put("customer_price", temp.get("unit_price"));
						temp.put("customer_price_u", temp.get("unit_price_u"));
					}else if(ShopEnum.RentType.NEWS_RENT.getValue().equals(temp.get("rent_type")+"")){
						temp.put("customer_price", temp.get("daily_rent"));
						temp.put("customer_price_u", temp.get("daily_rent_u"));
					}else if(ShopEnum.RentType.NEWS_SALE.getValue().equals(temp.get("rent_type")+"")){
						temp.put("customer_price", temp.get("customer_price"));
						temp.put("customer_price_u", temp.get("customer_price_u"));
					}
				}
			}
			resultObject.put("list", list);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}

	@Override
	public void saveAll(Shop shop) {
		shopMapper.saveAll(shop);
	}
	
	//=========================================================================app start 
	
	@Override
	public ResultObject findMyFollowShopPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			this.officeService.analysisLeftRight(paraMap);//解析搜索条件id为区间
			//Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			//Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			//Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			
			List<PublishShopVo> list= this.shopMapper.findMyFollowShopPage(paraMap);
			if(list!=null && list.size()>0){
				for(PublishShopVo temp:list){
					temp.setLabel(this.showInfoService.findLabelByObjId(temp.getId()+"", ProjectEnum.ProjectType.SHOP.getValue(), ShopEnum.SHOP_LABEL_KEY));
					paraMap.put("projectId", temp.getId());
					paraMap.put("projectType", ProjectEnum.ProjectType.SHOP.getValue());
					temp.setSumMyFollowList(this.officeService.getSumFiveStatusList(temp.getId()+"",ProjectEnum.ProjectType.SHOP.getValue(),paraMap.get("agentId")+""));//联系1人+到访1人+认购1人
				}
			}
			resultObject.put("list", list);
			//resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	@Cacheable(expireTime=30*60)
	public ResultObject myPublishSearch(Map<String, Object> parameters){
		ResultObject resultObject = new ResultObject();
		//区域
		resultObject.put("areaList", this.officeService.findAreaAndRegions(parameters.get("cityId")+""));
		//类型
		if(ProjectEnum.ProjectType.SHOP.getValue().equals(parameters.get("projectType"))){
			 List<Map<String,Object>> parentList=this.dictionaryMapper.findItem(Constant.SHOP_TYPE);
			 if(parentList!=null && parentList.size()>0){
				 for(Map<String,Object> temp:parentList){
					 temp.put("childrenList", this.jsonShopChildrent());
				 }
			 }
			resultObject.put("typeList", parentList);
		}else{
			 List<Map<String,Object>> parentList=this.dictionaryMapper.findItem(Constant.OFFICE_TYPE);
			if(parentList!=null && parentList.size()>0){
				 for(Map<String,Object> temp:parentList){
					 temp.put("childrenList", this.jsonOfficeChildrent());
				 }
			 }
			 resultObject.put("typeList", parentList);
		}
		//面积
		parameters.put("type", Constant.CONDITION_TYPE_AREA);
		resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
		return resultObject;
	}

	@Override
	public ResultObject updateUserName(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		shopMapper.updateUserName(parameters);
		return resultObject;
	}


	/**
	 * 爬虫录入数据
	 */
	@Override
	public ResultObject crawlerShop(JSONObject jsonObject) {
		ResultObject resultObject = new ResultObject();
		if (Objects.isNull(jsonObject)){
			return resultObject;
		}
		try {
			String[] imgArray = jsonObject.getJSONArray("img").toArray(new String[] {});
			String shopImgs = Stream.of(imgArray).collect(Collectors.joining(","));
			Shop shop = new Shop();
			shop.setOnlineStatus(0);
			shop.setCover(shopImgs.substring(0,shopImgs.indexOf(",")));
			shop.setAgentId("1");//爬取数据无经纪人，在此设置经纪人默认id为1  对应user_app表id
			shop.setCity(jsonObject.getInteger("cityId"));//城市id
			shop.setImgs(shopImgs);//图片
			shop.setTotalPrice(new BigDecimal(jsonObject.getString("price_unit").replaceAll("万元","")));//总价
			shop.setPrice(Double.valueOf(jsonObject.getString("price").replaceAll("万元/m²","")));//单价
			shop.setBuildArea(new BigDecimal(jsonObject.getString("buildArea").replaceAll("m²","")));//建筑面积
			shop.setRealAddress(jsonObject.getString("realAddress"));//详细地址
			List<String> types = Arrays.asList("商业街商铺","社区商业","写字楼配套","市场","百货购物中心","学校","村镇商铺","档口摊位","其他");
			if (types.contains(jsonObject.getString("type"))){
				shop.setType(types.indexOf(jsonObject.getString("type")));//商铺类型
			}
			if (jsonObject.getString("manageStatus").equals("经营中")){
				shop.setManageStatus(0);
			}else{
				shop.setManageStatus(1);//经营状态
			}
			if (jsonObject.getString("floor").contains("1层")){
				shop.setFloor1(true);
			}else if (jsonObject.getString("floor").contains("2层")){
				shop.setFloor2(true);
			}else if (jsonObject.getString("floor").contains("3层")){
				shop.setFloor3(true);
			}else if (jsonObject.getString("floor").contains("4层")){
				shop.setFloor4(true);//楼层
			}
			if (StringUtils.isNotBlank(jsonObject.getString("parentManageTypeId"))){
				Integer id = shopMapper.selectParentManageTypeName(jsonObject.getString("parentManageTypeId"));
				if (id != null){
					shop.setParentManageTypeId(id);//经营一级业态
				}
			}
			shop.setIntroduce(jsonObject.getString("introduce"));//房屋描述
			shop.setShopName(jsonObject.getString("shopName"));//店名
			//设置区域商圈id
			//String areaStr = jsonObject.getString("areaId");
			shop.setAreaId(110101);
			shop.setBusinessAreaId(2);
			shop.setCreateTime(new Date());
			//设置类型
			shop.setRentType(Integer.valueOf(jsonObject.getString("rent_type")));
			if (shop.getRentType().equals("2")){
				shop.setCommission("成交价的1%");
			}else{
				shop.setCommission("0.1个月的租金");
			}
			//商铺编号
			shop.setShopNumber(this.showInfoService.getNextCustomerID("S"));
			shopMapper.saveAll(shop);
			String[] shopSupportingArray = jsonObject.getJSONArray("supporting").toArray(new String[] {});
			List<String> shopSupports = Arrays.asList(shopSupportingArray);
			List<String> support = Arrays.asList("1","380V","煤气","排污管道","明火","上水","天然气","停车位","外摆区","下水","烟道管");
			List<Map<String,Object>> mapList = new ArrayList<>();
			for (String a : shopSupports){
				if (support.contains(a)){
					Map<String,Object> map = new HashMap<>();
					map.put("object_id",shop.getId());
					map.put("d_value",support.indexOf(a));
					map.put("type",1);
					map.put("dic_type",135);
					mapList.add(map);
				}
			}
			if (mapList.size() > 0){
				officeDicService.saveAll(mapList);//保存商铺配套
			}
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}

	/**
	 * 爬虫录入数据
	 */
	@Override
	public ResultObject crawlerNewDiskShop(JSONObject jsonObject) {
		ResultObject resultObject = new ResultObject();
		try {
			Shop shop = new Shop();
			shop.setRealAddress(jsonObject.getString("address"));//详细地址
			shop.setIntroduce(jsonObject.getString("status"));//楼盘动态
			shop.setShopAverage(new Double(jsonObject.getString("price")));//均价
			shop.setAgentId("1");//爬取数据无经纪人，在此设置经纪人默认id为1  对应user_app表id
			shop.setCity(jsonObject.getInteger("cityId"));//城市id
			shopMapper.saveAll(shop);
			String[] label = jsonObject.getJSONArray("label").toArray(new String[] {});
			List<String> la = Arrays.asList(label);
			List<String> stringList = Arrays.asList("1","随时看铺","繁华地段","临街旺铺","价值低洼","免费车位","交通便利");
			List<Map<String,Object>> mapList = new ArrayList<>();
			for (String a : la){
				if (stringList.contains(a)){
					Map<String,Object> map = new HashMap<>();
					map.put("object_id",shop.getId());
					map.put("d_value",stringList.indexOf(a));
					map.put("type",1);
					map.put("dic_type",536);
					mapList.add(map);
				}
			}
			if (mapList.size() > 0){
				officeDicService.saveAll(mapList);//商铺出售特殊标签
			}
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("商铺新盘爬虫推送接口错误...");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}

	@Override
	public ResultObject selectMyAppHomeEntrustPage(Map<String, Object> parameters) {
		if (String.valueOf(parameters.get("type")).equals("1")){
			parameters.put("type",2);
		}else{
			parameters.put("type",1);
		}
		ResultObject resultObject = new ResultObject();
		try {
			List<Map<String, Object>>  list=shopMapper.selectMyAppHomeEntrustPage(parameters);
			if(list !=null && list.size()>0){
				for(Map<String, Object> temp:list){
					IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(temp.get("account")+"");
					if(ivrEn !=null){
						temp.put("ivrType", ivrEn.getIvrType());
						temp.put("ivrPhone", ivrEn.getIvrPhone());
						temp.put("ivrKey", ivrEn.getIvrKey());
					}else{
						temp.put("ivrType", "");
						temp.put("ivrPhone", "");
						temp.put("ivrKey", "");
					}
				}
			}
			resultObject.put("data",list);
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}

	@Override
	public ResultObject updateTel(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			if (String.valueOf(parameters.get("id")).contains("ls")){
				parameters.put("id",String.valueOf(parameters.get("id")).replaceAll("ls_",""));
				shopMapper.updateShopTel(parameters);
			}else{
				parameters.put("id",String.valueOf(parameters.get("id")).replaceAll("lo_",""));
				shopMapper.updateOfficeTel(parameters);
			}
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}


	public  List<Map<String,Object>> jsonShopChildrent(){
		 List<Map<String,Object>> childrenList=new ArrayList<Map<String,Object>>();
		 Map<String,Object> ch1=new HashMap<String,Object>();
		 ch1.put(ShopEnum.RentType.RENT.getValue(), ShopEnum.RentType.RENT.getName());
		 childrenList.add(ch1);
		 Map<String,Object> ch2=new HashMap<String,Object>();
		 ch2.put(ShopEnum.RentType.SALE.getValue(), ShopEnum.RentType.SALE.getName());
		 childrenList.add(ch2);
		 Map<String,Object> ch3=new HashMap<String,Object>();
		 ch3.put(ShopEnum.RentType.NEWS_RENT.getValue(), ShopEnum.RentType.NEWS_RENT.getName());
		 childrenList.add(ch3);
		 Map<String,Object> ch4=new HashMap<String,Object>();
		 ch4.put(ShopEnum.RentType.NEWS_SALE.getValue(), ShopEnum.RentType.NEWS_SALE.getName());
		 childrenList.add(ch4);
		 return childrenList;
	}
	
	public  List<Map<String,Object>> jsonOfficeChildrent(){
		 List<Map<String,Object>> childrenList=new ArrayList<Map<String,Object>>();
		 Map<String,Object> ch1=new HashMap<String,Object>();
		 ch1.put(OfficeEnum.TypeSale.RENT.getValue(), OfficeEnum.TypeSale.RENT.getName());
		 childrenList.add(ch1);
		 Map<String,Object> ch2=new HashMap<String,Object>();
		 ch2.put(OfficeEnum.TypeSale.SALE.getValue(), OfficeEnum.TypeSale.SALE.getName());
		 childrenList.add(ch2);
		 Map<String,Object> ch3=new HashMap<String,Object>();
		 ch3.put(OfficeEnum.TypeSale.NEWS_RENT.getValue(), OfficeEnum.TypeSale.NEWS_RENT.getName());
		 childrenList.add(ch3);
		 Map<String,Object> ch4=new HashMap<String,Object>();
		 ch4.put(OfficeEnum.TypeSale.NEWS_SALE.getValue(), OfficeEnum.TypeSale.NEWS_SALE.getName());
		 childrenList.add(ch4);
		 return childrenList;
	}
	
	@Override
	public ResultObject findMyPublishShopPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {

			this.officeService.analysisLeftRight(paraMap);//解析搜索条件id为区间
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<PublishShopVo> list= this.shopMapper.findMyPublishShopPage(paraMap);
			if(list!=null && list.size()>0){
				for(PublishShopVo temp:list){
					//跟进状态
					Map<String,Object> statusMap=new HashMap<String,Object>();
					statusMap.put("projectId", temp.getId());
					statusMap.put("projectType", ProjectEnum.ProjectType.SHOP.getValue());
					temp.setLabel(this.showInfoService.findLabelByObjId(temp.getId()+"", ProjectEnum.ProjectType.OFFICE.getValue(), ShopEnum.SHOP_LABEL_KEY));
					temp.setSumMyFollowList(this.officeService.getSumFiveStatusList(temp.getId()+"",ProjectEnum.ProjectType.SHOP.getValue(),""));//看所有人的
				}
			}
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	

	//=========================================================================app end
	

	@Override
	public ResultObject selectShopManager(Map<String, Object> paraMap) {
        logger.info("===========================[ShopServiceImpl][selectShopManager],param{}",paraMap);
        ResultObject resultObject = new ResultObject();
        try {
            Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
            Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
            PageHelper.startPage(pageNum, pageSize, true);
            PageInfo<Map<String, Object>> mapPageInfo = new PageInfo<>(this.shopMapper.selectShopManager(paraMap));
            List<Map<String, Object>> list = mapPageInfo.getList();
            if(list!=null && list.size()>0) {
                for (Map<String, Object> temp : list) {
                    //获取orderStatus数值对应的name
                    if(null != temp.get("orderStatus")){
                        ProjectEnum.OrderStatus orderStatus = ProjectEnum.OrderStatus.codeOf(temp.get("orderStatus").toString());
                        temp.put("orderStatusStr",orderStatus.getName());
                    }
                    //获取rentType数值对应的name
                    if(null != temp.get("rentType")){
                        ShopEnum.RentType rentType = ShopEnum.RentType.codeOf(temp.get("rentType").toString());
                        temp.put("rentTypeStr",rentType.getName());
                    }
                }
            }
            resultObject.put("list", list);
            resultObject.put("totalCount", mapPageInfo.getTotal());
            return resultObject;
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject getFollowSearch(Map<String, Object> map) {
        logger.info("===========================[ShopServiceImpl][getFollowSearch],param{}",map);
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String, Object>> areaList = this.areasMapper.selectByParentId(map.get("cityId")+"");
            resultObject.put("areaList",areaList);
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

	@Override
	public ResultObject selectPage(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			List<Map<String, Object>> myCreateShop = shopMapper.selectPage(parameters);
			resultObject.put("data", myCreateShop);
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}
	
	@Override
	public ResultObject findMyPublishAll(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			List<MyPublishPC> myList = shopMapper.findMyPublishAll(parameters);
			resultObject.put("data", myList);
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}
	
	
	
	@Override
	public ResultObject pcShopDetail(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		resultObject.put("myRoleType", "2");//默认我是客源
		resultObject.put("nodes","");
		resultObject.put("recordList", "");
		resultObject.put("renGouList", "");
		resultObject.put("signList", "");
		resultObject.put("jieYongList", "");
		resultObject.put("completeList", "");
		try {
			Map<String,Object> basic=new HashMap<String,Object>();
			String projectId=paraMap.get("projectId")+"";
			String projectType=ProjectEnum.ProjectType.SHOP.getValue();
			
			//基本信息：
			basic=this.shopMapper.findEntityById(projectId);
			if(basic==null){
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("入参projectId("+projectId+")有误，查无数据！");
				return resultObject;
			}

			//判断出租是否有月租 如果为空或者为-2时 则为面议
			if (String.valueOf(basic.get("daily_rent")).equals("面议")){
				basic.put("monthly_rent","面议");
				basic.put("monthly_rent_u","");
			}
			//业态
			basic.put("son_no_type_id", this.shopBusinessTypeMapper.findNameById(basic.get("parent_manage_type_id")+""));
			
			//名称
			basic.put("name", this.jsonDetailShopName(basic));
			//主图
			basic.put("imgs", Arrays.asList(String.valueOf(basic.get("imgs")).split(",")));
			//标签
			resultObject.put("labelList", this.showInfoService.findLabelByObjId(projectId,projectType , ShopEnum.SHOP_LABEL_KEY));
			Map<String,Object> labelMap=new HashMap<String,Object>();
			labelMap.put("parentKey", ShopEnum.SHOP_LABEL_KEY);
			resultObject.put("labelListAll",this.dictionaryMapper.selectBankList(labelMap));
			//新盘位置图
			if( !ObjectHelpUtils.isMyNull(basic.get("position_img")+"")){
				basic.put("site_imgs",new ArrayList<Object>());
			}else{
				basic.put("site_imgs",Arrays.asList(String.valueOf(basic.get("position_img")).split(",")));
			}
			//新盘平面图
			if( !ObjectHelpUtils.isMyNull(basic.get("plane_imgs")+"")){
				basic.put("plane_imgs",new ArrayList<Object>());
			}else{
				basic.put("plane_imgs",Arrays.asList(String.valueOf(basic.get("plane_img")).split(",")));
			}
			basic.put("build_area_text", this.showInfoService.findLabelByObjId(projectId, "1", ShopEnum.NEW_ACREAGE));
			//是否分割
			if ("true".equals(basic.get("separate")+"")){
				basic.put("separate", "可分割");
			}else{
				basic.put("separate", "不可分割");
			}
			
			IvrKeyShow ivrEn =this.fourHundredService.findIvrKeyShow(basic.get("phone")+"");
			basic.put("phone", ivrEn.getIvrAll());
			resultObject.put("basic", basic);
			//配套设施：
			resultObject.put("supportingList", this.showInfoService.findLabelByOid2(projectId, projectType, ShopEnum.SHOP_LABEL_KEY));
			//客源控制按钮
			//String ifShow=this.projectOrderService.jsonCustomerOnlyOne(paraMap.get("projectId")+"",paraMap.get("projectType")+"");
			resultObject.put("show", "show");
			//nodes+
			this.officeService.jsonRoleType(resultObject, projectId, projectType, paraMap.get("loginUserId")+"" , basic.get("agent_id")+"");
			//跟进记录-列表：
			this.officeService.followLog(projectId, projectType, paraMap.get("loginUserId")+"", resultObject);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 *  商铺详情页标题优化
	 *  商铺出售	{区域+商圈+面积+商铺出售}
		商铺出租	{区域+商圈+面积+商铺出租}
		商业新盘出售	{楼盘名称}
		商业新盘出租	{楼盘名称}

	 * @param entityMap
	 * @return
	 */
	public String jsonDetailShopName(Map<String,Object> entityMap){
		String rentType=entityMap.get("rent_type")+"";
		String officeName="";
		String areaName =this.areasMapper.selectById(entityMap.get("area_id")+"");
		String regionName = this.regionsMapper.findNameById(entityMap.get("business_area_id")+"");
		String mianJi=entityMap.get("build_area")+""+entityMap.get("build_area_u");
		if(OfficeEnum.TypeSale.RENT.getValue().equals(rentType)){
			officeName=areaName+regionName+mianJi+"商铺出租";
		}else if(OfficeEnum.TypeSale.SALE.getValue().equals(rentType)){
			officeName=areaName+regionName+mianJi+"商铺出售";
		}else {
			officeName=entityMap.get("name")+"";
		}
		return officeName;
	}
	


	/**
	 * 我的委托 铺源 客源
	 * @param parameters
	 * @return
	 */
	@Override
	public ResultObject selectMyHomeEntrustPage(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			resultObject.put("data",shopMapper.selectMyHomeEntrustPage(parameters));
			return resultObject;
		}catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
	}


	/**
	 * app商铺详情   
	 * @param basic
	 * @return
	 */
	@Override
	public ResultObject appShopDetail(Map<String,Object> paraMap){
		ResultObject resultObject = new ResultObject();
		try{
			String id=paraMap.get("projectId")+"";
			String projectType=ProjectEnum.ProjectType.SHOP.getValue();
			Map<String,Object> entityMap=this.shopMapper.findEntityById(id);
			OfficeDetailApp entity=new OfficeDetailApp();
			entity.setName(this.jsonDetailShopName(entityMap));
			entity.setRent_type(entityMap.get("rent_type") + "");
			entity.setAve_price(entityMap.get("ave_price")+"");
			entity.setAve_price_u(entityMap.get("ave_price_u")+"");
			entity.setUnit_price(entityMap.get("unit_price")+"");
			entity.setUnit_price_u(entityMap.get("unit_price_u")+"");
			entity.setBuild_area(entityMap.get("build_area")+"");
			entity.setBuild_area_u(entityMap.get("build_area_u")+"");
			// entity.setBuild_areas(entityMap.get("build_areas")+"");
			entity.setBuild_areas(entityMap.get("build_areas")+"");
			entity.setTotal_price(entityMap.get("totalPrice")+"");
			entity.setTotalPrice_u(entityMap.get("totalPrice_u")+"");
			entity.setCommission(entityMap.get("commission")+"");
			entity.setDeveloper(entityMap.get("open_worker")+"");
			entity.setImgs(Arrays.asList(String.valueOf(entityMap.get("imgs")).split(",")));
			if( !ObjectHelpUtils.isMyNull((entityMap.get("introduce")+""))){
				entity.setIntroduce(entityMap.get("introduce") + "");
			}
			if( !ObjectHelpUtils.isMyNull(entityMap.get("support_profile")+"")){
				entity.setIntroduceMating(entityMap.get("support_profile") + "");
			}
			
			entity.setLabel(this.showInfoService.findLabelByObjId(id,projectType, ShopEnum.SHOP_LABEL_KEY));
			entity.setPositionx(entityMap.get("positionx")+"");
			entity.setPositiony(entityMap.get("positiony")+"");
			entity.setReal_address(entityMap.get("real_address")+"");
			entity.setShop_number(entityMap.get("shop_number")+"");
			entity.setType(entityMap.get("type")+"");
			entity.setExpired("客户签约日期后"+entityMap.get("expired")+"天内");
			entity.setFloor_current(entityMap.get("floor_total")+"");
			if (Objects.isNull(entityMap.get("build_areas"))){
				entity.setBuild_areas("暂无");
			}
			//业态
			if(Objects.nonNull(entityMap.get("parent_manage_type_id"))){
				String name = this.shopBusinessTypeMapper.findNameById(entityMap.get("parent_manage_type_id")+"");
				if (StringUtils.isNotBlank(name)){
					entity.setYetai(name);
				}else{
					entity.setYetai("暂无");
				}
			}else{
				entity.setYetai("暂无");
			}
			entity.setDaily_rent(entityMap.get("daily_rent")+"");
			entity.setDaily_rent_u(entityMap.get("daily_rent_u")+"");
			if(Objects.isNull(entityMap.get("monthly_rent"))){
				entity.setMonthly_rent("面议");
				entity.setMonthly_rent_u("");
			}else{
				entity.setMonthly_rent(entityMap.get("monthly_rent")+"");
				entity.setMonthly_rent_u(entityMap.get("monthly_rent_u")+"");
			}
			entity.setTransfer_fee_u("万元");
			entity.setDecorate(entityMap.get("decorate")+"");
			entity.setStation(entityMap.get("station")+"");
			entity.setRegister(entityMap.get("register")+"");
			entity.setSeparate(entityMap.get("separate")+"");
			if (entity.getSeparate().equals("true")){
				entity.setSeparate("可分割");
			}else{
				entity.setSeparate("不可分割");
			}
			entity.setTransfer_fee(entityMap.get("transfer_fee")+"");
			entity.setManage_status(entityMap.get("manage_status")+"");
			if("临街".equals(entityMap.get("frontage")+"") || "true".equals(entityMap.get("frontage")+"")){
				entity.setFrontage("是");
			}else{
				entity.setFrontage("否");
			}
			
			entity.setPay_method(entityMap.get("pay")+"");
			entity.setOpen_time(entityMap.get("open_time")+"");
			//位置图
			if( !ObjectHelpUtils.isMyNull(entityMap.get("position_img")+"")){
				entity.setSite_imgs(Arrays.asList(String.valueOf(entityMap.get("position_img")).split(",")) );
			}
			//平面图
			if( !ObjectHelpUtils.isMyNull(entityMap.get("plane_img")+"")){
				entity.setPlane_imgs(Arrays.asList(String.valueOf(entityMap.get("plane_img")).split(",")) );
			}

			//配套设施：
			resultObject.put("supportingList", this.showInfoService.findLabelByOid2(id, projectType, ShopEnum.SHOP_MATCHE_KEY));
			//铺源动态  
			Map<String,Object> dyMap=new HashMap<String,Object>();
			dyMap.put("projectId", id);
			dyMap.put("projectType", ProjectEnum.ProjectType.SHOP.getValue());
			entity.setDynamicList(this.projectOrderMapper.findDynamicList(dyMap));

			//为你推荐
			List<Map<String,Object>> recommendedList=new ArrayList<Map<String,Object>>();
			if("1".equals(entityMap.get("online_status")+"") && "2".equals(entityMap.get("shop_audit")+"")){
				Map<String,Object> recoMap=new HashMap<String,Object>();
				recoMap.put("pageNum", "1");
				recoMap.put("pageSize", "5");
				recoMap.put("rentType", entityMap.get("rent_type")+"");
				ResultObject tjResult=this.selectShopPage(recoMap);
				recommendedList=(List<Map<String,Object>>)tjResult.get("list");
				entity.setRecommendedList(recommendedList);
			}
			resultObject.put("basic",entity);
			//节点：
			this.officeService.jsonRoleType(resultObject, id, projectType, paraMap.get("loginUserId")+"" , entityMap.get("agent_id")+"");
			AgentEntity  agEn=this.officeService.findAgentEntity(entityMap.get("agent_id")+"");
			agEn.setName(entityMap.get("linkman")+"");
			//agEn.setTel(entityMap.get("phone")+"");//不要经纪人信息，要发布时填的联系方式
			IvrKeyShow ivrEn =this.fourHundredService.findIvrKeyShow(entityMap.get("phone")+"");
			if(ivrEn !=null){
				agEn.setIvrType(ivrEn.getIvrType());
				agEn.setIvrPhone(ivrEn.getIvrPhone());
				agEn.setIvrKey(ivrEn.getIvrKey());
			}
			resultObject.put("agentEntiy",agEn);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	

	@Override
	public ResultObject shopOut(Map<String,Object> params) {
		ResultObject resultObject=new ResultObject();
		try {
			this.shopMapper.updateShopOnlineStatus(params);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_ERROR);
			resultObject.setMessage("异常");
			e.printStackTrace();
		}
		return resultObject;
	}
	
	

}
