package com.up.zpb.util;

import java.beans.BeanInfo;
import java.beans.Introspector;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;
import java.util.regex.Pattern;

//import net.sf.json.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson.util.Base64;

public abstract class ObjectHelpUtils {
    public static final Logger LOGGER = LoggerFactory.getLogger(ObjectHelpUtils.class);
    public static final Object NULL = null;

    public static boolean isNull(Object o) {
        return o == null;
    }

    public static boolean notNull(Object o) {
        return !isNull(o);
    }

    public static boolean isEmpty(Object o) {
        if (isNull(o)) {
            return true;
        }

        if ((o instanceof String)) {
            return "".equals(o.toString());
        }
        if ((o instanceof Collection)) {
            return ((Collection) o).isEmpty();
        }
        if ((o instanceof Map)) {
            return ((Map) o).isEmpty();
        }
        if (o.getClass().isArray()) {
            return Array.getLength(o) == 0;
        }

        return true;
    }

    public static boolean notEmpty(Object o) {
        return !isEmpty(o);
    }

    //true-表示是空的
    public static boolean isMyNull(String str) {
    	if(str ==null || "".equals(str) || "null".equals(str)){
    		return true;
    	}
    	return false;
    }
    
    public static <T> T nullSafe(T actual, T safe) {
        return actual == null ? safe : actual;
    }

    public static <T> T mapToObject(Map<String, Object> map, Class<T> beanClass) throws Exception {
        return (T) setValToObj(beanClass.newInstance(), mapToString(map));
    }

    public static Object setValToObj(Object entityName, Map<String, String> para) {
        try {
            Class c = entityName.getClass();
            // 获得对象属性
            Field field[] = c.getDeclaredFields();
            for (Field f : field) {
                if ("serialVersionUID".equals(f.getName())) {
                    continue;
                }
                PropertyDescriptor pd = new PropertyDescriptor(f.getName(), c);
                Method writeMethod = pd.getWriteMethod();
                if (null != para.get(f.getName()))
                    writeMethod.invoke(entityName, ConvertType(f.getType().toString(), para.get(f.getName())));

            }
        } catch (Exception e) {
            LOGGER.error("反射设置对象属性出错了", e);
            throw new RuntimeException(e);
        }
        return entityName;
    }

    //设置对象所有的字段,包含父类的字段
    public static Object setValToObjWithSuperClass(Object entityName, Map<String, String> para) {
        try {
            Class c = entityName.getClass();
            // 获得对象属性
            Field field[] = getField(c);
            for (Field f : field) {
                try {

                    PropertyDescriptor pd = new PropertyDescriptor(f.getName(), c);
                    Method writeMethod = pd.getWriteMethod();
                    if (null != para.get(f.getName()))
                        writeMethod.invoke(entityName, ConvertType(f.getType().toString(), para.get(f.getName())));
                } catch (Exception e) {
                    LOGGER.error("字段" + f.getName() + "(" + f.getType().toString() + ")反射错误", e);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return entityName;
    }

    //获取对象所有的字段,包含父类的字段
    private static Field[] getField(Class<?> clazz) {

        Set<Field> fields = new HashSet<>();


        for (; clazz != Object.class; clazz = clazz.getSuperclass()) {

            Field field[] = clazz.getDeclaredFields();
            for (Field f : field) {
                if ("serialVersionUID".equals(f.getName())) {
                    continue;
                }
                //移除静态字段
                if (Modifier.isStatic(f.getModifiers())) {
                    continue;
                }
                fields.add(f);
            }
        }

        return fields.toArray(new Field[]{});
    }

    /**
     * 将一个 JavaBean 对象转化为一个  Map
     *
     * @param bean
     * @return
     */
    public static SortedMap convertBean(Object bean) {
        SortedMap<String, Object> map = new TreeMap<String, Object>();
        try {
            if (bean != null) {
                BeanInfo beanInfo = Introspector.getBeanInfo(bean.getClass());
                PropertyDescriptor[] propertyDescriptors = beanInfo.getPropertyDescriptors();
                for (PropertyDescriptor property : propertyDescriptors) {
                    String key = property.getName();
                    if (key.compareToIgnoreCase("class") == 0) {
                        continue;
                    }
                    Method getter = property.getReadMethod();
                    Object value = getter != null ? getter.invoke(bean) : null;
                    map.put(key, value);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return map;


    }

    /**
     * 描述   类型转换
     *
     * @param type
     * @param value
     * @return
     */
    public static Object ConvertType(String type, String value) {
        if (type.endsWith("int") || type.endsWith("Integer")) {
            if (StringUtils.isEmpty(value)) {
                return 0;
            } else {
                return Integer.valueOf(value.toString());
            }
        } else if (type.endsWith("long") || type.endsWith("Long")) {
            if (StringUtils.isEmpty(value)) {
                return 0l;
            } else {
                return Long.valueOf(value.toString());
            }
        } else if (type.endsWith("boolean") || type.endsWith("Boolean")) {
            if (StringUtils.isEmpty(value)) {
                return false;
            } else {
                return Boolean.valueOf(value);
            }

        } else if (type.endsWith("BigDecimal")) {
            if (StringUtils.isEmpty(value)) {
                return new BigDecimal(0.00);
            } else {
                return new BigDecimal(value.toString());
            }

        } else {
            return value.toString();
        }
    }

    public static Map<String, String> mapToString(Map<String, Object> map) {
        Map<String, String> newMap = new ConcurrentHashMap<String, String>();
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            if (entry.getValue() instanceof String) {
                newMap.put(entry.getKey(), (String) entry.getValue());
            }
        }
        return newMap;
    }

    /**
     * 将分转换成元
     *
     * @param obj
     * @return
     */
    public static BigDecimal convertYuan(Object obj) {
        float num = Float.valueOf(obj.toString()) / 100;
        DecimalFormat df = new DecimalFormat("0.00");
        String str = df.format(num);
        return new BigDecimal(str);
    }

    /**
     * 将元转换成分
     *
     * @param dec
     * @return
     */
    public static BigDecimal yuantofen(BigDecimal dec) {
        if (dec.compareTo(BigDecimal.ZERO) == 0) {
            return new BigDecimal(0);
        }
        //乘以100(单位：分)
        return dec.multiply(new BigDecimal(100));

    }
    
    /**
     * 元转换成万元   
     * @param dec
     * @return
     */
    public static BigDecimal yuanToWanYuan(BigDecimal dec) {
    	 if (dec.compareTo(BigDecimal.ZERO) == 0) {
             return dec;
         }
         BigDecimal amt = dec.divide(new BigDecimal(10000),2,BigDecimal.ROUND_HALF_UP);
         return amt;
    }
    /**
     * 元转换成万元   
     * @param dec
     * @return
     */
    public static BigDecimal wanYuantoYuan(BigDecimal dec) {
    	 if (dec.compareTo(BigDecimal.ZERO) == 0) {
             return dec;
         }
         BigDecimal amt = dec.multiply(new BigDecimal(10000)).setScale(2,BigDecimal.ROUND_HALF_UP);
         return amt;
    }

    /**
     * 定义分割常量 （@在集合中的含义是每个元素的分割，#主要用于map类型的集合用于key与value中的分割）
     */
    private static final String SEP1 = "=";
    private static final String SEP2 = "&";

    /**
     * Map转换String
     *
     * @param map :需要转换的Map
     * @return String转换后的字符串
     */
    public static String MapToString(Map<?, ?> map) {
        StringBuffer sb = new StringBuffer();
        // 遍历map
        for (Object obj : map.keySet()) {
            if (obj == null) {
                continue;
            }
            Object key = obj;
            Object value = map.get(key);
            if (value instanceof List<?>) {
                sb.append(key.toString() + SEP1 + ListToString((List<?>) value));
                sb.append(SEP2);
            } else if (value instanceof Map<?, ?>) {
                sb.append(key.toString() + SEP1
                        + MapToString((Map<?, ?>) value));
                sb.append(SEP2);
            } else {
                sb.append(key.toString() + SEP1 + value.toString());
                sb.append(SEP2);
            }
        }
            /*return "M" + EspUtils.EncodeBase64(sb.toString());  */
        return "#" + sb.toString();
    }

    /**
     * String转换Map
     *
     * @param mapText :需要转换的字符串
     *                KeySeparator     :字符串中的分隔符每一个key与value中的分割
     *                ElementSeparator :字符串中每个元素的分割
     * @return Map<?,?>
     */
    public static Map<String, Object> StringToMap(String mapText) {

        if (mapText == null || mapText.equals("")) {
            return null;
        }
        mapText = mapText.substring(1);
        /*mapText = EspUtils.DecodeBase64(mapText);  */

        Map<String, Object> map = new ConcurrentHashMap<String, Object>();
        String[] text = mapText.split("\\" + SEP2); // 转换为数组
        for (String str : text) {
            String[] keyText = str.split(SEP1); // 转换key与value的数组
            if (keyText.length < 1) {
                continue;
            }
            String key = keyText[0]; // key
            if (keyText.length > 1) {
                String value = keyText[1]; // value
                if (value.charAt(0) == '#') {
                    Map<?, ?> map1 = StringToMap(value);
                    map.put(key, map1);
                } else if (value.charAt(0) == '@') {
                    List<?> list = StringToList(value);
                    map.put(key, list);
                } else {
                    map.put(key, value);
                }
            }
        }
        return map;
    }

    /**
     * List转换String
     *
     * @param list :需要转换的List
     * @return String转换后的字符串
     */
    public static String ListToString(List<?> list) {
        StringBuffer sb = new StringBuffer();
        if (list != null && list.size() > 0) {
            for (int i = 0; i < list.size(); i++) {
                if (list.get(i) == null || list.get(i) == "") {
                    continue;
                }
                // 如果值是list类型则调用自己
                if (list.get(i) instanceof List) {
                    sb.append(ListToString((List<?>) list.get(i)));
                    sb.append(SEP1);
                } else if (list.get(i) instanceof Map) {
                    sb.append(MapToString((Map<?, ?>) list.get(i)));
                    sb.append(SEP1);
                } else {
                    sb.append(list.get(i));
                    sb.append(SEP1);
                }
            }
        }
        // return "L" + EspUtils.EncodeBase64(sb.toString());
        return "@" + sb.toString();
    }


    /**
     * String转换List
     * Map 	 --用#
     * List用  --用@
     *
     * @param listText :需要转换的文本
     * @return List<?>
     */
    public static List<Object> StringToList(String listText) {
        if (listText == null || listText.equals("")) {
            return null;
        }
        listText = listText.substring(1);
        //listText = EspUtils.DecodeBase64(listText);

        List<Object> list = new ArrayList<Object>();
        String[] text = listText.split(SEP1);
        for (String str : text) {
            if (str.charAt(0) == '#') {
                Map<?, ?> map = StringToMap(str);
                list.add(map);
            } else if (str.charAt(0) == '@') {
                List<?> lists = StringToList(str);
                list.add(lists);
            } else {
                list.add(str);
            }
        }
        return list;
    }

    /**
     * 描述   转换Map<String, Object>===》Map<String, String>
     *
     * @param mapObj
     * @return
     */
    public static Map<String, String> ConvertMapObjToMapString(Map<String, Object> mapObj) {
        Map<String, String> mapStr = new HashMap<String, String>();
        Iterator<Entry<String, Object>> it = mapObj.entrySet().iterator();
        while (it.hasNext()) {
            Entry<String, Object> entry = it.next();
            String key = entry.getKey();
            Object value = entry.getValue();
            mapStr.put(key, value == null ? null : value.toString());
        }
        return mapStr;
    }

    /**
     * 描述   转换Map<String, Object>===》Map<String, String>
     *
     * @param mapStr
     * @return
     */
    public static Map<String, Object> ConvertMapStringToMapObj(Map<String, String> mapStr) {
        Map<String, Object> mapObj = new ConcurrentHashMap<String, Object>();
        Iterator<Entry<String, String>> it = mapStr.entrySet().iterator();
        while (it.hasNext()) {
            Entry<String, String> entry = it.next();
            String key = entry.getKey();
            Object value = entry.getValue();
            mapObj.put(key, value);
        }
        return mapObj;
    }

    public static BigDecimal formateRate(String value) {
        return new BigDecimal(value).divide(new BigDecimal(100)).setScale(4, BigDecimal.ROUND_HALF_UP);
    }


    public static Map<String, Object> objectToMap(Object obj) throws Exception {
        if (obj == null) {
            return null;
        }
        Map<String, Object> map = new HashMap<String, Object>();
        Field[] declaredFields = obj.getClass().getDeclaredFields();
        for (Field field : declaredFields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(obj));
        }
        return map;
    }

    public static Map<String, Object> objectToMapStr(Object obj) throws Exception {
        if (obj == null) {
            return null;
        }
        Map<String, Object> map = new HashMap<String, Object>();
        Field[] declaredFields = obj.getClass().getDeclaredFields();
        for (Field field : declaredFields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(obj)+"");
        }
        return map;
    }

    public static Map<String, Object> objectToMapWithSuperClass(Object obj) throws Exception {
        if (obj == null) {
            return null;
        }
        Map<String, Object> map = new HashMap<>();
        Field[] declaredFields = getField(obj.getClass());
        for (Field field : declaredFields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(obj));
        }
        return map;
    }



    /**
     * 描述   list转String
     *
     * @param stringList
     * @return
     */
    public static String converListToString(List<String> stringList) {
        if (stringList == null) {
            return null;
        }
        StringBuilder result = new StringBuilder();
        boolean flag = false;
        for (String string : stringList) {
            if (flag) {
                result.append(",");
            } else {
                flag = true;
            }
            result.append(string);
        }
        return result.toString();
    }


    /**
     * 描述   随机生成10位数
     *
     * @return
     */
    public static String suiJiRandom() {
        int ss = (int) ((Math.random() * 9 + 1) * 1000000000);
        return ss + "";
    }

    /**
     * 生成6位随机数
     * @return
     */
    public static String ranDomSix() {
        int ss = (int) ((Math.random() * 9 + 1) * 100000);
        return ss + "";
    }
    
    
    /**
     * 描述    Map<String, String> 转 Map<String,Object>
     *
     * @param params
     * @return
     */
    public static Map<String, Object> getMapObject(Map<String, String> params) {
        Map<String, Object> bannerMap = new HashMap<>();
        if (!params.isEmpty()) {
            for (Map.Entry<String, String> entry : params.entrySet()) {
                if (entry.getValue() != null && !"".equals(entry.getValue())) {
                    bannerMap.put(entry.getKey(), entry.getValue());
                }
            }
        }
        return bannerMap;
    }

    /*
     * 判断是否为整数 
     * @param str 传入的字符串 
     * @return 是整数返回true,否则返回false 
     */
    public static boolean isInteger(String str) {
        Pattern pattern = Pattern.compile("^[-\\+]?[\\d]*$");
        return pattern.matcher(str).matches();
    }

    public static Object setValToObj2(Object entityName, Map<String, Object> para) {
        try {
            Class c = entityName.getClass();
            // 获得对象属性
            Field field[] = c.getDeclaredFields();
            for (Field f : field) {
                try {
                    if ("serialVersionUID".equals(f.getName())) {
                        continue;
                    }
                    PropertyDescriptor pd = new PropertyDescriptor(f.getName(), c);
                    Method writeMethod = pd.getWriteMethod();
                    if (null != para.get(f.getName()))
                        writeMethod.invoke(entityName, ConvertType2(f.getType().toString(), para.get(f.getName())));
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return entityName;
    }

    /**
     * 描述   类型转换
     *
     * @param type
     * @param value
     * @return
     */
    public static Object ConvertType2(String type, Object value) {
        if (type.endsWith("int") || type.endsWith("Integer")) {
            if (null == value || "".equals(value)) {
                return 0;
            } else {
                return value;
            }
        } else if (type.endsWith("long") || type.endsWith("Long")) {
            if (null == value || "".equals(value)) {
                return 0l;
            } else {
                return value;
            }
        } else if (type.endsWith("boolean") || type.endsWith("Boolean")) {
            if (null == value || "".equals(value)) {
                return false;
            } else {
                return value;
            }

        } else if (type.endsWith("BigDecimal")) {
            if (null == value || "".equals(value)) {
                return new BigDecimal(0.00);
            } else {
                return new BigDecimal(value.toString());
            }

        } else {
            return value.toString();
        }
    }

    public static Map<String, String> getUrlParams(String param) {
        Map<String, String> map = new HashMap<>();
        if (StringUtils.isBlank(param)) {
            return map;
        }
        String[] params = param.split("&");
        for (int i = 0; i < params.length; i++) {
            String[] p = params[i].split("=");
            if (p.length == 2) {
                map.put(dealStr(p[0]), dealStr(p[1]));
            }
        }
        return map;
    }

    private static String dealStr(String str) {
        if (StringUtils.isEmpty(str)) {
            return "";
        }
        return str.trim();
    }
    
    
    /**
     * 年月日+N位随机数
     * 例：20190803881612940327
     * @param number  几位的随机数
     * @return
     */
    public static String getRondam(int number){
    	SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyyMMdd");//yyyyMMddHHmmssSSS
    	String timeStamp = simpleDateFormat.format(new Date());
    	String mark = "";
        for (int i = 0; i < number; i++) {
            int random = (int) (Math.random() * 10);
            mark = mark + random;
        }
    	return timeStamp+mark;
    }
	
   /**
    * 输入1————————》输出00001 
    * @param num
    * @return
    */
   public static String formatFiveNum(int num){
	   return String.format("%05d", num);
   }
	
   /**
    * 消息图标转换
    * @param touchType 触发点：
    * @return
    */
   public static String getIcon(String touchType){
	       //touch:0-终止流程 1-电话拒接(被叫挂断）、2-电话未接（振铃挂断）、3-到访4-认购5-签约6-提醒结佣7-其他 8-勾搭9-房源审核通过10-房源审核拒绝11-经纪人分配12-经济公司分配
	 		String icon="6";
	 		if ("3".equals(touchType) || "4".equals(touchType)|| "5".equals(touchType)|| "6".equals(touchType)){
	 			icon="1";//icon:1-到访登记；2-注意啦；3-房源审核通过提醒；4-流程终止提醒；5-新任务提醒；6-其他
	 		}else if ("1".equals(touchType)||"2".equals(touchType)||"8".equals(touchType)){
	 			icon="2";
	 		}else if ("9".equals(touchType) || "10".equals(touchType)){
	 			icon="3";
	 		}else if ("0".equals(touchType)){
	 			icon="4";
	 		}else if ("11".equals(touchType) || "12".equals(touchType)){
	 			icon="5";
	 		}else{
	 			icon="6";
	 		}
	   return icon;
   }
    
    
 //
 	/**
 	 * map转str
 	 * 参数类型是Map<String,String> 
 	 * @param map
 	 * @return
 	 */
 	public static String jsonParamMapToStr(Map<String,String> map){
 		Set<String> keySet = map.keySet();
 		//将set集合转换为数组
 		String[] keyArray = keySet.toArray(new String[keySet.size()]);
 		//给数组排序(升序)
 		//Arrays.sort(keyArray);
 		//因为String拼接效率会很低的，所以转用StringBuilder
 		StringBuilder sb = new StringBuilder();
 		for (int i = 0; i < keyArray.length; i++) {
 			// 参数值为空，则不参与签名 这个方法trim()是去空格
 			if (map.get(keyArray[i]).trim().length() > 0) {
 				sb.append(keyArray[i]).append("=").append(map.get(keyArray[i]).trim());
 			}
 			if(i != keyArray.length-1){
 				sb.append("&");
 			}
 		}
 		return sb.toString();
 	}
	 
	 
    public static void main(String[] args) {
    	
    	//System.out.println("======="+formatFiveNum(2));
	}
    
    
}