package com.up.zpb.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.stream.Stream;

import org.apache.commons.lang.StringUtils;

import com.google.common.collect.Lists;

/**
 * 商铺信息
 * 
 * @author gust
 *
 */
public class Shop {

	/**
	 * 主键id
	 */
	private Integer id;

	/**
	 * 联系人
	 */
	private String linkMan;

	/**
	 * 电话
	 */
	private String phone;

	/**
	 * 年租金（整数,万元）
	 */
	private BigDecimal yearlyRent;

	public String getYearlyRentText() {
		if (Objects.nonNull(yearlyRent) && !Objects.equals(yearlyRent.intValue(), -2)) {
			yearlyRent = yearlyRent.setScale(0, BigDecimal.ROUND_HALF_UP);
		}
		if (yearlyRent == null) {
			return null;
		} else if (yearlyRent.intValue() == -2) {
			return "面议";
		} else {
			return yearlyRent + "万元/年";
		}
	}

	/**
	 * 月租金（2位小数,元/月）
	 */
	private BigDecimal monthlyRent;

	public String getMonthlyRentText() {
		if (Objects.nonNull(monthlyRent) && !Objects.equals(monthlyRent.intValue(), -2)) {
			monthlyRent = monthlyRent.setScale(0, BigDecimal.ROUND_HALF_UP);
		}
		if (monthlyRent == null) {
			return null;
		} else if (monthlyRent.intValue() == -2) {
			return "面议";
		} else {
			return monthlyRent + "元/月";
		}
	}

	/**
	 * 日租金（2位小数,元/天/㎡）
	 */
	private BigDecimal dailyRent;

	public String getDailyRentText() {
		if (dailyRent == null) {
			return null;
		} else if (dailyRent.intValue() == -2) {
			return "面议";
		} else {
			return monthlyRent + "元/天/㎡";
		}
	}

	/**
	 * 转让费（1位小数,万元）
	 */
	private BigDecimal transferFee;

	public String getTransferFeeText() {
		if (transferFee == null) {
			return null;
		} else if (transferFee.intValue() == -1) {
			return "无";
		} else if (transferFee.intValue() == -2) {
			return "面议";
		} else {
			return transferFee + "万元";
		}
	}

	/**
	 * 押金
	 */
	private Integer pledgeMethod; // 0:个月 1：元 2 : 无

	private String pledgeInfo;

	/**
	 * 支付方式 月付,季度付,半年付,年付
	 */
	private Integer payMethod;

	/**
	 * 商铺租售状态（0：租赁中，1：已成交，2：已租出一部分，3：停转/租-违建拆除，4：停转/租-房东收回，5：停转/租-被查封，6：停转/租-继续经营）
	 */
	private Integer status;

	/**
	 * 租售类型(0:商铺出租 1:商铺转租/生意转让)
	 */
	private Integer rentType;

	/**
	 * 分时出租(0:否 1:是-早间出租 2:是-晚间出租 3:是-早、晚出租)
	 */
	private Integer timeRent;

	/**
	 * 当前租约
	 */
	private String currLease;

	/**
	 * 还剩余
	 */
	private String residue;

	/**
	 * 最长可租约
	 */
	private String maxLease;

	/**
	 * 商铺类型 商业街商铺, 社区商业, 写字楼配套, 市场, 百货购物中心, 学校, 村镇商铺, 档口摊位, 其他
	 */
	private Integer type;

	/**
	 * 建筑面积
	 */
	private BigDecimal buildArea;

	/**
	 * 使用面积
	 */
	private BigDecimal useArea;

	/**
	 * 是否分隔(1 false 否；2 true 是)
	 */
	private Boolean separate;

	/**
	 * 是否临主干道/两车道以上道路(0 false 否；1 true 是)
	 */
	private Boolean frontage;

	/**
	 * 楼层 一层、二层、三层、四层、高层、半地下
	 */
	private Boolean floor1 = false;
	private Boolean floor2 = false;
	private Boolean floor3 = false;
	private Boolean floor4 = false;
	private Boolean floorHigh = false;
	private Boolean floorUnder = false;

	/**
	 * 当前经营/经营业态（一级）
	 */
	private Integer parentManageTypeId;

	/**
	 * 当前经营/经营业态（二级）
	 */
	private Integer sonManageTypeId;

	/**
	 * 证照（0：不可办照，1：可办照，2：公司照可过户，3：有照可增项，4：大照/集体照，5：个人照可用，6：公司照可用，7：个人照可过户）
	 */
	private Integer license;
	/**
	 * 经营状态（0：营业中，1:空铺）
	 */
	private Integer manageStatus;
	/**
	 * 店名
	 */
	private String shopName;

	/**
	 * 证件照
	 */
	private String paperImgs;

	/**
	 * 封面图
	 */
	private String cover;

	/**
	 * 展示图片
	 */
	public String[] getPaperImgArray() {
		if (StringUtils.isEmpty(paperImgs)) {
			return null;
		} else {
			List<String> list = Lists.newArrayList();
			Stream.of(paperImgs.split(",")).forEach(s -> {
				if (s.contains("aliyuncs") && !s.contains("x-oss-process")) {
					s += "?x-oss-process=style/watermark";
				} else if (!s.contains("aliyuncs")) {
					s = "https://static.youpuchina.com" + s;
				}
				list.add(s);
			});
			return list.toArray(new String[] {});
		}
	}

	/**
	 * 市
	 */
	private Integer cityId;
	/**
	 * 区域
	 */
	private Integer areaId;

	/**
	 * 商圈
	 */
	private Integer businessAreaId;

	/**
	 * 道路
	 */
	private Integer roadAreaId;

	/**
	 * 详细地址
	 */
	private String realAddress;

	/**
	 * x坐标
	 */
	private String positionX;

	/**
	 * y坐标
	 */
	private String positionY;
	/**
	 * 环线(0:不限,1:2环内,2:2-3环,3:3-4环,4:4-5环,5:5环外)
	 */
	private Integer loopLine;

	/**
	 * 选择图片
	 */
	private String imgs;

	/**
	 * 后台展示图片
	 */
	public String[] getImgArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			return imgs.split(",");
		}
	}

	/**
	 * 前天展示图片
	 * 
	 * @return
	 */
	public String[] getImgStyleArray() {
		if (StringUtils.isEmpty(imgs)) {
			return null;
		} else {
			List<String> list = Lists.newArrayList();
			Stream.of(imgs.split(",")).forEach(s -> {
				if (s.contains("aliyuncs")) {
					s = s.replace("up-img.oss-cn-beijing.aliyuncs.com", "cdn.youpuchina.com");
					if (!s.contains("x-oss-process")) {
						s += "?x-oss-process=style/watermark";
					}
				}
				list.add(s);
			});
			return list.toArray(new String[] {});
		}
	}

	/**
	 * 介绍
	 */

	private String introduce;

	/**
	 * 营业额分成
	 */
	private String turnoverShare;

	/**
	 * 编号
	 */
	private String shopNumber;

	/**
	 * 名称
	 */
	private String name;

	/**
	 * 上架状态（0 下架 1 上架）
	 */
	private Integer onlineStatus;
	/**
	 * 商铺来源 乐铺, 安居客, 五八同城, 赶集, 房天下, 拍店, 优铺租赁APP提交, 后台录入, 委托转铺, 发布,铺铺旺;
	 */
	private Integer createType;

	/**
	 * 拒绝原因
	 */
	private String remark;

	/**
	 * 证照代表的文本内容
	 * 
	 * @return
	 */
	public String getLicenseText() {
		String licenseText = null;
		switch (this.license) {
		case 0:
			licenseText = "不可办照";
			break;
		case 1:
			licenseText = "可办照";
			break;
		case 2:
			licenseText = "公司照可过户";
			break;
		case 3:
			licenseText = "有照可增项";
			break;
		case 4:
			licenseText = "大照/集体照";
			break;
		case 5:
			licenseText = "个人照可用";
			break;
		case 6:
			licenseText = "公司照可用";
			break;
		case 7:
			licenseText = "个人照可过户";
			break;
		}
		return licenseText;

	}

	/**
	 * 核铺无效（无效原因） 外地, 中介, 空号, 停机, 非商铺;
	 */
	private Integer invalidReason;

	/**
	 * 置顶开始时间
	 */
	private Date topBeginTime;

	/**
	 * 置顶结束时间
	 */
	private Date topEndTime;

	/**
	 * 置顶状态 0 失效 1 置顶
	 */
	private Integer topStatus;

	/**
	 * 是否在发布列表展示标识 0 不展示 1 展示
	 */
	private Integer showFlag;

	/**
	 * 商铺状态 0 待认领
	 */
	private Integer shopFlow;

	/**
	 * 创建时间
	 */
	private Date createTime;
	
	/**
	 * 商铺属性(商铺标签)
	 */
	private Integer shopAttr;
	
	/**
	 * 核铺是否以导入商铺（0 否 1 是）ƒ
	 */
	private Integer isImport;
	
	/**
	 * 结佣时间
	 */
	private String expired;
	/**
	 *  总价
	 */
	private BigDecimal totalPrice;

	/**
	 * 发布人id
	 */
	private Integer customerId;

	/**
	 * 进深
	 */
	private Double depth;

	/**
	 * 面宽
	 */
	private Double faceWidth;

	/**
	 * 合作佣金
	 */
	private String commission;
	private BigDecimal commissionValue=new BigDecimal(0.00);

	/**
	 * 委托书 使用第二个
	 */
	private String entrustImg;
	private String entrustPaper;
	/**
	 * 平台服务费
	 */
	private Double feeService;

	/**
	 * 水费
	 */
	private Double waterFee;

	/**
	 * 电费
	 */
	private Double electricityFee;

	/**
	 * 物业费
	 */
	private Double propertyFee;

	/**
	 * 层高
	 */
	private Double shopHeight;

	/*
	单价
	 */
	private Double price;

	/**
	 * 位置图
	 */
	private String positionImg;

	/**
	 * 平面图
	 */
	private String planeImg;

	/**
	 * 开盘时间
	 */
	private Date openTime;

	/**
	 * 开发商
	 */
	private String openWorker;

	/**
	 * 商铺均价
	 */
	private Double shopAverage;
	private BigDecimal avePrice;
	/**
	 * 楼盘姓名
	 */
	private String floorName;

	/**
	 * 商铺配套 文字形式展示
	 */
	private String shopSupporting;

	/**
	 * 经纪人id
	 */
	private String agentId;

	/**
	 * 单价
	 */
	private BigDecimal unitPrice;
	private BigDecimal customerPrice;

	/**
	 * 不可经营业态二级
	 */
	private Integer sonNoTypeId;

	/**
	 * 佣金类型：1-百分比 2-直接填金额
	 */
	private String commissionType;

	private String title;

	private String titleSub;

	private String titleThree;

	private String titlePc;

	private String titlePcSub;

	//面积 多选
	private String buildAreas;

	/**
	 * 核实
	 */
	private Integer shopVerify; //1:待核实 2:通过 3:拒绝

	private Date verifyTime;

	private Long verifyAccountId;

	/**
	 * 审核
	 */
	private Integer shopAudit; //1:待审核 2:通过 3:拒绝

	private Date auditTime;

	private Long auditAccountId;

	public Integer getShopVerify() {
		return shopVerify;
	}

	public void setShopVerify(Integer shopVerify) {
		this.shopVerify = shopVerify;
	}

	public Date getVerifyTime() {
		return verifyTime;
	}

	public void setVerifyTime(Date verifyTime) {
		this.verifyTime = verifyTime;
	}

	public Long getVerifyAccountId() {
		return verifyAccountId;
	}

	public void setVerifyAccountId(Long verifyAccountId) {
		this.verifyAccountId = verifyAccountId;
	}

	public Integer getShopAudit() {
		return shopAudit;
	}

	public void setShopAudit(Integer shopAudit) {
		this.shopAudit = shopAudit;
	}

	public Date getAuditTime() {
		return auditTime;
	}

	public void setAuditTime(Date auditTime) {
		this.auditTime = auditTime;
	}

	public Long getAuditAccountId() {
		return auditAccountId;
	}

	public void setAuditAccountId(Long auditAccountId) {
		this.auditAccountId = auditAccountId;
	}

	public String getBuildAreas() {
		return buildAreas;
	}

	public void setBuildAreas(String buildAreas) {
		this.buildAreas = buildAreas;
	}

	public String getCommissionType() {
		return commissionType;
	}

	public void setCommissionType(String commissionType) {
		this.commissionType = commissionType;
	}

	public String getTitlePc() {
		return titlePc;
	}

	public void setTitlePc(String titlePc) {
		this.titlePc = titlePc;
	}

	public String getTitlePcSub() {
		return titlePcSub;
	}

	public void setTitlePcSub(String titlePcSub) {
		this.titlePcSub = titlePcSub;
	}

	public String getTitleThree() {
		return titleThree;
	}

	public void setTitleThree(String titleThree) {
		this.titleThree = titleThree;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getTitleSub() {
		return titleSub;
	}

	public void setTitleSub(String titleSub) {
		this.titleSub = titleSub;
	}

	public Integer getSonNoTypeId() {
		return sonNoTypeId;
	}

	public void setSonNoTypeId(Integer sonNoTypeId) {
		this.sonNoTypeId = sonNoTypeId;
	}

	/**
	 * 来源	channel=0-pc  1-ios  2-android
	 */
	private String channel;

	public BigDecimal getCustomerPrice() {
		return customerPrice;
	}

	public void setCustomerPrice(BigDecimal customerPrice) {
		this.customerPrice = customerPrice;
	}

	public String getChannel() {
		return channel;
	}

	public void setChannel(String channel) {
		this.channel = channel;
	}

	public String getEntrustPaper() {
		return entrustPaper;
	}

	public BigDecimal getAvePrice() {
		return avePrice;
	}

	public void setAvePrice(BigDecimal avePrice) {
		this.avePrice = avePrice;
	}

	public void setEntrustPaper(String entrustPaper) {
		this.entrustPaper = entrustPaper;
	}

	public BigDecimal getUnitPrice() {
		return unitPrice;
	}

	public void setUnitPrice(BigDecimal unitPrice) {
		this.unitPrice = unitPrice;
	}

	public String getAgentId() {
		return agentId;
	}

	public void setAgentId(String agentId) {
		this.agentId = agentId;
	}

	public Boolean getSeparate() {
		return separate;
	}

	public void setSeparate(Boolean separate) {
		this.separate = separate;
	}

	public Double getShopHeight() {
		return shopHeight;
	}

	public void setShopHeight(Double shopHeight) {
		this.shopHeight = shopHeight;
	}

	public Double getDepth() {
		return depth;
	}

	public void setDepth(Double depth) {
		this.depth = depth;
	}

	public Double getFaceWidth() {
		return faceWidth;
	}

	public void setFaceWidth(Double faceWidth) {
		this.faceWidth = faceWidth;
	}

	public String getShopSupporting() {
		return shopSupporting;
	}

	public void setShopSupporting(String shopSupporting) {
		this.shopSupporting = shopSupporting;
	}

	public Double getPrice() {
		return price;
	}

	public void setPrice(Double price) {
		this.price = price;
	}

	public String getPositionImg() {
		return positionImg;
	}

	public void setPositionImg(String positionImg) {
		this.positionImg = positionImg;
	}

	public String getPlaneImg() {
		return planeImg;
	}

	public void setPlaneImg(String planeImg) {
		this.planeImg = planeImg;
	}

	public Date getOpenTime() {
		return openTime;
	}

	public void setOpenTime(Date openTime) {
		this.openTime = openTime;
	}

	public String getOpenWorker() {
		return openWorker;
	}

	public void setOpenWorker(String openWorker) {
		this.openWorker = openWorker;
	}

	public Double getShopAverage() {
		return shopAverage;
	}

	public void setShopAverage(Double shopAverage) {
		this.shopAverage = shopAverage;
	}

	public String getFloorName() {
		return floorName;
	}

	public void setFloorName(String floorName) {
		this.floorName = floorName;
	}


	

	public String getCommission() {
		return commission;
	}

	public void setCommission(String commission) {
		this.commission = commission;
	}

	

	public BigDecimal getCommissionValue() {
		return commissionValue;
	}

	public void setCommissionValue(BigDecimal commissionValue) {
		this.commissionValue = commissionValue;
	}

	public String getEntrustImg() {
		return entrustImg;
	}

	public void setEntrustImg(String entrustImg) {
		this.entrustImg = entrustImg;
	}

	public Double getFeeService() {
		return feeService;
	}

	public void setFeeService(Double feeService) {
		this.feeService = feeService;
	}

	public Double getWaterFee() {
		return waterFee;
	}

	public void setWaterFee(Double waterFee) {
		this.waterFee = waterFee;
	}

	public Double getElectricityFee() {
		return electricityFee;
	}

	public void setElectricityFee(Double electricityFee) {
		this.electricityFee = electricityFee;
	}

	public Double getPropertyFee() {
		return propertyFee;
	}

	public void setPropertyFee(Double propertyFee) {
		this.propertyFee = propertyFee;
	}

	public Integer getCustomerId() {
		return customerId;
	}

	public void setCustomerId(Integer customerId) {
		this.customerId = customerId;
	}

	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public String getLinkMan() {
		return linkMan;
	}

	public void setLinkman(String linkMan) {
		this.linkMan = linkMan;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public BigDecimal getYearlyRent() {
		return yearlyRent;
	}

	public void setYearlyRent(BigDecimal yearlyRent) {
		this.yearlyRent = yearlyRent;
	}

	public BigDecimal getMonthlyRent() {
		return monthlyRent;
	}

	public void setMonthlyRent(BigDecimal monthlyRent) {
		this.monthlyRent = monthlyRent;
	}

	public BigDecimal getDailyRent() {
		return dailyRent;
	}

	public void setDailyRent(BigDecimal dailyRent) {
		this.dailyRent = dailyRent;
	}

	public BigDecimal getTransferFee() {
		return transferFee;
	}

	public void setTransferFee(BigDecimal transferFee) {
		this.transferFee = transferFee;
	}

	public Integer getPledgeMethod() {
		return pledgeMethod;
	}

	public void setPledgeMethod(Integer pledgeMethod) {
		this.pledgeMethod = pledgeMethod;
	}

	public String getPledgeInfo() {
		return pledgeInfo;
	}

	public void setPledgeInfo(String pledgeInfo) {
		this.pledgeInfo = pledgeInfo;
	}

	public Integer getPayMethod() {
		return payMethod;
	}

	public void setPayMethod(Integer payMethod) {
		this.payMethod = payMethod;
	}

	public Integer getStatus() {
		return status;
	}

	public void setStatus(Integer status) {
		this.status = status;
	}

	public Integer getRentType() {
		return rentType;
	}

	public void setRentType(Integer rentType) {
		this.rentType = rentType;
	}

	public Integer getTimeRent() {
		return timeRent;
	}

	public void setTimeRent(Integer timeRent) {
		this.timeRent = timeRent;
	}

	public String getCurrLease() {
		return currLease;
	}

	public void setCurrLease(String currLease) {
		this.currLease = currLease;
	}

	public String getResidue() {
		return residue;
	}

	public void setResidue(String residue) {
		this.residue = residue;
	}

	public String getMaxLease() {
		return maxLease;
	}

	public void setMaxLease(String maxLease) {
		this.maxLease = maxLease;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public BigDecimal getBuildArea() {
		return buildArea;
	}

	public void setBuildArea(BigDecimal buildArea) {
		this.buildArea = buildArea;
	}

	public BigDecimal getUseArea() {
		return useArea;
	}

	public void setUseArea(BigDecimal useArea) {
		this.useArea = useArea;
	}


	public Boolean getFrontage() {
		return frontage;
	}

	public void setFrontage(Boolean frontage) {
		this.frontage = frontage;
	}

	public Boolean getFloor1() {
		return floor1;
	}

	public void setFloor1(Boolean floor1) {
		this.floor1 = floor1;
	}

	public Boolean getFloor2() {
		return floor2;
	}

	public void setFloor2(Boolean floor2) {
		this.floor2 = floor2;
	}

	public Boolean getFloor3() {
		return floor3;
	}

	public void setFloor3(Boolean floor3) {
		this.floor3 = floor3;
	}

	public Boolean getFloor4() {
		return floor4;
	}

	public void setFloor4(Boolean floor4) {
		this.floor4 = floor4;
	}

	public Boolean getFloorHigh() {
		return floorHigh;
	}

	public void setFloorHigh(Boolean floorHigh) {
		this.floorHigh = floorHigh;
	}

	public Boolean getFloorUnder() {
		return floorUnder;
	}

	public void setFloorUnder(Boolean floorUnder) {
		this.floorUnder = floorUnder;
	}

	public Integer getParentManageTypeId() {
		return parentManageTypeId;
	}

	public void setParentManageTypeId(Integer parentManageTypeId) {
		this.parentManageTypeId = parentManageTypeId;
	}

	public Integer getSonManageTypeId() {
		return sonManageTypeId;
	}

	public void setSonManageTypeId(Integer sonManageTypeId) {
		this.sonManageTypeId = sonManageTypeId;
	}

	public Integer getLicense() {
		return license;
	}

	public void setLicense(Integer license) {
		this.license = license;
	}

	public Integer getManageStatus() {
		return manageStatus;
	}

	public void setManageStatus(Integer manageStatus) {
		this.manageStatus = manageStatus;
	}

	public String getShopName() {
		return shopName;
	}

	public void setShopName(String shopName) {
		this.shopName = shopName;
	}

	public String getPaperImgs() {
		return paperImgs;
	}

	public void setPaperImgs(String paperImgs) {
		this.paperImgs = paperImgs;
	}

	public String getCover() {
		return cover;
	}

	public void setCover(String cover) {
		this.cover = cover;
	}

	public Integer getCityId() {
		return cityId;
	}

	public void setCity(Integer cityId) {
		this.cityId = cityId;
	}

	public Integer getAreaId() {
		return areaId;
	}

	public void setAreaId(Integer areaId) {
		this.areaId = areaId;
	}

	public Integer getBusinessAreaId() {
		return businessAreaId;
	}

	public void setBusinessAreaId(Integer businessAreaId) {
		this.businessAreaId = businessAreaId;
	}

	public Integer getRoadAreaId() {
		return roadAreaId;
	}

	public void setRoadAreaId(Integer roadAreaId) {
		this.roadAreaId = roadAreaId;
	}

	public String getRealAddress() {
		return realAddress;
	}

	public void setRealAddress(String realAddress) {
		this.realAddress = realAddress;
	}

	public String getPositionX() {
		return positionX;
	}

	public void setPositionX(String positionX) {
		this.positionX = positionX;
	}

	public String getPositionY() {
		return positionY;
	}

	public void setPositionY(String positionY) {
		this.positionY = positionY;
	}

	public Integer getLoopLine() {
		return loopLine;
	}

	public void setLoopLine(Integer loopLine) {
		this.loopLine = loopLine;
	}

	public String getImgs() {
		return imgs;
	}

	public void setImgs(String imgs) {
		this.imgs = imgs;
	}

	public String getIntroduce() {
		return introduce;
	}

	public void setIntroduce(String introduce) {
		this.introduce = introduce;
	}

	public String getTurnoverShare() {
		return turnoverShare;
	}

	public void setTurnoverShare(String turnoverShare) {
		this.turnoverShare = turnoverShare;
	}

	public String getShopNumber() {
		return shopNumber;
	}

	public void setShopNumber(String shopNumber) {
		this.shopNumber = shopNumber;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Integer getOnlineStatus() {
		return onlineStatus;
	}

	public void setOnlineStatus(Integer onlineStatus) {
		this.onlineStatus = onlineStatus;
	}

	public Integer getCreateType() {
		return createType;
	}

	public void setCreateType(Integer createType) {
		this.createType = createType;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public Integer getInvalidReason() {
		return invalidReason;
	}

	public void setInvalidReason(Integer invalidReason) {
		this.invalidReason = invalidReason;
	}

	public Date getTopBeginTime() {
		return topBeginTime;
	}

	public void setTopBeginTime(Date topBeginTime) {
		this.topBeginTime = topBeginTime;
	}

	public Date getTopEndTime() {
		return topEndTime;
	}

	public void setTopEndTime(Date topEndTime) {
		this.topEndTime = topEndTime;
	}

	public Integer getTopStatus() {
		return topStatus;
	}

	public void setTopStatus(Integer topStatus) {
		this.topStatus = topStatus;
	}

	public Integer getShowFlag() {
		return showFlag;
	}

	public void setShowFlag(Integer showFlag) {
		this.showFlag = showFlag;
	}

	public Integer getShopFlow() {
		return shopFlow;
	}

	public void setShopFlow(Integer shopFlow) {
		this.shopFlow = shopFlow;
	}

	public void setLinkMan(String linkMan) {
		this.linkMan = linkMan;
	}

	public void setCityId(Integer cityId) {
		this.cityId = cityId;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public Integer getShopAttr() {
		return shopAttr;
	}

	public void setShopAttr(Integer shopAttr) {
		this.shopAttr = shopAttr;
	}

	public Integer getIsImport() {
		return isImport;
	}

	public void setIsImport(Integer isImport) {
		this.isImport = isImport;
	}

	public String getExpired() {
		return expired;
	}

	public void setExpired(String expired) {
		this.expired = expired;
	}

	public BigDecimal getTotalPrice() {
		return totalPrice;
	}

	public void setTotalPrice(BigDecimal totalPrice) {
		this.totalPrice = totalPrice;
	}
	
}
